searchData={"items":[{"type":"module","title":"StarkBank","doc":"SDK to facilitate Elixir integrations with the Stark Bank API v2.","ref":"StarkBank.html"},{"type":"function","title":"StarkBank.organization/1","doc":"The Organization object is an authentication entity for the SDK that\nrepresents your entire Organization, being able to access any Workspace\nunderneath it and even create new Workspaces. Only a legal representative\nof your organization can register or change the Organization credentials.\nAll requests to the Stark Bank API must be authenticated via an SDK user,\nwhich must have been previously created at the Stark Bank website\n[https://web.sandbox.starkbank.com] or [https://web.starkbank.com]\nbefore you can use it in this SDK. Organizations may be passed as the user parameter on\neach request or may be defined as the default user at the start (See README).\nIf you are accessing a specific Workspace using Organization credentials, you should\nspecify the workspace ID when building the Organization object or by request, using\nthe Organization.replace(organization, workspace_id) method, which creates a copy of the organization\nobject with the altered workspace ID. If you are listing or creating new Workspaces, the\nworkspace_id should be nil.","ref":"StarkBank.html#organization/1"},{"type":"function","title":"Parameters (required): - StarkBank.organization/1","doc":"- `:environment` [string]: environment where the organization is being used. ex: \"sandbox\" or \"production\"\n  - `:id` [string]: unique id required to identify organization. ex: \"5656565656565656\"\n  - `:private_key` [EllipticCurve.Organization()]: PEM string of the private key linked to the organization. ex: \"-----BEGIN PUBLIC KEY-----\nMFYwEAYHKoZIzj0CAQYFK4EEAAoDQgAEyTIHK6jYuik6ktM9FIF3yCEYzpLjO5X/\ntqDioGM+R2RyW0QEo+1DG8BrUf4UXHSvCjtQ0yLppygz23z0yPZYfw==\n-----END PUBLIC KEY-----\"","ref":"StarkBank.html#organization/1-parameters-required"},{"type":"function","title":"Parameters (optional): - StarkBank.organization/1","doc":"- `:workspace_id` [string]: unique id of the accessed Workspace, if any. ex: nil or \"4848484848484848\"","ref":"StarkBank.html#organization/1-parameters-optional"},{"type":"function","title":"StarkBank.project/1","doc":"The Project object is an authentication entity for the SDK that is permanently\nlinked to a specific Workspace.\nAll requests to the Stark Bank API must be authenticated via an SDK user,\nwhich must have been previously created at the Stark Bank website\n[https://web.sandbox.starkbank.com] or [https://web.starkbank.com]\nbefore you can use it in this SDK. Projects may be passed as the user parameter on\neach request or may be defined as the default user at the start (See README).","ref":"StarkBank.html#project/1"},{"type":"function","title":"Parameters (required): - StarkBank.project/1","doc":"- `environment` [string]: environment where the project is being used. ex: \"sandbox\" or \"production\"\n  - `id` [string]: unique id required to identify project. ex: \"5656565656565656\"\n  - `private_key` [string]: PEM string of the private key linked to the project. ex: \"-----BEGIN PUBLIC KEY-----\nMFYwEAYHKoZIzj0CAQYFK4EEAAoDQgAEyTIHK6jYuik6ktM9FIF3yCEYzpLjO5X/\ntqDioGM+R2RyW0QEo+1DG8BrUf4UXHSvCjtQ0yLppygz23z0yPZYfw==\n-----END PUBLIC KEY-----\"","ref":"StarkBank.html#project/1-parameters-required"},{"type":"module","title":"StarkBank.Balance","doc":"Groups Balance related functions","ref":"StarkBank.Balance.html"},{"type":"function","title":"StarkBank.Balance.__struct__/0","doc":"The Balance struct displays the current balance of the workspace,\nwhich is the result of the sum of all transactions within this\nworkspace. The balance is never generated by the user, but it\ncan be retrieved to see the information available.","ref":"StarkBank.Balance.html#__struct__/0"},{"type":"function","title":"Attributes (return-only): - StarkBank.Balance.__struct__/0","doc":"- `:id` [string, default nil]: unique id returned when Balance is created. ex: \"5656565656565656\"\n  - `:amount` [integer, default nil]: current balance amount of the workspace in cents. ex: 200 (= R$ 2.00)\n  - `:currency` [string, default nil]: currency of the current workspace. Expect others to be added eventually. ex: \"BRL\"\n  - `:updated` [DateTime, default nil]: update datetime for the balance. ex: ~U[2020-03-26 19:32:35.418698Z]","ref":"StarkBank.Balance.html#__struct__/0-attributes-return-only"},{"type":"function","title":"StarkBank.Balance.get/1","doc":"Receive the Balance entity linked to your workspace in the Stark Bank API","ref":"StarkBank.Balance.html#get/1"},{"type":"function","title":"Options: - StarkBank.Balance.get/1","doc":"- `:user` [Organization/Project, default nil]: Organization or Project struct returned from StarkBank.project(). Only necessary if default project or organization has not been set in configs.","ref":"StarkBank.Balance.html#get/1-options"},{"type":"function","title":"Return: - StarkBank.Balance.get/1","doc":"- Balance struct with updated attributes","ref":"StarkBank.Balance.html#get/1-return"},{"type":"function","title":"StarkBank.Balance.get!/1","doc":"Same as get(), but it will unwrap the error tuple and raise in case of errors.","ref":"StarkBank.Balance.html#get!/1"},{"type":"type","title":"StarkBank.Balance.t/0","doc":"","ref":"StarkBank.Balance.html#t:t/0"},{"type":"module","title":"StarkBank.Boleto","doc":"Groups Boleto related functions","ref":"StarkBank.Boleto.html"},{"type":"function","title":"StarkBank.Boleto.__struct__/0","doc":"When you initialize a Boleto struct, the entity will not be automatically\nsent to the Stark Bank API. The 'create' function sends the structs\nto the Stark Bank API and returns the list of created structs.","ref":"StarkBank.Boleto.html#__struct__/0"},{"type":"function","title":"Parameters (required): - StarkBank.Boleto.__struct__/0","doc":"- `:amount` [integer]: Boleto value in cents. Minimum amount = 200 (R$2,00). ex: 1234 (= R$ 12.34)\n  - `:name` [string]: payer full name. ex: \"Anthony Edward Stark\"\n  - `:tax_id` [string]: payer tax ID (CPF or CNPJ) with or without formatting. ex: \"01234567890\" or \"20.018.183/0001-80\"\n  - `:street_line_1` [string]: payer main address. ex: Av. Paulista, 200\n  - `:street_line_2` [string]: payer address complement. ex: Apto. 123\n  - `:district` [string]: payer address district / neighbourhood. ex: Bela Vista\n  - `:city` [string]: payer address city. ex: Rio de Janeiro\n  - `:state_code` [string]: payer address state. ex: GO\n  - `:zip_code` [string]: payer address zip code. ex: 01311-200","ref":"StarkBank.Boleto.html#__struct__/0-parameters-required"},{"type":"function","title":"Parameters (optional): - StarkBank.Boleto.__struct__/0","doc":"- `:due` [Date or string, default today + 2 days]: Boleto due date in ISO format. ex: 2020-04-30\n  - `:fine` [float, default 0.0]: Boleto fine for overdue payment in %. ex: 2.5\n  - `:interest` [float, default 0.0]: Boleto monthly interest for overdue payment in %. ex: 5.2\n  - `:overdue_limit` [integer, default 59]: limit in days for payment after due date. ex: 7 (max: 59)\n  - `:receiver_name` [string]: receiver (Sacador Avalista) full name. ex: \"Anthony Edward Stark\"\n  - `:receiver_tax_id` [string]: receiver (Sacador Avalista) tax ID (CPF or CNPJ) with or without formatting. ex: \"01234567890\" or \"20.018.183/0001-80\"\n  - `:descriptions` [list of maps, default nil]: list of maps with :text (string) and :amount (int, optional) pairs\n  - `:discounts` [list of maps, default nil]: list of maps with :percentage (float) and :date (Date or string) pairs\n  - `:tags` [list of strings]: list of strings for tagging","ref":"StarkBank.Boleto.html#__struct__/0-parameters-optional"},{"type":"function","title":"Attributes (return-only): - StarkBank.Boleto.__struct__/0","doc":"- `:id` [string, default nil]: unique id returned when Boleto is created. ex: \"5656565656565656\"\n  - `:fee` [integer, default nil]: fee charged when Boleto is paid. ex: 200 (= R$ 2.00)\n  - `:line` [string, default nil]: generated Boleto line for payment. ex: \"34191.09008 63571.277308 71444.640008 5 81960000000062\"\n  - `:bar_code` [string, default nil]: generated Boleto bar-code for payment. ex: \"34195819600000000621090063571277307144464000\"\n  - `:transaction_ids` [list of strings, default nil]: ledger transaction ids linked to this boleto. ex: [\"19827356981273\"]\n  - `:status` [string, default nil]: current Boleto status. ex: \"registered\" or \"paid\"\n  - `:created` [DateTime, default nil]: creation datetime for the Boleto. ex: ~U[2020-03-26 19:32:35.418698Z]\n  - `:our_number` [string, default nil]: reference number registered at the settlement bank. ex: \"10131474\"","ref":"StarkBank.Boleto.html#__struct__/0-attributes-return-only"},{"type":"function","title":"StarkBank.Boleto.create/2","doc":"Send a list of Boleto structs for creation in the Stark Bank API","ref":"StarkBank.Boleto.html#create/2"},{"type":"function","title":"Parameters (required): - StarkBank.Boleto.create/2","doc":"- `boletos` [list of Boleto structs]: list of Boleto structs to be created in the API","ref":"StarkBank.Boleto.html#create/2-parameters-required"},{"type":"function","title":"Options: - StarkBank.Boleto.create/2","doc":"- `:user` [Organization/Project, default nil]: Organization or Project struct returned from StarkBank.project(). Only necessary if default project or organization has not been set in configs.","ref":"StarkBank.Boleto.html#create/2-options"},{"type":"function","title":"Return: - StarkBank.Boleto.create/2","doc":"- list of Boleto structs with updated attributes","ref":"StarkBank.Boleto.html#create/2-return"},{"type":"function","title":"StarkBank.Boleto.create!/2","doc":"Same as create(), but it will unwrap the error tuple and raise in case of errors.","ref":"StarkBank.Boleto.html#create!/2"},{"type":"function","title":"StarkBank.Boleto.delete/2","doc":"Delete a list of Boleto entities previously created in the Stark Bank API","ref":"StarkBank.Boleto.html#delete/2"},{"type":"function","title":"Parameters (required): - StarkBank.Boleto.delete/2","doc":"- `id` [string]: Boleto unique id. ex: \"5656565656565656\"","ref":"StarkBank.Boleto.html#delete/2-parameters-required"},{"type":"function","title":"Options: - StarkBank.Boleto.delete/2","doc":"- `:user` [Organization/Project, default nil]: Organization or Project struct returned from StarkBank.project(). Only necessary if default project or organization has not been set in configs.\n\n##  Return:\n  - deleted Boleto struct","ref":"StarkBank.Boleto.html#delete/2-options"},{"type":"function","title":"StarkBank.Boleto.delete!/2","doc":"Same as delete(), but it will unwrap the error tuple and raise in case of errors.","ref":"StarkBank.Boleto.html#delete!/2"},{"type":"function","title":"StarkBank.Boleto.get/2","doc":"Receive a single Boleto struct previously created in the Stark Bank API by passing its id","ref":"StarkBank.Boleto.html#get/2"},{"type":"function","title":"Parameters (required): - StarkBank.Boleto.get/2","doc":"- `id` [string]: struct unique id. ex: \"5656565656565656\"","ref":"StarkBank.Boleto.html#get/2-parameters-required"},{"type":"function","title":"Options: - StarkBank.Boleto.get/2","doc":"- `:user` [Organization/Project, default nil]: Organization or Project struct returned from StarkBank.project(). Only necessary if default project or organization has not been set in configs.","ref":"StarkBank.Boleto.html#get/2-options"},{"type":"function","title":"Return: - StarkBank.Boleto.get/2","doc":"- Boleto struct with updated attributes","ref":"StarkBank.Boleto.html#get/2-return"},{"type":"function","title":"StarkBank.Boleto.get!/2","doc":"Same as get(), but it will unwrap the error tuple and raise in case of errors.","ref":"StarkBank.Boleto.html#get!/2"},{"type":"function","title":"StarkBank.Boleto.page/1","doc":"Receive a list of up to 100 Boleto objects previously created in the Stark Bank API and the cursor to the next page. \nUse this function instead of query if you want to manually page your requests.","ref":"StarkBank.Boleto.html#page/1"},{"type":"function","title":"Options: - StarkBank.Boleto.page/1","doc":"- `:cursor` [string, default nil]: cursor returned on the previous page function call\n  - `:limit` [integer, default nil]: maximum number of structs to be retrieved. Unlimited if nil. ex: 35\n  - `:after` [Date or string, default nil]: date filter for structs created only after specified date. ex: ~D[2020-03-25]\n  - `:before` [Date or string, default nil]: date filter for structs created only before specified date. ex: ~D[2020-03-25]\n  - `:status` [string, default nil]: filter for status of retrieved structs. ex: \"paid\" or \"registered\"\n  - `:tags` [list of strings, default nil]: tags to filter retrieved structs. ex: [\"tony\", \"stark\"]\n  - `:ids` [list of strings, default nil]: list of ids to filter retrieved structs. ex: [\"5656565656565656\", \"4545454545454545\"]\n  - `:user` [Organization/Project, default nil]: Organization or Project struct returned from StarkBank.project(). Only necessary if default project or organization has not been set in configs.","ref":"StarkBank.Boleto.html#page/1-options"},{"type":"function","title":"Return: - StarkBank.Boleto.page/1","doc":"- stream of Boleto structs with updated attributes","ref":"StarkBank.Boleto.html#page/1-return"},{"type":"function","title":"StarkBank.Boleto.page!/1","doc":"Same as page(), but it will unwrap the error tuple and raise in case of errors.","ref":"StarkBank.Boleto.html#page!/1"},{"type":"function","title":"StarkBank.Boleto.pdf/2","doc":"Receive a single Boleto pdf file generated in the Stark Bank API by passing its id.","ref":"StarkBank.Boleto.html#pdf/2"},{"type":"function","title":"Parameters (required): - StarkBank.Boleto.pdf/2","doc":"- `id` [string]: struct unique id. ex: \"5656565656565656\"","ref":"StarkBank.Boleto.html#pdf/2-parameters-required"},{"type":"function","title":"Options: - StarkBank.Boleto.pdf/2","doc":"- `:layout` [string]: Layout specification. Available options are \"default\" and \"booklet\".\n  - `:user` [Organization/Project, default nil]: Organization or Project struct returned from StarkBank.project(). Only necessary if default project or organization has not been set in configs.","ref":"StarkBank.Boleto.html#pdf/2-options"},{"type":"function","title":"Return: - StarkBank.Boleto.pdf/2","doc":"- Boleto pdf file content","ref":"StarkBank.Boleto.html#pdf/2-return"},{"type":"function","title":"StarkBank.Boleto.pdf!/2","doc":"Same as pdf(), but it will unwrap the error tuple and raise in case of errors.","ref":"StarkBank.Boleto.html#pdf!/2"},{"type":"function","title":"StarkBank.Boleto.query/1","doc":"Receive a stream of Boleto structs previously created in the Stark Bank API","ref":"StarkBank.Boleto.html#query/1"},{"type":"function","title":"Options: - StarkBank.Boleto.query/1","doc":"- `:limit` [integer, default nil]: maximum number of structs to be retrieved. Unlimited if nil. ex: 35\n  - `:after` [Date or string, default nil]: date filter for structs created only after specified date. ex: ~D[2020-03-25]\n  - `:before` [Date or string, default nil]: date filter for structs created only before specified date. ex: ~D[2020-03-25]\n  - `:status` [string, default nil]: filter for status of retrieved structs. ex: \"paid\" or \"registered\"\n  - `:tags` [list of strings, default nil]: tags to filter retrieved structs. ex: [\"tony\", \"stark\"]\n  - `:ids` [list of strings, default nil]: list of ids to filter retrieved structs. ex: [\"5656565656565656\", \"4545454545454545\"]\n  - `:user` [Organization/Project, default nil]: Organization or Project struct returned from StarkBank.project(). Only necessary if default project or organization has not been set in configs.","ref":"StarkBank.Boleto.html#query/1-options"},{"type":"function","title":"Return: - StarkBank.Boleto.query/1","doc":"- stream of Boleto structs with updated attributes","ref":"StarkBank.Boleto.html#query/1-return"},{"type":"function","title":"StarkBank.Boleto.query!/1","doc":"Same as query(), but it will unwrap the error tuple and raise in case of errors.","ref":"StarkBank.Boleto.html#query!/1"},{"type":"type","title":"StarkBank.Boleto.t/0","doc":"","ref":"StarkBank.Boleto.html#t:t/0"},{"type":"module","title":"StarkBank.Boleto.Log","doc":"Groups Boleto.Log related functions","ref":"StarkBank.Boleto.Log.html"},{"type":"function","title":"StarkBank.Boleto.Log.__struct__/0","doc":"Every time a Boleto entity is updated, a corresponding Boleto.Log\nis generated for the entity. This log is never generated by the\nuser, but it can be retrieved to check additional information\non the Boleto.","ref":"StarkBank.Boleto.Log.html#__struct__/0"},{"type":"function","title":"Attributes: - StarkBank.Boleto.Log.__struct__/0","doc":"- `:id` [string]: unique id returned when the log is created. ex: \"5656565656565656\"\n  - `:boleto` [Boleto]: Boleto entity to which the log refers to.\n  - `:errors` [list of strings]: list of errors linked to this Boleto event\n  - `:type` [string]: type of the Boleto event which triggered the log creation. ex: \"registered\" or \"paid\"\n  - `:created` [DateTime]: creation datetime for the log. ex: ~U[2020-03-26 19:32:35.418698Z]","ref":"StarkBank.Boleto.Log.html#__struct__/0-attributes"},{"type":"function","title":"StarkBank.Boleto.Log.get/2","doc":"Receive a single Log struct previously created by the Stark Bank API by passing its id","ref":"StarkBank.Boleto.Log.html#get/2"},{"type":"function","title":"Parameters (required): - StarkBank.Boleto.Log.get/2","doc":"- `id` [string]: struct unique id. ex: \"5656565656565656\"","ref":"StarkBank.Boleto.Log.html#get/2-parameters-required"},{"type":"function","title":"Options: - StarkBank.Boleto.Log.get/2","doc":"- `:user` [Organization/Project, default nil]: Organization or Project struct returned from StarkBank.project(). Only necessary if default project or organization has not been set in configs.","ref":"StarkBank.Boleto.Log.html#get/2-options"},{"type":"function","title":"Return: - StarkBank.Boleto.Log.get/2","doc":"- Log struct with updated attributes","ref":"StarkBank.Boleto.Log.html#get/2-return"},{"type":"function","title":"StarkBank.Boleto.Log.get!/2","doc":"Same as get(), but it will unwrap the error tuple and raise in case of errors.","ref":"StarkBank.Boleto.Log.html#get!/2"},{"type":"function","title":"StarkBank.Boleto.Log.page/1","doc":"Receive a list of up to 100 Boleto.Log objects previously created in the Stark Bank API and the cursor to the next page. \nUse this function instead of query if you want to manually page your requests.","ref":"StarkBank.Boleto.Log.html#page/1"},{"type":"function","title":"Options: - StarkBank.Boleto.Log.page/1","doc":"- `:cursor` [string, default nil]: cursor returned on the previous page function call\n  - `:limit` [integer, default nil]: maximum number of structs to be retrieved. Unlimited if nil. ex: 35\n  - `:after` [Date or string, default nil]: date filter for structs created only after specified date. ex: ~D[2020-03-25]\n  - `:before` [Date or string, default nil]: date filter for structs created only before specified date. ex: ~D[2020-03-25]\n  - `:types` [list of strings, default nil]: filter for log event types. ex: \"paid\" or \"registered\"\n  - `:boleto_ids` [list of strings, default nil]: list of Boleto ids to filter logs. ex: [\"5656565656565656\", \"4545454545454545\"]\n  - `:user` [Organization/Project, default nil]: Organization or Project struct returned from StarkBank.project(). Only necessary if default project or organization has not been set in configs.","ref":"StarkBank.Boleto.Log.html#page/1-options"},{"type":"function","title":"Return: - StarkBank.Boleto.Log.page/1","doc":"- list of Boleto.Log structs with updated attributes and cursor to retrieve the next page of Boleto.Log objects","ref":"StarkBank.Boleto.Log.html#page/1-return"},{"type":"function","title":"StarkBank.Boleto.Log.page!/1","doc":"Same as page(), but it will unwrap the error tuple and raise in case of errors.","ref":"StarkBank.Boleto.Log.html#page!/1"},{"type":"function","title":"StarkBank.Boleto.Log.query/1","doc":"Receive a stream of Log structs previously created in the Stark Bank API","ref":"StarkBank.Boleto.Log.html#query/1"},{"type":"function","title":"Options: - StarkBank.Boleto.Log.query/1","doc":"- `:limit` [integer, default nil]: maximum number of structs to be retrieved. Unlimited if nil. ex: 35\n  - `:after` [Date or string, default nil]: date filter for structs created only after specified date. ex: ~D[2020-03-25]\n  - `:before` [Date or string, default nil]: date filter for structs created only before specified date. ex: ~D[2020-03-25]\n  - `:types` [list of strings, default nil]: filter for log event types. ex: \"paid\" or \"registered\"\n  - `:boleto_ids` [list of strings, default nil]: list of Boleto ids to filter logs. ex: [\"5656565656565656\", \"4545454545454545\"]\n  - `:user` [Organization/Project, default nil]: Organization or Project struct returned from StarkBank.project(). Only necessary if default project or organization has not been set in configs.","ref":"StarkBank.Boleto.Log.html#query/1-options"},{"type":"function","title":"Return: - StarkBank.Boleto.Log.query/1","doc":"- stream of Log structs with updated attributes","ref":"StarkBank.Boleto.Log.html#query/1-return"},{"type":"function","title":"StarkBank.Boleto.Log.query!/1","doc":"Same as query(), but it will unwrap the error tuple and raise in case of errors.","ref":"StarkBank.Boleto.Log.html#query!/1"},{"type":"type","title":"StarkBank.Boleto.Log.t/0","doc":"","ref":"StarkBank.Boleto.Log.html#t:t/0"},{"type":"module","title":"StarkBank.BoletoHolmes","doc":"Groups BoletoHolmes related functions","ref":"StarkBank.BoletoHolmes.html"},{"type":"function","title":"StarkBank.BoletoHolmes.__struct__/0","doc":"When you initialize a BoletoHolmes, the entity will not be automatically\ncreated in the Stark Bank API. The 'create' function sends the objects\nto the Stark Bank API and returns the list of created objects.","ref":"StarkBank.BoletoHolmes.html#__struct__/0"},{"type":"function","title":"Parameters (required): - StarkBank.BoletoHolmes.__struct__/0","doc":"- `:boleto_id` [string]: unique id of the investigated boleto. ex: \"5656565656565656\"","ref":"StarkBank.BoletoHolmes.html#__struct__/0-parameters-required"},{"type":"function","title":"Parameters (optional): - StarkBank.BoletoHolmes.__struct__/0","doc":"- `:tags` [list of strings]: list of strings for tagging","ref":"StarkBank.BoletoHolmes.html#__struct__/0-parameters-optional"},{"type":"function","title":"Attributes (return-only): - StarkBank.BoletoHolmes.__struct__/0","doc":"- `:id` [string, default nil]: unique id returned when BoletoHolmes is created. ex: \"5656565656565656\"\n  - `:status` [string, default nil]: current BoletoHolmes status. ex: \"solving\" or \"solved\"\n  - `:result` [string, default nil]: result of boleto status investigation. ex: \"paid\" or \"registered\"\n  - `:created` [DateTime, default nil]: creation datetime for the BoletoHolmes. ex: ~U[2020-03-26 19:32:35.418698Z]\n  - `:updated` [DateTime, default nil]: latest updated datetime for the BoletoHolmes. ex: ~U[2020-03-26 19:32:35.418698Z]","ref":"StarkBank.BoletoHolmes.html#__struct__/0-attributes-return-only"},{"type":"function","title":"StarkBank.BoletoHolmes.create/2","doc":"Send a list of BoletoHolmes objects for creation in the Stark Bank API","ref":"StarkBank.BoletoHolmes.html#create/2"},{"type":"function","title":"Parameters (required): - StarkBank.BoletoHolmes.create/2","doc":"- `holmes` [list of BoletoHolmes structs]: list of BoletoHolmes structs to be created in the API","ref":"StarkBank.BoletoHolmes.html#create/2-parameters-required"},{"type":"function","title":"Options: - StarkBank.BoletoHolmes.create/2","doc":"- `:user` [Organization/Project, default nil]: Organization or Project struct returned from StarkBank.project(). Only necessary if default project or organization has not been set in configs.","ref":"StarkBank.BoletoHolmes.html#create/2-options"},{"type":"function","title":"Return: - StarkBank.BoletoHolmes.create/2","doc":"- list of BoletoHolmes structs with updated attributes","ref":"StarkBank.BoletoHolmes.html#create/2-return"},{"type":"function","title":"StarkBank.BoletoHolmes.create!/2","doc":"Same as create(), but it will unwrap the error tuple and raise in case of errors.","ref":"StarkBank.BoletoHolmes.html#create!/2"},{"type":"function","title":"StarkBank.BoletoHolmes.get/2","doc":"Receive a single BoletoHolmes struct previously created in the Stark Bank API by passing its id","ref":"StarkBank.BoletoHolmes.html#get/2"},{"type":"function","title":"Parameters (required): - StarkBank.BoletoHolmes.get/2","doc":"- `id` [string]: struct unique id. ex: \"5656565656565656\"","ref":"StarkBank.BoletoHolmes.html#get/2-parameters-required"},{"type":"function","title":"Options: - StarkBank.BoletoHolmes.get/2","doc":"- `:user` [Organization/Project, default nil]: Organization or Project struct returned from StarkBank.project(). Only necessary if default project or organization has not been set in configs.","ref":"StarkBank.BoletoHolmes.html#get/2-options"},{"type":"function","title":"Return: - StarkBank.BoletoHolmes.get/2","doc":"- BoletoHolmes struct with updated attributes","ref":"StarkBank.BoletoHolmes.html#get/2-return"},{"type":"function","title":"StarkBank.BoletoHolmes.get!/2","doc":"Same as get(), but it will unwrap the error tuple and raise in case of errors.","ref":"StarkBank.BoletoHolmes.html#get!/2"},{"type":"function","title":"StarkBank.BoletoHolmes.page/1","doc":"Receive a list of up to 100 BoletoHolmes objects previously created in the Stark Bank API and the cursor to the next page. \nUse this function instead of query if you want to manually page your requests.","ref":"StarkBank.BoletoHolmes.html#page/1"},{"type":"function","title":"Options: - StarkBank.BoletoHolmes.page/1","doc":"- `:cursor` [string, default nil]: cursor returned on the previous page function call\n  - `:limit` [integer, default nil]: maximum number of structs to be retrieved. Unlimited if nil. ex: 35\n  - `:after` [Date or string, default nil]: date filter for structs created only after specified date. ex: ~D[2020-03-25]\n  - `:before` [Date or string, default nil]: date filter for structs created only before specified date. ex: ~D[2020-03-25]\n  - `:status` [string, default nil]: filter for status of retrieved structs. ex: \"solving\" or \"solved\"\n  - `:tags` [list of strings, default nil]: tags to filter retrieved structs. ex: [\"tony\", \"stark\"]\n  - `:ids` [list of strings, default nil]: list of ids to filter retrieved structs. ex: [\"5656565656565656\", \"4545454545454545\"]\n  - `:boleto_id` [string, default nil]: filter for holmes that investigate a specific boleto by its ID. ex: \"5656565656565656\"\n  - `:user` [Organization/Project, default nil]: Organization or Project struct returned from StarkBank.project(). Only necessary if default project or organization has not been set in configs.","ref":"StarkBank.BoletoHolmes.html#page/1-options"},{"type":"function","title":"Return: - StarkBank.BoletoHolmes.page/1","doc":"- list of BoletoHolmes structs with updated attributes and cursor to retrieve the next page of BoletoHolmes objects","ref":"StarkBank.BoletoHolmes.html#page/1-return"},{"type":"function","title":"StarkBank.BoletoHolmes.page!/1","doc":"Same as page(), but it will unwrap the error tuple and raise in case of errors.","ref":"StarkBank.BoletoHolmes.html#page!/1"},{"type":"function","title":"StarkBank.BoletoHolmes.query/1","doc":"Receive a stream of BoletoHolmes structs previously created in the Stark Bank API","ref":"StarkBank.BoletoHolmes.html#query/1"},{"type":"function","title":"Options: - StarkBank.BoletoHolmes.query/1","doc":"- `:limit` [integer, default nil]: maximum number of structs to be retrieved. Unlimited if nil. ex: 35\n  - `:after` [Date or string, default nil]: date filter for structs created only after specified date. ex: ~D[2020-03-25]\n  - `:before` [Date or string, default nil]: date filter for structs created only before specified date. ex: ~D[2020-03-25]\n  - `:status` [string, default nil]: filter for status of retrieved structs. ex: \"solving\" or \"solved\"\n  - `:tags` [list of strings, default nil]: tags to filter retrieved structs. ex: [\"tony\", \"stark\"]\n  - `:ids` [list of strings, default nil]: list of ids to filter retrieved structs. ex: [\"5656565656565656\", \"4545454545454545\"]\n  - `:boleto_id` [string, default nil]: filter for holmes that investigate a specific boleto by its ID. ex: \"5656565656565656\"\n  - `:user` [Organization/Project, default nil]: Organization or Project struct returned from StarkBank.project(). Only necessary if default project or organization has not been set in configs.","ref":"StarkBank.BoletoHolmes.html#query/1-options"},{"type":"function","title":"Return: - StarkBank.BoletoHolmes.query/1","doc":"- stream of BoletoHolmes structs with updated attributes","ref":"StarkBank.BoletoHolmes.html#query/1-return"},{"type":"function","title":"StarkBank.BoletoHolmes.query!/1","doc":"Same as query(), but it will unwrap the error tuple and raise in case of errors.","ref":"StarkBank.BoletoHolmes.html#query!/1"},{"type":"type","title":"StarkBank.BoletoHolmes.t/0","doc":"","ref":"StarkBank.BoletoHolmes.html#t:t/0"},{"type":"module","title":"StarkBank.BoletoHolmes.Log","doc":"Groups BoletoHolmes.Log related functions","ref":"StarkBank.BoletoHolmes.Log.html"},{"type":"function","title":"StarkBank.BoletoHolmes.Log.__struct__/0","doc":"Every time a BoletoHolmes entity is updated, a corresponding BoletoHolmes.Log\nis generated for the entity. This log is never generated by the\nuser, but it can be retrieved to check additional information\non the BoletoHolmes.","ref":"StarkBank.BoletoHolmes.Log.html#__struct__/0"},{"type":"function","title":"Attributes: - StarkBank.BoletoHolmes.Log.__struct__/0","doc":"- `:id` [string]: unique id returned when the log is created. ex: \"5656565656565656\"\n  - `:holmes` [BoletoHolmes]: BoletoHolmes entity to which the log refers to.\n  - `:type` [string]: type of the BoletoHolmes event which triggered the log creation. ex: \"solving\" or \"solved\"\n  - `:created` [DateTime]: creation datetime for the log. ex: ~U[2020-03-26 19:32:35.418698Z]","ref":"StarkBank.BoletoHolmes.Log.html#__struct__/0-attributes"},{"type":"function","title":"StarkBank.BoletoHolmes.Log.get/2","doc":"Receive a single Log struct previously created by the Stark Bank API by passing its id","ref":"StarkBank.BoletoHolmes.Log.html#get/2"},{"type":"function","title":"Parameters (required): - StarkBank.BoletoHolmes.Log.get/2","doc":"- `id` [string]: struct unique id. ex: \"5656565656565656\"","ref":"StarkBank.BoletoHolmes.Log.html#get/2-parameters-required"},{"type":"function","title":"Options: - StarkBank.BoletoHolmes.Log.get/2","doc":"- `:user` [Organization/Project, default nil]: Organization or Project struct returned from StarkBank.project(). Only necessary if default project or organization has not been set in configs.","ref":"StarkBank.BoletoHolmes.Log.html#get/2-options"},{"type":"function","title":"Return: - StarkBank.BoletoHolmes.Log.get/2","doc":"- Log struct with updated attributes","ref":"StarkBank.BoletoHolmes.Log.html#get/2-return"},{"type":"function","title":"StarkBank.BoletoHolmes.Log.get!/2","doc":"Same as get(), but it will unwrap the error tuple and raise in case of errors.","ref":"StarkBank.BoletoHolmes.Log.html#get!/2"},{"type":"function","title":"StarkBank.BoletoHolmes.Log.page/1","doc":"Receive a list of up to 100 BoletoHolmes.Log objects previously created in the Stark Bank API and the cursor to the next page. \nUse this function instead of query if you want to manually page your requests.","ref":"StarkBank.BoletoHolmes.Log.html#page/1"},{"type":"function","title":"Options: - StarkBank.BoletoHolmes.Log.page/1","doc":"- `:cursor` [string, default nil]: cursor returned on the previous page function call\n  - `:limit` [integer, default nil]: maximum number of structs to be retrieved. Unlimited if nil. ex: 35\n  - `:after` [Date or string, default nil]: date filter for structs created only after specified date. ex: ~D[2020-03-25]\n  - `:before` [Date or string, default nil]: date filter for structs created only before specified date. ex: ~D[2020-03-25]\n  - `:types` [list of strings, default nil]: filter for log event types. ex: \"paid\" or \"registered\"\n  - `:holmes_ids` [list of strings, default nil]: list of BoletoHolmes ids to filter logs. ex: [\"5656565656565656\", \"4545454545454545\"]\n  - `:user` [Organization/Project, default nil]: Organization or Project struct returned from StarkBank.project(). Only necessary if default project or organization has not been set in configs.","ref":"StarkBank.BoletoHolmes.Log.html#page/1-options"},{"type":"function","title":"Return: - StarkBank.BoletoHolmes.Log.page/1","doc":"- list of BoletoHolmes.Log structs with updated attributes and cursor to retrieve the next page of BoletoHolmes.Log objects","ref":"StarkBank.BoletoHolmes.Log.html#page/1-return"},{"type":"function","title":"StarkBank.BoletoHolmes.Log.page!/1","doc":"Same as page(), but it will unwrap the error tuple and raise in case of errors.","ref":"StarkBank.BoletoHolmes.Log.html#page!/1"},{"type":"function","title":"StarkBank.BoletoHolmes.Log.query/1","doc":"Receive a stream of Log structs previously created in the Stark Bank API","ref":"StarkBank.BoletoHolmes.Log.html#query/1"},{"type":"function","title":"Options: - StarkBank.BoletoHolmes.Log.query/1","doc":"- `:limit` [integer, default nil]: maximum number of structs to be retrieved. Unlimited if nil. ex: 35\n  - `:after` [Date or string, default nil]: date filter for structs created only after specified date. ex: ~D[2020-03-25]\n  - `:before` [Date or string, default nil]: date filter for structs created only before specified date. ex: ~D[2020-03-25]\n  - `:types` [list of strings, default nil]: filter for log event types. ex: \"paid\" or \"registered\"\n  - `:holmes_ids` [list of strings, default nil]: list of BoletoHolmes ids to filter logs. ex: [\"5656565656565656\", \"4545454545454545\"]\n  - `:user` [Organization/Project, default nil]: Organization or Project struct returned from StarkBank.project(). Only necessary if default project or organization has not been set in configs.","ref":"StarkBank.BoletoHolmes.Log.html#query/1-options"},{"type":"function","title":"Return: - StarkBank.BoletoHolmes.Log.query/1","doc":"- stream of Log structs with updated attributes","ref":"StarkBank.BoletoHolmes.Log.html#query/1-return"},{"type":"function","title":"StarkBank.BoletoHolmes.Log.query!/1","doc":"Same as query(), but it will unwrap the error tuple and raise in case of errors.","ref":"StarkBank.BoletoHolmes.Log.html#query!/1"},{"type":"type","title":"StarkBank.BoletoHolmes.Log.t/0","doc":"","ref":"StarkBank.BoletoHolmes.Log.html#t:t/0"},{"type":"module","title":"StarkBank.BoletoPayment","doc":"Groups BoletoPayment related functions","ref":"StarkBank.BoletoPayment.html"},{"type":"function","title":"StarkBank.BoletoPayment.__struct__/0","doc":"When you initialize a BoletoPayment, the entity will not be automatically\ncreated in the Stark Bank API. The 'create' function sends the structs\nto the Stark Bank API and returns the list of created structs.","ref":"StarkBank.BoletoPayment.html#__struct__/0"},{"type":"function","title":"Parameters (conditionally required): - StarkBank.BoletoPayment.__struct__/0","doc":"- `:line` [string, default nil]: Number sequence that describes the payment. Either 'line' or 'bar_code' parameters are required. If both are sent, they must match. ex: \"34191.09008 63571.277308 71444.640008 5 81960000000062\"\n  - `:bar_code` [string, default nil]: Bar code number that describes the payment. Either 'line' or 'barCode' parameters are required. If both are sent, they must match. ex: \"34195819600000000621090063571277307144464000\"","ref":"StarkBank.BoletoPayment.html#__struct__/0-parameters-conditionally-required"},{"type":"function","title":"Parameters (required): - StarkBank.BoletoPayment.__struct__/0","doc":"- `:tax_id` [string]: receiver tax ID (CPF or CNPJ) with or without formatting. ex: \"01234567890\" or \"20.018.183/0001-80\"\n  - `:description` [string]: Text to be displayed in your statement (min. 10 characters). ex: \"payment ABC\"","ref":"StarkBank.BoletoPayment.html#__struct__/0-parameters-required"},{"type":"function","title":"Parameters (optional): - StarkBank.BoletoPayment.__struct__/0","doc":"- `:scheduled` [Date or string, default today]: payment scheduled date. ex: ~D[2020-03-25]\n  - `:tags` [list of strings]: list of strings for tagging","ref":"StarkBank.BoletoPayment.html#__struct__/0-parameters-optional"},{"type":"function","title":"Attributes (return-only): - StarkBank.BoletoPayment.__struct__/0","doc":"- `:id` [string, default nil]: unique id returned when payment is created. ex: \"5656565656565656\"\n  - `:status` [string, default nil]: current payment status. ex: \"success\" or \"failed\"\n  - `:amount` [int, default nil]: amount automatically calculated from line or bar_code. ex: 23456 (= R$ 234.56)\n  - `:fee` [integer, default nil]: fee charged when a boleto payment is created. ex: 200 (= R$ 2.00)\n  - `:created` [DateTime, default nil]: creation datetime for the payment. ex: ~U[2020-03-26 19:32:35.418698Z]","ref":"StarkBank.BoletoPayment.html#__struct__/0-attributes-return-only"},{"type":"function","title":"StarkBank.BoletoPayment.create/2","doc":"Send a list of BoletoPayment structs for creation in the Stark Bank API","ref":"StarkBank.BoletoPayment.html#create/2"},{"type":"function","title":"Parameters (required): - StarkBank.BoletoPayment.create/2","doc":"- `payments` [list of BoletoPayment structs]: list of BoletoPayment structs to be created in the API","ref":"StarkBank.BoletoPayment.html#create/2-parameters-required"},{"type":"function","title":"Options: - StarkBank.BoletoPayment.create/2","doc":"- `:user` [Organization/Project, default nil]: Organization or Project struct returned from StarkBank.project(). Only necessary if default project or organization has not been set in configs.","ref":"StarkBank.BoletoPayment.html#create/2-options"},{"type":"function","title":"Return: - StarkBank.BoletoPayment.create/2","doc":"- list of BoletoPayment structs with updated attributes","ref":"StarkBank.BoletoPayment.html#create/2-return"},{"type":"function","title":"StarkBank.BoletoPayment.create!/2","doc":"Same as create(), but it will unwrap the error tuple and raise in case of errors.","ref":"StarkBank.BoletoPayment.html#create!/2"},{"type":"function","title":"StarkBank.BoletoPayment.delete/2","doc":"Delete a BoletoPayment entity previously created in the Stark Bank API","ref":"StarkBank.BoletoPayment.html#delete/2"},{"type":"function","title":"Parameters (required): - StarkBank.BoletoPayment.delete/2","doc":"- `id` [string]: BoletoPayment unique id. ex: \"5656565656565656\"","ref":"StarkBank.BoletoPayment.html#delete/2-parameters-required"},{"type":"function","title":"Options: - StarkBank.BoletoPayment.delete/2","doc":"- `:user` [Organization/Project, default nil]: Organization or Project struct returned from StarkBank.project(). Only necessary if default project or organization has not been set in configs.","ref":"StarkBank.BoletoPayment.html#delete/2-options"},{"type":"function","title":"Return: - StarkBank.BoletoPayment.delete/2","doc":"- deleted BoletoPayment struct","ref":"StarkBank.BoletoPayment.html#delete/2-return"},{"type":"function","title":"StarkBank.BoletoPayment.delete!/2","doc":"Same as delete(), but it will unwrap the error tuple and raise in case of errors.","ref":"StarkBank.BoletoPayment.html#delete!/2"},{"type":"function","title":"StarkBank.BoletoPayment.get/2","doc":"Receive a single BoletoPayment struct previously created by the Stark Bank API by passing its id","ref":"StarkBank.BoletoPayment.html#get/2"},{"type":"function","title":"Parameters (required): - StarkBank.BoletoPayment.get/2","doc":"- `id` [string]: struct unique id. ex: \"5656565656565656\"","ref":"StarkBank.BoletoPayment.html#get/2-parameters-required"},{"type":"function","title":"Options: - StarkBank.BoletoPayment.get/2","doc":"- `:user` [Organization/Project, default nil]: Organization or Project struct returned from StarkBank.project(). Only necessary if default project or organization has not been set in configs.","ref":"StarkBank.BoletoPayment.html#get/2-options"},{"type":"function","title":"Return: - StarkBank.BoletoPayment.get/2","doc":"- BoletoPayment struct with updated attributes","ref":"StarkBank.BoletoPayment.html#get/2-return"},{"type":"function","title":"StarkBank.BoletoPayment.get!/2","doc":"Same as get(), but it will unwrap the error tuple and raise in case of errors.","ref":"StarkBank.BoletoPayment.html#get!/2"},{"type":"function","title":"StarkBank.BoletoPayment.page/1","doc":"Receive a list of up to 100 BoletoPayment objects previously created in the Stark Bank API and the cursor to the next page. \nUse this function instead of query if you want to manually page your requests.","ref":"StarkBank.BoletoPayment.html#page/1"},{"type":"function","title":"Options: - StarkBank.BoletoPayment.page/1","doc":"- `:cursor` [string, default nil]: cursor returned on the previous page function call\n  - `:limit` [integer, default nil]: maximum number of structs to be retrieved. Unlimited if nil. ex: 35\n  - `:after` [Date or string, default nil]: date filter for structs created only after specified date. ex: ~D[2020-03-25]\n  - `:before` [Date or string, default nil]: date filter for structs created only before specified date. ex: ~D[2020-03-25]\n  - `:tags` [list of strings, default nil]: tags to filter retrieved structs. ex: [\"tony\", \"stark\"]\n  - `:ids` [list of strings, default nil]: list of ids to filter retrieved objects. ex: [\"5656565656565656\", \"4545454545454545\"]\n  - `:status` [string, default nil]: filter for status of retrieved structs. ex: \"paid\"\n  - `:user` [Organization/Project, default nil]: Organization or Project struct returned from StarkBank.project(). Only necessary if default project or organization has not been set in configs.","ref":"StarkBank.BoletoPayment.html#page/1-options"},{"type":"function","title":"Return: - StarkBank.BoletoPayment.page/1","doc":"- list of BoletoPayment structs with updated attributes and cursor to retrieve the next page of BoletoPayment objects","ref":"StarkBank.BoletoPayment.html#page/1-return"},{"type":"function","title":"StarkBank.BoletoPayment.page!/1","doc":"Same as page(), but it will unwrap the error tuple and raise in case of errors.","ref":"StarkBank.BoletoPayment.html#page!/1"},{"type":"function","title":"StarkBank.BoletoPayment.pdf/2","doc":"Receive a single BoletoPayment pdf file generated in the Stark Bank API by passing its id.\nOnly valid for boleto payments with \"success\" status.","ref":"StarkBank.BoletoPayment.html#pdf/2"},{"type":"function","title":"Parameters (required): - StarkBank.BoletoPayment.pdf/2","doc":"- `id` [string]: struct unique id. ex: \"5656565656565656\"","ref":"StarkBank.BoletoPayment.html#pdf/2-parameters-required"},{"type":"function","title":"Options: - StarkBank.BoletoPayment.pdf/2","doc":"- `:user` [Organization/Project, default nil]: Organization or Project struct returned from StarkBank.project(). Only necessary if default project or organization has not been set in configs.","ref":"StarkBank.BoletoPayment.html#pdf/2-options"},{"type":"function","title":"Return: - StarkBank.BoletoPayment.pdf/2","doc":"- BoletoPayment pdf file content","ref":"StarkBank.BoletoPayment.html#pdf/2-return"},{"type":"function","title":"StarkBank.BoletoPayment.pdf!/2","doc":"Same as pdf(), but it will unwrap the error tuple and raise in case of errors.","ref":"StarkBank.BoletoPayment.html#pdf!/2"},{"type":"function","title":"StarkBank.BoletoPayment.query/1","doc":"Receive a stream of BoletoPayment structs previously created in the Stark Bank API","ref":"StarkBank.BoletoPayment.html#query/1"},{"type":"function","title":"Options: - StarkBank.BoletoPayment.query/1","doc":"- `:limit` [integer, default nil]: maximum number of structs to be retrieved. Unlimited if nil. ex: 35\n  - `:after` [Date or string, default nil]: date filter for structs created only after specified date. ex: ~D[2020-03-25]\n  - `:before` [Date or string, default nil]: date filter for structs created only before specified date. ex: ~D[2020-03-25]\n  - `:tags` [list of strings, default nil]: tags to filter retrieved structs. ex: [\"tony\", \"stark\"]\n  - `:ids` [list of strings, default nil]: list of ids to filter retrieved objects. ex: [\"5656565656565656\", \"4545454545454545\"]\n  - `:status` [string, default nil]: filter for status of retrieved structs. ex: \"paid\"\n  - `:user` [Organization/Project, default nil]: Organization or Project struct returned from StarkBank.project(). Only necessary if default project or organization has not been set in configs.","ref":"StarkBank.BoletoPayment.html#query/1-options"},{"type":"function","title":"Return: - StarkBank.BoletoPayment.query/1","doc":"- stream of BoletoPayment structs with updated attributes","ref":"StarkBank.BoletoPayment.html#query/1-return"},{"type":"function","title":"StarkBank.BoletoPayment.query!/1","doc":"Same as query(), but it will unwrap the error tuple and raise in case of errors.","ref":"StarkBank.BoletoPayment.html#query!/1"},{"type":"type","title":"StarkBank.BoletoPayment.t/0","doc":"","ref":"StarkBank.BoletoPayment.html#t:t/0"},{"type":"module","title":"StarkBank.BoletoPayment.Log","doc":"Groups BoletoPayment.Log related functions","ref":"StarkBank.BoletoPayment.Log.html"},{"type":"function","title":"StarkBank.BoletoPayment.Log.__struct__/0","doc":"Every time a BoletoPayment entity is modified, a corresponding BoletoPayment.Log\nis generated for the entity. This log is never generated by the\nuser, but it can be retrieved to check additional information\non the BoletoPayment.","ref":"StarkBank.BoletoPayment.Log.html#__struct__/0"},{"type":"function","title":"Attributes: - StarkBank.BoletoPayment.Log.__struct__/0","doc":"- `:id` [string]: unique id returned when the log is created. ex: \"5656565656565656\"\n  - `:payment` [BoletoPayment]: BoletoPayment entity to which the log refers to.\n  - `:errors` [list of strings]: list of errors linked to this BoletoPayment event.\n  - `:type` [string]: type of the BoletoPayment event which triggered the log creation. ex: \"processing\" or \"success\"\n  - `:created` [DateTime]: creation datetime for the log. ex: ~U[2020-03-26 19:32:35.418698Z]","ref":"StarkBank.BoletoPayment.Log.html#__struct__/0-attributes"},{"type":"function","title":"StarkBank.BoletoPayment.Log.get/2","doc":"Receive a single Log struct previously created by the Stark Bank API by passing its id","ref":"StarkBank.BoletoPayment.Log.html#get/2"},{"type":"function","title":"Parameters (required): - StarkBank.BoletoPayment.Log.get/2","doc":"- `id` [string]: struct unique id. ex: \"5656565656565656\"","ref":"StarkBank.BoletoPayment.Log.html#get/2-parameters-required"},{"type":"function","title":"Options: - StarkBank.BoletoPayment.Log.get/2","doc":"- `:user` [Organization/Project, default nil]: Organization or Project struct returned from StarkBank.project(). Only necessary if default project or organization has not been set in configs.","ref":"StarkBank.BoletoPayment.Log.html#get/2-options"},{"type":"function","title":"Return: - StarkBank.BoletoPayment.Log.get/2","doc":"- Log struct with updated attributes","ref":"StarkBank.BoletoPayment.Log.html#get/2-return"},{"type":"function","title":"StarkBank.BoletoPayment.Log.get!/2","doc":"Same as get(), but it will unwrap the error tuple and raise in case of errors.","ref":"StarkBank.BoletoPayment.Log.html#get!/2"},{"type":"function","title":"StarkBank.BoletoPayment.Log.page/1","doc":"Receive a list of up to 100 BoletoPayment.Log objects previously created in the Stark Bank API and the cursor to the next page. \nUse this function instead of query if you want to manually page your requests.","ref":"StarkBank.BoletoPayment.Log.html#page/1"},{"type":"function","title":"Options: - StarkBank.BoletoPayment.Log.page/1","doc":"- `:cursor` [string, default nil]: cursor returned on the previous page function call\n  - `:limit` [integer, default nil]: maximum number of entities to be retrieved. Unlimited if nil. ex: 35\n  - `:after` [Date or string, default nil]: date filter for entities created only after specified date. ex: ~D[2020-03-25]\n  - `:before` [Date or string, default nil]: date filter for entities created only before specified date. ex: ~D[2020-03-25]\n  - `:types` [list of strings, default nil]: filter retrieved entities by event types. ex: \"processing\" or \"success\"\n  - `:payment_ids` [list of strings, default nil]: list of BoletoPayment ids to filter retrieved entities. ex: [\"5656565656565656\", \"4545454545454545\"]\n  - `:user` [Organization/Project, default nil]: Organization or Project struct returned from StarkBank.project(). Only necessary if default project or organization has not been set in configs.","ref":"StarkBank.BoletoPayment.Log.html#page/1-options"},{"type":"function","title":"Return: - StarkBank.BoletoPayment.Log.page/1","doc":"- list of BoletoPayment.Log structs with updated attributes and cursor to retrieve the next page of BoletoPayment.Log objects","ref":"StarkBank.BoletoPayment.Log.html#page/1-return"},{"type":"function","title":"StarkBank.BoletoPayment.Log.page!/1","doc":"Same as page(), but it will unwrap the error tuple and raise in case of errors.","ref":"StarkBank.BoletoPayment.Log.html#page!/1"},{"type":"function","title":"StarkBank.BoletoPayment.Log.query/1","doc":"Receive a stream of Log structs previously created in the Stark Bank API","ref":"StarkBank.BoletoPayment.Log.html#query/1"},{"type":"function","title":"Options: - StarkBank.BoletoPayment.Log.query/1","doc":"- `:limit` [integer, default nil]: maximum number of entities to be retrieved. Unlimited if nil. ex: 35\n  - `:after` [Date or string, default nil]: date filter for entities created only after specified date. ex: ~D[2020-03-25]\n  - `:before` [Date or string, default nil]: date filter for entities created only before specified date. ex: ~D[2020-03-25]\n  - `:types` [list of strings, default nil]: filter retrieved entities by event types. ex: \"processing\" or \"success\"\n  - `:payment_ids` [list of strings, default nil]: list of BoletoPayment ids to filter retrieved entities. ex: [\"5656565656565656\", \"4545454545454545\"]\n  - `:user` [Organization/Project, default nil]: Organization or Project struct returned from StarkBank.project(). Only necessary if default project or organization has not been set in configs.","ref":"StarkBank.BoletoPayment.Log.html#query/1-options"},{"type":"function","title":"Return: - StarkBank.BoletoPayment.Log.query/1","doc":"- stream of Log structs with updated attributes","ref":"StarkBank.BoletoPayment.Log.html#query/1-return"},{"type":"function","title":"StarkBank.BoletoPayment.Log.query!/1","doc":"Same as query(), but it will unwrap the error tuple and raise in case of errors.","ref":"StarkBank.BoletoPayment.Log.html#query!/1"},{"type":"type","title":"StarkBank.BoletoPayment.Log.t/0","doc":"","ref":"StarkBank.BoletoPayment.Log.html#t:t/0"},{"type":"module","title":"StarkBank.BrcodePayment","doc":"Groups BrcodePayment related functions","ref":"StarkBank.BrcodePayment.html"},{"type":"function","title":"StarkBank.BrcodePayment.__struct__/0","doc":"When you initialize a BrcodePayment, the entity will not be automatically\ncreated in the Stark Bank API. The 'create' function sends the structs\nto the Stark Bank API and returns the list of created structs.","ref":"StarkBank.BrcodePayment.html#__struct__/0"},{"type":"function","title":"Parameters (required): - StarkBank.BrcodePayment.__struct__/0","doc":"- `:brcode` [string]: String loaded directly from the QRCode or copied from the invoice. ex: \"00020126580014br.gov.bcb.pix0136a629532e-7693-4846-852d-1bbff817b5a8520400005303986540510.005802BR5908T'Challa6009Sao Paulo62090505123456304B14A\"\n  - `:tax_id` [string]: receiver tax ID (CPF or CNPJ) with or without formatting. ex: \"01234567890\" or \"20.018.183/0001-80\"\n  - `:description` [string]: Text to be displayed in your statement (min. 10 characters). ex: \"payment ABC\"","ref":"StarkBank.BrcodePayment.html#__struct__/0-parameters-required"},{"type":"function","title":"Parameters (conditionally required): - StarkBank.BrcodePayment.__struct__/0","doc":"- `:amount` [int, default nil]: If the BR Code does not provide an amount, this parameter is mandatory, else it is optional. ex: 23456 (= R$ 234.56)","ref":"StarkBank.BrcodePayment.html#__struct__/0-parameters-conditionally-required"},{"type":"function","title":"Parameters (optional): - StarkBank.BrcodePayment.__struct__/0","doc":"- `:scheduled` [Date, DateTime or string, default now]: payment scheduled date or datetime. ex: \"2020-12-13T18:36:18.219000+00:00\"\n  - `:tags` [list of strings]: list of strings for tagging.","ref":"StarkBank.BrcodePayment.html#__struct__/0-parameters-optional"},{"type":"function","title":"Attributes (return-only): - StarkBank.BrcodePayment.__struct__/0","doc":"- `:id` [string, default nil]: unique id returned when payment is created. ex: \"5656565656565656\"\n  - `:name` [string, default nil]: receiver name. ex: \"Jon Snow\"\n  - `:status` [string, default nil]: current payment status. ex: \"success\" or \"failed\"\n  - `:type` [string, default nil]: brcode type. ex: \"static\" or \"dynamic\"\n  - `:fee` [integer, default nil]: fee charged when a brcode payment is created. ex: 200 (= R$ 2.00)\n  - `:transaction_ids` [list of strings, default nil]: ledger transaction ids linked to this BR Code payment. ex: [\"19827356981273\"]\n  - `:created` [DateTime, default nil]: creation datetime for the payment. ex: ~U[2020-03-26 19:32:35.418698Z]\n  - `:updated` [DateTime, default nil]: latest update datetime for the Deposit. ex: ~U[2020-08-20 19:32:35.418698Z]","ref":"StarkBank.BrcodePayment.html#__struct__/0-attributes-return-only"},{"type":"function","title":"StarkBank.BrcodePayment.create/2","doc":"Send a list of BrcodePayment structs for creation in the Stark Bank API","ref":"StarkBank.BrcodePayment.html#create/2"},{"type":"function","title":"Parameters (required): - StarkBank.BrcodePayment.create/2","doc":"- `payments` [list of BrcodePayment structs]: list of BrcodePayment structs to be created in the API","ref":"StarkBank.BrcodePayment.html#create/2-parameters-required"},{"type":"function","title":"Options: - StarkBank.BrcodePayment.create/2","doc":"- `:user` [Organization/Project, default nil]: Organization or Project struct returned from StarkBank.project(). Only necessary if default project or organization has not been set in configs.","ref":"StarkBank.BrcodePayment.html#create/2-options"},{"type":"function","title":"Return: - StarkBank.BrcodePayment.create/2","doc":"- list of BrcodePayment structs with updated attributes","ref":"StarkBank.BrcodePayment.html#create/2-return"},{"type":"function","title":"StarkBank.BrcodePayment.create!/2","doc":"Same as create(), but it will unwrap the error tuple and raise in case of errors.","ref":"StarkBank.BrcodePayment.html#create!/2"},{"type":"function","title":"StarkBank.BrcodePayment.get/2","doc":"Receive a single BrcodePayment struct previously created by the Stark Bank API by passing its id","ref":"StarkBank.BrcodePayment.html#get/2"},{"type":"function","title":"Parameters (required): - StarkBank.BrcodePayment.get/2","doc":"- `id` [string]: struct unique id. ex: \"5656565656565656\"","ref":"StarkBank.BrcodePayment.html#get/2-parameters-required"},{"type":"function","title":"Options: - StarkBank.BrcodePayment.get/2","doc":"- `:user` [Organization/Project, default nil]: Organization or Project struct returned from StarkBank.project(). Only necessary if default project or organization has not been set in configs.","ref":"StarkBank.BrcodePayment.html#get/2-options"},{"type":"function","title":"Return: - StarkBank.BrcodePayment.get/2","doc":"- BrcodePayment struct with updated attributes","ref":"StarkBank.BrcodePayment.html#get/2-return"},{"type":"function","title":"StarkBank.BrcodePayment.get!/2","doc":"Same as get(), but it will unwrap the error tuple and raise in case of errors.","ref":"StarkBank.BrcodePayment.html#get!/2"},{"type":"function","title":"StarkBank.BrcodePayment.page/1","doc":"Receive a list of up to 100 BrcodePayment objects previously created in the Stark Bank API and the cursor to the next page. \nUse this function instead of query if you want to manually page your requests.","ref":"StarkBank.BrcodePayment.html#page/1"},{"type":"function","title":"Options: - StarkBank.BrcodePayment.page/1","doc":"- `:cursor` [string, default nil]: cursor returned on the previous page function call\n  - `:limit` [integer, default nil]: maximum number of structs to be retrieved. Unlimited if nil. ex: 35\n  - `:after` [Date or string, default nil]: date filter for structs created only after specified date. ex: ~D[2020-03-25]\n  - `:before` [Date or string, default nil]: date filter for structs created only before specified date. ex: ~D[2020-03-25]\n  - `:tags` [list of strings, default nil]: tags to filter retrieved structs. ex: [\"tony\", \"stark\"]\n  - `:ids` [list of strings, default nil]: list of ids to filter retrieved objects. ex: [\"5656565656565656\", \"4545454545454545\"]\n  - `:status` [string, default nil]: filter for status of retrieved structs. ex: \"paid\"\n  - `:user` [Organization/Project, default nil]: Organization or Project struct returned from StarkBank.project(). Only necessary if default project or organization has not been set in configs.","ref":"StarkBank.BrcodePayment.html#page/1-options"},{"type":"function","title":"Return: - StarkBank.BrcodePayment.page/1","doc":"- list of BrcodePayment structs with updated attributes and cursor to retrieve the next page of BrcodePayment objects","ref":"StarkBank.BrcodePayment.html#page/1-return"},{"type":"function","title":"StarkBank.BrcodePayment.page!/1","doc":"Same as page(), but it will unwrap the error tuple and raise in case of errors.","ref":"StarkBank.BrcodePayment.html#page!/1"},{"type":"function","title":"StarkBank.BrcodePayment.pdf/2","doc":"Receive a single BrcodePayment pdf file generated in the Stark Bank API by passing its id.","ref":"StarkBank.BrcodePayment.html#pdf/2"},{"type":"function","title":"Parameters (required): - StarkBank.BrcodePayment.pdf/2","doc":"- `id` [string]: struct unique id. ex: \"5656565656565656\"","ref":"StarkBank.BrcodePayment.html#pdf/2-parameters-required"},{"type":"function","title":"Options: - StarkBank.BrcodePayment.pdf/2","doc":"- `:user` [Organization/Project, default nil]: Organization or Project struct returned from StarkBank.project(). Only necessary if default project or organization has not been set in configs.","ref":"StarkBank.BrcodePayment.html#pdf/2-options"},{"type":"function","title":"Return: - StarkBank.BrcodePayment.pdf/2","doc":"- BrcodePayment pdf file content","ref":"StarkBank.BrcodePayment.html#pdf/2-return"},{"type":"function","title":"StarkBank.BrcodePayment.pdf!/2","doc":"Same as pdf(), but it will unwrap the error tuple and raise in case of errors.","ref":"StarkBank.BrcodePayment.html#pdf!/2"},{"type":"function","title":"StarkBank.BrcodePayment.query/1","doc":"Receive a stream of BrcodePayment structs previously created in the Stark Bank API","ref":"StarkBank.BrcodePayment.html#query/1"},{"type":"function","title":"Options: - StarkBank.BrcodePayment.query/1","doc":"- `:limit` [integer, default nil]: maximum number of structs to be retrieved. Unlimited if nil. ex: 35\n  - `:after` [Date or string, default nil]: date filter for structs created only after specified date. ex: ~D[2020-03-25]\n  - `:before` [Date or string, default nil]: date filter for structs created only before specified date. ex: ~D[2020-03-25]\n  - `:tags` [list of strings, default nil]: tags to filter retrieved structs. ex: [\"tony\", \"stark\"]\n  - `:ids` [list of strings, default nil]: list of ids to filter retrieved objects. ex: [\"5656565656565656\", \"4545454545454545\"]\n  - `:status` [string, default nil]: filter for status of retrieved structs. ex: \"paid\"\n  - `:user` [Organization/Project, default nil]: Organization or Project struct returned from StarkBank.project(). Only necessary if default project or organization has not been set in configs.","ref":"StarkBank.BrcodePayment.html#query/1-options"},{"type":"function","title":"Return: - StarkBank.BrcodePayment.query/1","doc":"- stream of BrcodePayment structs with updated attributes","ref":"StarkBank.BrcodePayment.html#query/1-return"},{"type":"function","title":"StarkBank.BrcodePayment.query!/1","doc":"Same as query(), but it will unwrap the error tuple and raise in case of errors.","ref":"StarkBank.BrcodePayment.html#query!/1"},{"type":"function","title":"StarkBank.BrcodePayment.update/2","doc":"Update an BrcodePayment by passing id, if it hasn't been paid yet.","ref":"StarkBank.BrcodePayment.html#update/2"},{"type":"function","title":"Parameters (required): - StarkBank.BrcodePayment.update/2","doc":"- `:id` [string]: BrcodePayment id. ex: '5656565656565656'","ref":"StarkBank.BrcodePayment.html#update/2-parameters-required"},{"type":"function","title":"Parameters (optional): - StarkBank.BrcodePayment.update/2","doc":"- `:status` [string]: You may cancel the BrcodePayment by passing \"canceled\" in the status\n  - `:user` [Organization/Project, default nil]: Organization or Project struct returned from StarkBank.project(). Only necessary if default project or organization has not been set in configs.","ref":"StarkBank.BrcodePayment.html#update/2-parameters-optional"},{"type":"function","title":"Return: - StarkBank.BrcodePayment.update/2","doc":"- target BrcodePayment with updated attributes","ref":"StarkBank.BrcodePayment.html#update/2-return"},{"type":"function","title":"StarkBank.BrcodePayment.update!/2","doc":"Same as update(), but it will unwrap the error tuple and raise in case of errors.","ref":"StarkBank.BrcodePayment.html#update!/2"},{"type":"type","title":"StarkBank.BrcodePayment.t/0","doc":"","ref":"StarkBank.BrcodePayment.html#t:t/0"},{"type":"module","title":"StarkBank.BrcodePayment.Log","doc":"Groups BrcodePayment.Log related functions","ref":"StarkBank.BrcodePayment.Log.html"},{"type":"function","title":"StarkBank.BrcodePayment.Log.__struct__/0","doc":"Every time a BrcodePayment entity is modified, a corresponding BrcodePayment.Log\nis generated for the entity. This log is never generated by the\nuser, but it can be retrieved to check additional information\non the BrcodePayment.","ref":"StarkBank.BrcodePayment.Log.html#__struct__/0"},{"type":"function","title":"Attributes: - StarkBank.BrcodePayment.Log.__struct__/0","doc":"- `:id` [string]: unique id returned when the log is created. ex: \"5656565656565656\"\n  - `:payment` [BrcodePayment]: BrcodePayment entity to which the log refers to.\n  - `:errors` [list of strings]: list of errors linked to this BrcodePayment event.\n  - `:type` [string]: type of the BrcodePayment event which triggered the log creation. ex: \"processing\" or \"success\"\n  - `:created` [DateTime]: creation datetime for the log. ex: ~U[2020-03-26 19:32:35.418698Z]","ref":"StarkBank.BrcodePayment.Log.html#__struct__/0-attributes"},{"type":"function","title":"StarkBank.BrcodePayment.Log.get/2","doc":"Receive a single Log struct previously created by the Stark Bank API by passing its id","ref":"StarkBank.BrcodePayment.Log.html#get/2"},{"type":"function","title":"Parameters (required): - StarkBank.BrcodePayment.Log.get/2","doc":"- `id` [string]: struct unique id. ex: \"5656565656565656\"","ref":"StarkBank.BrcodePayment.Log.html#get/2-parameters-required"},{"type":"function","title":"Options: - StarkBank.BrcodePayment.Log.get/2","doc":"- `:user` [Organization/Project, default nil]: Organization or Project struct returned from StarkBank.project(). Only necessary if default project or organization has not been set in configs.","ref":"StarkBank.BrcodePayment.Log.html#get/2-options"},{"type":"function","title":"Return: - StarkBank.BrcodePayment.Log.get/2","doc":"- Log struct with updated attributes","ref":"StarkBank.BrcodePayment.Log.html#get/2-return"},{"type":"function","title":"StarkBank.BrcodePayment.Log.get!/2","doc":"Same as get(), but it will unwrap the error tuple and raise in case of errors.","ref":"StarkBank.BrcodePayment.Log.html#get!/2"},{"type":"function","title":"StarkBank.BrcodePayment.Log.page/1","doc":"Receive a list of up to 100 BrcodePayment.Log objects previously created in the Stark Bank API and the cursor to the next page. \nUse this function instead of query if you want to manually page your requests.","ref":"StarkBank.BrcodePayment.Log.html#page/1"},{"type":"function","title":"Options: - StarkBank.BrcodePayment.Log.page/1","doc":"- `:cursor` [string, default nil]: cursor returned on the previous page function call\n  - `:limit` [integer, default nil]: maximum number of entities to be retrieved. Unlimited if nil. ex: 35\n  - `:after` [Date or string, default nil]: date filter for entities created only after specified date. ex: ~D[2020-03-25]\n  - `:before` [Date or string, default nil]: date filter for entities created only before specified date. ex: ~D[2020-03-25]\n  - `:types` [list of strings, default nil]: filter retrieved entities by event types. ex: \"processing\" or \"success\"\n  - `:payment_ids` [list of strings, default nil]: list of BrcodePayment ids to filter retrieved entities. ex: [\"5656565656565656\", \"4545454545454545\"]\n  - `:user` [Organization/Project, default nil]: Organization or Project struct returned from StarkBank.project(). Only necessary if default project or organization has not been set in configs.","ref":"StarkBank.BrcodePayment.Log.html#page/1-options"},{"type":"function","title":"Return: - StarkBank.BrcodePayment.Log.page/1","doc":"- list of BrcodePayment.Log structs with updated attributes and cursor to retrieve the next page of BrcodePayment.Log objects","ref":"StarkBank.BrcodePayment.Log.html#page/1-return"},{"type":"function","title":"StarkBank.BrcodePayment.Log.page!/1","doc":"Same as page(), but it will unwrap the error tuple and raise in case of errors.","ref":"StarkBank.BrcodePayment.Log.html#page!/1"},{"type":"function","title":"StarkBank.BrcodePayment.Log.query/1","doc":"Receive a stream of Log structs previously created in the Stark Bank API","ref":"StarkBank.BrcodePayment.Log.html#query/1"},{"type":"function","title":"Options: - StarkBank.BrcodePayment.Log.query/1","doc":"- `:limit` [integer, default nil]: maximum number of entities to be retrieved. Unlimited if nil. ex: 35\n  - `:after` [Date or string, default nil]: date filter for entities created only after specified date. ex: ~D[2020-03-25]\n  - `:before` [Date or string, default nil]: date filter for entities created only before specified date. ex: ~D[2020-03-25]\n  - `:types` [list of strings, default nil]: filter retrieved entities by event types. ex: \"processing\" or \"success\"\n  - `:payment_ids` [list of strings, default nil]: list of BrcodePayment ids to filter retrieved entities. ex: [\"5656565656565656\", \"4545454545454545\"]\n  - `:user` [Organization/Project, default nil]: Organization or Project struct returned from StarkBank.project(). Only necessary if default project or organization has not been set in configs.","ref":"StarkBank.BrcodePayment.Log.html#query/1-options"},{"type":"function","title":"Return: - StarkBank.BrcodePayment.Log.query/1","doc":"- stream of Log structs with updated attributes","ref":"StarkBank.BrcodePayment.Log.html#query/1-return"},{"type":"function","title":"StarkBank.BrcodePayment.Log.query!/1","doc":"Same as query(), but it will unwrap the error tuple and raise in case of errors.","ref":"StarkBank.BrcodePayment.Log.html#query!/1"},{"type":"type","title":"StarkBank.BrcodePayment.Log.t/0","doc":"","ref":"StarkBank.BrcodePayment.Log.html#t:t/0"},{"type":"module","title":"StarkBank.BrcodePreview","doc":"Groups BrcodePreview related functions","ref":"StarkBank.BrcodePreview.html"},{"type":"function","title":"StarkBank.BrcodePreview.__struct__/0","doc":"A BrcodePreview is used to get information from a BR Code\nyou received to check the informations before paying it.","ref":"StarkBank.BrcodePreview.html#__struct__/0"},{"type":"function","title":"Attributes (return-only): - StarkBank.BrcodePreview.__struct__/0","doc":"- `:id` [string]: Payment BR Code.\n  - `:status` [string]: Payment status. ex: \"active\", \"paid\", \"canceled\" or \"unknown\"\n  - `:name` [string]: Payment receiver name. ex: \"Tony Stark\"\n  - `:tax_id` [string]: Payment receiver tax ID. ex: \"012.345.678-90\"\n  - `:bank_code` [string]: Payment receiver bank code. ex: \"20018183\"\n  - `:branch_code` [string]: Payment receiver branch code. ex: \"0001\"\n  - `:account_number` [string]: Payment receiver account number. ex: \"1234567\"\n  - `:account_type` [string]: Payment receiver account type. ex: \"checking\"\n  - `:allow_change` [bool]: If True, the payment is able to receive amounts that are diferent from the nominal one. ex: True\n  - `:amount` [int]: Value in cents that this payment is expecting to receive. If 0, any value is accepted. ex: 123 (= R$1,23)\n  - `:reconciliation_id` [string]: Reconciliation ID linked to this payment. ex: \"tx_id\", \"payment123\"","ref":"StarkBank.BrcodePreview.html#__struct__/0-attributes-return-only"},{"type":"function","title":"StarkBank.BrcodePreview.query/1","doc":"Receive a generator of BrcodePreview objects previously created in the Stark Bank API","ref":"StarkBank.BrcodePreview.html#query/1"},{"type":"function","title":"Options: - StarkBank.BrcodePreview.query/1","doc":"- `:brcodes` [list of strings, default nil]: List of brcodes to preview. ex: [\"00020126580014br.gov.bcb.pix0136a629532e-7693-4846-852d-1bbff817b5a8520400005303986540510.005802BR5908T'Challa6009Sao Paulo62090505123456304B14A\"]\n  - `:user` [Organization/Project, default nil]: Organization or Project struct returned from StarkBank.project(). Only necessary if default project or organization has not been set in configs.","ref":"StarkBank.BrcodePreview.html#query/1-options"},{"type":"function","title":"Return: - StarkBank.BrcodePreview.query/1","doc":"- stream of BrcodePreview structs with updated attributes","ref":"StarkBank.BrcodePreview.html#query/1-return"},{"type":"function","title":"StarkBank.BrcodePreview.query!/1","doc":"Same as query(), but it will unwrap the error tuple and raise in case of errors.","ref":"StarkBank.BrcodePreview.html#query!/1"},{"type":"type","title":"StarkBank.BrcodePreview.t/0","doc":"","ref":"StarkBank.BrcodePreview.html#t:t/0"},{"type":"module","title":"StarkBank.DarfPayment","doc":"Groups DarfPayment related functions","ref":"StarkBank.DarfPayment.html"},{"type":"function","title":"StarkBank.DarfPayment.__struct__/0","doc":"When you initialize a DarfPayment, the entity will not be automatically\ncreated in the Stark Bank API. The 'create' function sends the objects\nto the Stark Bank API and returns the list of created objects.","ref":"StarkBank.DarfPayment.html#__struct__/0"},{"type":"function","title":"Parameters (required): - StarkBank.DarfPayment.__struct__/0","doc":"- `:description` [string]: Text to be displayed in your statement (min. 10 characters). ex: \"payment ABC\"\n  - `:revenue_code` [string]: 4-digit tax code assigned by Federal Revenue. ex: \"5948\"\n  - `:tax_id` [tax_id]: tax id (formatted or unformatted) of the payer. ex: \"12.345.678/0001-95\"\n  - `:competence` [Date or string]: competence month of the service. ex: ~D[2020-03-25]\n  - `:nominal_amount` [int]: amount due in cents without fee or interest. ex: 23456 (= R$ 234.56)\n  - `:fine_amount` [int]: fixed amount due in cents for fines. ex: 234 (= R$ 2.34)\n  - `:interest_amount` [int]: amount due in cents for interest. ex: 456 (= R$ 4.56)\n  - `:due` [Date or string]: due date for payment. ex: ~D[2020-03-25]","ref":"StarkBank.DarfPayment.html#__struct__/0-parameters-required"},{"type":"function","title":"Parameters (optional): - StarkBank.DarfPayment.__struct__/0","doc":"- `:reference_number` [string]: number assigned to the region of the tax. ex: \"08.1.17.00-4\"\n  - `:scheduled` [Date or string, default today]: payment scheduled date. ex: ~D[2020-03-25]\n  - `:tags` [list of strings]: list of strings for tagging","ref":"StarkBank.DarfPayment.html#__struct__/0-parameters-optional"},{"type":"function","title":"Attributes (return-only): - StarkBank.DarfPayment.__struct__/0","doc":"- `:id` [string, default nil]: unique id returned when payment is created. ex: \"5656565656565656\"\n  - `:status` [string, default nil]: current payment status. ex: \"success\" or \"failed\"\n  - `:amount` [int, default nil]: amount automatically calculated from line or bar_code. ex: 23456 (= R$ 234.56)\n  - `:fee` [integer, default nil]: fee charged when the tax payment is created. ex: 200 (= R$ 2.00)\n  - `:updated` [DateTime, default nil]: latest update datetime for the Invoice. ex: ~U[2020-11-26 17:31:45.482618Z]\n  - `:created` [DateTime, default nil]: creation datetime for the Invoice. ex: ~U[2020-03-26 19:32:35.418698Z]","ref":"StarkBank.DarfPayment.html#__struct__/0-attributes-return-only"},{"type":"function","title":"StarkBank.DarfPayment.create/2","doc":"Send a list of DarfPayment structs for creation in the Stark Bank API","ref":"StarkBank.DarfPayment.html#create/2"},{"type":"function","title":"Parameters (required): - StarkBank.DarfPayment.create/2","doc":"- `:payments` [list of DarfPayment structs]: list of DarfPayment structs to be created in the API","ref":"StarkBank.DarfPayment.html#create/2-parameters-required"},{"type":"function","title":"Options: - StarkBank.DarfPayment.create/2","doc":"- `:user` [Organization/Project, default nil]: Organization or Project struct returned from StarkBank.project(). Only necessary if default project or organization has not been set in configs.","ref":"StarkBank.DarfPayment.html#create/2-options"},{"type":"function","title":"Return: - StarkBank.DarfPayment.create/2","doc":"- list of DarfPayment structs with updated attributes","ref":"StarkBank.DarfPayment.html#create/2-return"},{"type":"function","title":"StarkBank.DarfPayment.create!/2","doc":"Same as create(), but it will unwrap the error tuple and raise in case of errors.","ref":"StarkBank.DarfPayment.html#create!/2"},{"type":"function","title":"StarkBank.DarfPayment.delete/2","doc":"Delete a DarfPayment entity previously created in the Stark Bank API","ref":"StarkBank.DarfPayment.html#delete/2"},{"type":"function","title":"Parameters (required): - StarkBank.DarfPayment.delete/2","doc":"- `:id` [string]: Boleto unique id. ex: \"5656565656565656\"","ref":"StarkBank.DarfPayment.html#delete/2-parameters-required"},{"type":"function","title":"Options: - StarkBank.DarfPayment.delete/2","doc":"- `:user` [Organization/Project, default nil]: Organization or Project struct returned from StarkBank.project(). Only necessary if default project or organization has not been set in configs.\n\n##  Return:\n  - deleted DarfPayment struct","ref":"StarkBank.DarfPayment.html#delete/2-options"},{"type":"function","title":"StarkBank.DarfPayment.delete!/2","doc":"Same as delete(), but it will unwrap the error tuple and raise in case of errors.","ref":"StarkBank.DarfPayment.html#delete!/2"},{"type":"function","title":"StarkBank.DarfPayment.get/2","doc":"Receive a single DarfPayment struct previously created by the Stark Bank API by passing its id","ref":"StarkBank.DarfPayment.html#get/2"},{"type":"function","title":"Parameters (required): - StarkBank.DarfPayment.get/2","doc":"- `:id` [string]: entity unique id. ex: \"5656565656565656\"","ref":"StarkBank.DarfPayment.html#get/2-parameters-required"},{"type":"function","title":"Options: - StarkBank.DarfPayment.get/2","doc":"- `:user` [Organization/Project, default nil]: Organization or Project struct returned from StarkBank.project(). Only necessary if default project or organization has not been set in configs.","ref":"StarkBank.DarfPayment.html#get/2-options"},{"type":"function","title":"Return: - StarkBank.DarfPayment.get/2","doc":"- DarfPayment struct with updated attributes","ref":"StarkBank.DarfPayment.html#get/2-return"},{"type":"function","title":"StarkBank.DarfPayment.get!/2","doc":"Same as get(), but it will unwrap the error tuple and raise in case of errors.","ref":"StarkBank.DarfPayment.html#get!/2"},{"type":"function","title":"StarkBank.DarfPayment.page/1","doc":"Receive a list of up to 100 DarfPayment structs previously created in the Stark Bank API and the cursor to the next page.\nUse this function instead of query if you want to manually page your requests.","ref":"StarkBank.DarfPayment.html#page/1"},{"type":"function","title":"Options: - StarkBank.DarfPayment.page/1","doc":"- `:cursor` [string, default nil]: cursor returned on the previous page function call\n  - `:limit` [integer, default nil]: maximum number of entities to be retrieved. Unlimited if nil. ex: 35\n  - `:after` [Date or string, default nil]: date filter for entities created only after specified date. ex: ~D[2020-03-25]\n  - `:before` [Date or string, default nil]: date filter for entities created only before specified date. ex: ~D[2020-03-25]\n  - `:tags` [list of strings, default nil]: tags to filter retrieved structs. ex: [\"tony\", \"stark\"]\n  - `:ids` [list of strings, default nil]: list of ids to filter retrieved structs. ex: ['5656565656565656', '4545454545454545']\n  - `:status` [string, default nil]: filter for status of retrieved structs. ex: 'success'\n  - `:user` [Organization/Project, default nil]: Organization or Project struct returned from StarkBank.project(). Only necessary if default project or organization has not been set in configs.","ref":"StarkBank.DarfPayment.html#page/1-options"},{"type":"function","title":"Return: - StarkBank.DarfPayment.page/1","doc":"- list of DarfPayment structs with updated attributes and cursor to retrieve the next page of DarfPayment structs","ref":"StarkBank.DarfPayment.html#page/1-return"},{"type":"function","title":"StarkBank.DarfPayment.page!/1","doc":"Same as page(), but it will unwrap the error tuple and raise in case of errors.","ref":"StarkBank.DarfPayment.html#page!/1"},{"type":"function","title":"StarkBank.DarfPayment.pdf/2","doc":"Receive a single Transfer pdf receipt file generated in the Stark Bank API by passing its id.\nOnly valid for transfers with \"processing\" or \"success\" status.","ref":"StarkBank.DarfPayment.html#pdf/2"},{"type":"function","title":"Parameters (required): - StarkBank.DarfPayment.pdf/2","doc":"- `id` [string]: struct unique id. ex: \"5656565656565656\"","ref":"StarkBank.DarfPayment.html#pdf/2-parameters-required"},{"type":"function","title":"Options: - StarkBank.DarfPayment.pdf/2","doc":"- `:user` [Organization/Project, default nil]: Organization or Project struct returned from StarkBank.project(). Only necessary if default project or organization has not been set in configs.","ref":"StarkBank.DarfPayment.html#pdf/2-options"},{"type":"function","title":"Return: - StarkBank.DarfPayment.pdf/2","doc":"- Transfer pdf file content","ref":"StarkBank.DarfPayment.html#pdf/2-return"},{"type":"function","title":"StarkBank.DarfPayment.pdf!/2","doc":"Same as pdf(), but it will unwrap the error tuple and raise in case of errors.","ref":"StarkBank.DarfPayment.html#pdf!/2"},{"type":"function","title":"StarkBank.DarfPayment.query/1","doc":"Receive a stream of DarfPayment entities previously created in the Stark Bank API","ref":"StarkBank.DarfPayment.html#query/1"},{"type":"function","title":"Options: - StarkBank.DarfPayment.query/1","doc":"- `:limit` [integer, default nil]: maximum number of entities to be retrieved. Unlimited if nil. ex: 35\n  - `:after` [Date or string, default nil]: date filter for entities created only after specified date. ex: ~D[2020-03-25]\n  - `:before` [Date or string, default nil]: date filter for entities created only before specified date. ex: ~D[2020-03-25]\n  - `:tags` [list of strings, default nil]: tags to filter retrieved structs. ex: [\"tony\", \"stark\"]\n  - `:ids` [list of strings, default nil]: list of ids to filter retrieved structs. ex: ['5656565656565656', '4545454545454545']\n  - `:status` [string, default nil]: filter for status of retrieved structs. ex: 'success'\n  - `:user` [Organization/Project, default nil]: Organization or Project struct returned from StarkBank.project(). Only necessary if default project or organization has not been set in configs.","ref":"StarkBank.DarfPayment.html#query/1-options"},{"type":"function","title":"Return: - StarkBank.DarfPayment.query/1","doc":"- stream of DarfPayment structs with updated attributes","ref":"StarkBank.DarfPayment.html#query/1-return"},{"type":"function","title":"StarkBank.DarfPayment.query!/1","doc":"Same as query(), but it will unwrap the error tuple and raise in case of errors.","ref":"StarkBank.DarfPayment.html#query!/1"},{"type":"type","title":"StarkBank.DarfPayment.t/0","doc":"","ref":"StarkBank.DarfPayment.html#t:t/0"},{"type":"module","title":"StarkBank.DarfPayment.Log","doc":"Groups DarfPayment.Log related functions","ref":"StarkBank.DarfPayment.Log.html"},{"type":"function","title":"StarkBank.DarfPayment.Log.__struct__/0","doc":"Every time a DarfPayment entity is modified, a corresponding DarfPayment.Log\nis generated for the entity. This log is never generated by the user, but it can\nbe retrieved to check additional information on the DarfPayment.","ref":"StarkBank.DarfPayment.Log.html#__struct__/0"},{"type":"function","title":"Attributes (return-only): - StarkBank.DarfPayment.Log.__struct__/0","doc":"- `:id` [string]: unique id returned when payment is created. ex: \"5656565656565656\"\n  - `:payment` [DarfPayment]: DarfPayment entity to which the log refers to.\n  - `:errors` [list of strings]: list of errors linked to this DarfPayment event.\n  - `:type` [string]: tax type. ex: \"das\"\n  - `:created` [DateTime]: creation datetime for the payment. ex: ~U[2020-03-26 19:32:35.418698Z]","ref":"StarkBank.DarfPayment.Log.html#__struct__/0-attributes-return-only"},{"type":"function","title":"StarkBank.DarfPayment.Log.get/2","doc":"Receive a single DarfPayment Log struct previously created by the Stark Bank API by passing its id","ref":"StarkBank.DarfPayment.Log.html#get/2"},{"type":"function","title":"Parameters (required): - StarkBank.DarfPayment.Log.get/2","doc":"- `:id` [string]: entity unique id. ex: \"5656565656565656\"","ref":"StarkBank.DarfPayment.Log.html#get/2-parameters-required"},{"type":"function","title":"Options: - StarkBank.DarfPayment.Log.get/2","doc":"- `:user` [Organization/Project, default nil]: Organization or Project struct returned from StarkBank.project(). Only necessary if default project or organization has not been set in configs.","ref":"StarkBank.DarfPayment.Log.html#get/2-options"},{"type":"function","title":"Return: - StarkBank.DarfPayment.Log.get/2","doc":"- DarfPayment Log struct with updated attributes","ref":"StarkBank.DarfPayment.Log.html#get/2-return"},{"type":"function","title":"StarkBank.DarfPayment.Log.get!/2","doc":"Same as get(), but it will unwrap the error tuple and raise in case of errors.","ref":"StarkBank.DarfPayment.Log.html#get!/2"},{"type":"function","title":"StarkBank.DarfPayment.Log.page/1","doc":"Receive a list of up to 100 DarfPayment structs previously created in the Stark Bank API and the cursor to the next page.\nUse this function instead of query if you want to manually page your requests.","ref":"StarkBank.DarfPayment.Log.html#page/1"},{"type":"function","title":"Options: - StarkBank.DarfPayment.Log.page/1","doc":"- `:cursor` [string, default nil]: cursor returned on the previous page function call\n  - `:limit` [integer, default nil]: maximum number of entities to be retrieved. Unlimited if nil. ex: 35\n  - `:after` [Date or string, default nil]: date filter for entities created only after specified date. ex: ~D[2020-03-25]\n  - `:before` [Date or string, default nil]: date filter for entities created only before specified date. ex: ~D[2020-03-25]\n  - `:types` [list of strings, default null]: filter retrieved structs by event types. ex: 'paid' or 'registered'\n  - `:payment_ids` [list of strings, default null]: list of DarfPayment ids to filter retrieved structs. ex: ['5656565656565656', '4545454545454545']\n  - `:user` [Organization/Project, default nil]: Organization or Project struct returned from StarkBank.project(). Only necessary if default project or organization has not been set in configs.","ref":"StarkBank.DarfPayment.Log.html#page/1-options"},{"type":"function","title":"Return: - StarkBank.DarfPayment.Log.page/1","doc":"- list of DarfPayment Log structs with updated attributes and cursor to retrieve the next page of DarfPayment structs","ref":"StarkBank.DarfPayment.Log.html#page/1-return"},{"type":"function","title":"StarkBank.DarfPayment.Log.page!/1","doc":"Same as page(), but it will unwrap the error tuple and raise in case of errors.","ref":"StarkBank.DarfPayment.Log.html#page!/1"},{"type":"function","title":"StarkBank.DarfPayment.Log.query/1","doc":"Receive a stream of DarfPayment Log structs previously created in the Stark Bank API","ref":"StarkBank.DarfPayment.Log.html#query/1"},{"type":"function","title":"Options: - StarkBank.DarfPayment.Log.query/1","doc":"- `:limit` [integer, default nil]: maximum number of entities to be retrieved. Unlimited if nil. ex: 35\n  - `:after` [Date or string, default nil]: date filter for entities created only after specified date. ex: ~D[2020-03-25]\n  - `:before` [Date or string, default nil]: date filter for entities created only before specified date. ex: ~D[2020-03-25]\n  - `:types` [list of strings, default null]: filter retrieved structs by event types. ex: 'paid' or 'registered'\n  - `:payment_ids` [list of strings, default null]: list of DarfPayment ids to filter retrieved structs. ex: ['5656565656565656', '4545454545454545']\n  - `:user` [Organization/Project, default nil]: Organization or Project struct returned from StarkBank.project(). Only necessary if default project or organization has not been set in configs.","ref":"StarkBank.DarfPayment.Log.html#query/1-options"},{"type":"function","title":"Return: - StarkBank.DarfPayment.Log.query/1","doc":"- stream of DarfPayment Log structs with updated attributes","ref":"StarkBank.DarfPayment.Log.html#query/1-return"},{"type":"function","title":"StarkBank.DarfPayment.Log.query!/1","doc":"Same as query(), but it will unwrap the error tuple and raise in case of errors.","ref":"StarkBank.DarfPayment.Log.html#query!/1"},{"type":"type","title":"StarkBank.DarfPayment.Log.t/0","doc":"","ref":"StarkBank.DarfPayment.Log.html#t:t/0"},{"type":"module","title":"StarkBank.Deposit","doc":"Groups Deposit related functions","ref":"StarkBank.Deposit.html"},{"type":"function","title":"StarkBank.Deposit.__struct__/0","doc":"Deposits represent passive cash-ins received by your account from external transfers and payments.\n\nAttributes (return-only):\n  - `:id` [string, default nil]: unique id associated with a Deposit when it is created. ex: \"5656565656565656\"\n  - `:name` [string]: payer name. ex: \"Iron Bank S.A.\"\n  - `:tax_id` [string]: payer tax ID (CPF or CNPJ). ex: \"012.345.678-90\" or \"20.018.183/0001-80\"\n  - `:bank_code` [string]: payer bank code in Brazil. ex: \"20018183\" or \"341\"\n  - `:branch_code` [string]: payer bank account branch. ex: \"1357-9\"\n  - `:account_number` [string]: payer bank account number. ex: \"876543-2\"\n  - `:account_type` [string]: payer bank account type. ex: \"checking\"\n  - `:amount` [integer]: Deposit value in cents. ex: 1234 (= R$ 12.34)\n  - `:type` [string]: Type of settlement that originated the deposit. ex: \"pix\" or \"ted\"\n  - `:status` [string, default nil]: current Deposit status. ex: \"paid\" or \"registered\"\n  - `:tags` [list of strings]: list of strings that are tagging the deposit. ex: [\"reconciliationId\", \"txId\"]\n  - `:fee` [integer, default nil]: fee charged by this deposit. ex: 50 (= R$ 0.50)\n  - `:transaction_ids` [list of strings, default nil]: ledger transaction ids linked to this deposit (if there are more than one, all but first are reversals). ex: [\"19827356981273\"]\n  - `:created` [DateTime, default nil]: creation datetime for the Deposit. ex: ~U[2020-03-26 19:32:35.418698Z]\n  - `:updated` [DateTime, default nil]:latest update datetime for the Deposit. ex: ~U[2020-08-20 19:32:35.418698Z]","ref":"StarkBank.Deposit.html#__struct__/0"},{"type":"function","title":"StarkBank.Deposit.get/2","doc":"Receive a single Deposit struct from the Stark Bank API by its id","ref":"StarkBank.Deposit.html#get/2"},{"type":"function","title":"Parameters (required): - StarkBank.Deposit.get/2","doc":"- `id` [string]: struct unique id. ex: \"5656565656565656\"","ref":"StarkBank.Deposit.html#get/2-parameters-required"},{"type":"function","title":"Options: - StarkBank.Deposit.get/2","doc":"- `:user` [Organization/Project, default nil]: Organization or Project struct returned from StarkBank.project(). Only necessary if default project or organization has not been set in configs.","ref":"StarkBank.Deposit.html#get/2-options"},{"type":"function","title":"Return: - StarkBank.Deposit.get/2","doc":"- Deposit struct with updated attributes","ref":"StarkBank.Deposit.html#get/2-return"},{"type":"function","title":"StarkBank.Deposit.get!/2","doc":"Same as get(), but it will unwrap the error tuple and raise in case of errors.","ref":"StarkBank.Deposit.html#get!/2"},{"type":"function","title":"StarkBank.Deposit.page/1","doc":"Receive a list of up to 100 Deposit objects previously created in the Stark Bank API and the cursor to the next page. \nUse this function instead of query if you want to manually page your requests.","ref":"StarkBank.Deposit.html#page/1"},{"type":"function","title":"Options: - StarkBank.Deposit.page/1","doc":"- `:cursor` [string, default nil]: cursor returned on the previous page function call\n  - `:limit` [integer, default nil]: maximum number of structs to be retrieved. Unlimited if nil. ex: 35\n  - `:after` [Date or string, default nil]: date filter for structs created only after specified date. ex: ~D[2020-03-25]\n  - `:before` [Date or string, default nil]: date filter for structs created only before specified date. ex: ~D[2020-03-25]\n  - `:status` [string, default nil]: filter for status of retrieved structs. ex: \"paid\" or \"registered\"\n  - `:sort` [string, default \"-created\"]: sort order considered in response. Valid options are \"created\", \"-created\", \"updated\" or \"-updated\".\n  - `:tags` [list of strings, default nil]: tags to filter retrieved structs. ex: [\"tony\", \"stark\"]\n  - `:ids` [list of strings, default nil]: list of ids to filter retrieved structs. ex: [\"5656565656565656\", \"4545454545454545\"]\n  - `:user` [Organization/Project, default nil]: Organization or Project struct returned from StarkBank.project(). Only necessary if default project or organization has not been set in configs.","ref":"StarkBank.Deposit.html#page/1-options"},{"type":"function","title":"Return: - StarkBank.Deposit.page/1","doc":"- list of Deposit structs with updated attributes and cursor to retrieve the next page of Deposit objects","ref":"StarkBank.Deposit.html#page/1-return"},{"type":"function","title":"StarkBank.Deposit.page!/1","doc":"Same as page(), but it will unwrap the error tuple and raise in case of errors.","ref":"StarkBank.Deposit.html#page!/1"},{"type":"function","title":"StarkBank.Deposit.query/1","doc":"Receive a generator of Deposit structs from the Stark Bank API","ref":"StarkBank.Deposit.html#query/1"},{"type":"function","title":"Options: - StarkBank.Deposit.query/1","doc":"- `:limit` [integer, default nil]: maximum number of structs to be retrieved. Unlimited if nil. ex: 35\n  - `:after` [Date or string, default nil]: date filter for structs created only after specified date. ex: ~D[2020-03-25]\n  - `:before` [Date or string, default nil]: date filter for structs created only before specified date. ex: ~D[2020-03-25]\n  - `:status` [string, default nil]: filter for status of retrieved structs. ex: \"paid\" or \"registered\"\n  - `:sort` [string, default \"-created\"]: sort order considered in response. Valid options are \"created\", \"-created\", \"updated\" or \"-updated\".\n  - `:tags` [list of strings, default nil]: tags to filter retrieved structs. ex: [\"tony\", \"stark\"]\n  - `:ids` [list of strings, default nil]: list of ids to filter retrieved structs. ex: [\"5656565656565656\", \"4545454545454545\"]\n  - `:user` [Organization/Project, default nil]: Organization or Project struct returned from StarkBank.project(). Only necessary if default project or organization has not been set in configs.","ref":"StarkBank.Deposit.html#query/1-options"},{"type":"function","title":"Return: - StarkBank.Deposit.query/1","doc":"- stream of Deposit structs with updated attributes","ref":"StarkBank.Deposit.html#query/1-return"},{"type":"function","title":"StarkBank.Deposit.query!/1","doc":"Same as query(), but it will unwrap the error tuple and raise in case of errors.","ref":"StarkBank.Deposit.html#query!/1"},{"type":"type","title":"StarkBank.Deposit.t/0","doc":"","ref":"StarkBank.Deposit.html#t:t/0"},{"type":"module","title":"StarkBank.Deposit.Log","doc":"Groups Deposit.Log related functions","ref":"StarkBank.Deposit.Log.html"},{"type":"function","title":"StarkBank.Deposit.Log.__struct__/0","doc":"Every time a Deposit entity is updated, a corresponding deposit.Log\n  is generated for the entity. This log is never generated by the\n  user, but it can be retrieved to check additional information","ref":"StarkBank.Deposit.Log.html#__struct__/0"},{"type":"function","title":"Attributes: - StarkBank.Deposit.Log.__struct__/0","doc":"- `:id` [string]: unique id returned when the log is created. ex: \"5656565656565656\"\n  - `:deposit` [Deposit]: Deposit entity to which the log refers to.\n  - `:errors` [list of strings]: list of errors linked to this Deposit event.\n  - `:type` [string]: type of the Deposit event which triggered the log creation. ex: \"created\" or \"credited\"\n  - `:created` [DateTime]: creation datetime for the log. ex: ~U[2020-03-26 19:32:35.418698Z]","ref":"StarkBank.Deposit.Log.html#__struct__/0-attributes"},{"type":"function","title":"StarkBank.Deposit.Log.get/2","doc":"Receive a single Log struct previously created by the Stark Bank API by passing its id","ref":"StarkBank.Deposit.Log.html#get/2"},{"type":"function","title":"Parameters (required): - StarkBank.Deposit.Log.get/2","doc":"- `id` [string]: struct unique id. ex: \"5656565656565656\"","ref":"StarkBank.Deposit.Log.html#get/2-parameters-required"},{"type":"function","title":"Options: - StarkBank.Deposit.Log.get/2","doc":"- `:user` [Organization/Project, default nil]: Organization or Project struct returned from StarkBank.project(). Only necessary if default project or organization has not been set in configs.","ref":"StarkBank.Deposit.Log.html#get/2-options"},{"type":"function","title":"Return: - StarkBank.Deposit.Log.get/2","doc":"- Log struct with updated attributes","ref":"StarkBank.Deposit.Log.html#get/2-return"},{"type":"function","title":"StarkBank.Deposit.Log.get!/2","doc":"Same as get(), but it will unwrap the error tuple and raise in case of errors.","ref":"StarkBank.Deposit.Log.html#get!/2"},{"type":"function","title":"StarkBank.Deposit.Log.page/1","doc":"Receive a list of up to 100 Deposit.Log objects previously created in the Stark Bank API and the cursor to the next page. \nUse this function instead of query if you want to manually page your requests.","ref":"StarkBank.Deposit.Log.html#page/1"},{"type":"function","title":"Options: - StarkBank.Deposit.Log.page/1","doc":"- `:cursor` [string, default nil]: cursor returned on the previous page function call\n  - `:limit` [integer, default nil]: maximum number of structs to be retrieved. Unlimited if nil. ex: 35\n  - `:after` [Date or string, default nil]: date filter for structs created only after specified date. ex: ~D[2020-03-25]\n  - `:before` [Date or string, default nil]: date filter for structs created only before specified date. ex: ~D[2020-03-25]\n  - `:types` [list of strings, default nil]: filter retrieved structs by types. ex: \"success\" or \"failed\"\n  - `:deposit_ids` [list of strings, default nil]: list of Deposit ids to filter retrieved structs. ex: [\"5656565656565656\", \"4545454545454545\"]\n  - `:user` [Organization/Project, default nil]: Organization or Project struct returned from StarkBank.project(). Only necessary if default project or organization has not been set in configs.","ref":"StarkBank.Deposit.Log.html#page/1-options"},{"type":"function","title":"Return: - StarkBank.Deposit.Log.page/1","doc":"- list of Deposit.Log structs with updated attributes and cursor to retrieve the next page of Deposit.Log objects","ref":"StarkBank.Deposit.Log.html#page/1-return"},{"type":"function","title":"StarkBank.Deposit.Log.page!/1","doc":"Same as page(), but it will unwrap the error tuple and raise in case of errors.","ref":"StarkBank.Deposit.Log.html#page!/1"},{"type":"function","title":"StarkBank.Deposit.Log.query/1","doc":"Receive a stream of Log structs previously created in the Stark Bank API","ref":"StarkBank.Deposit.Log.html#query/1"},{"type":"function","title":"Options: - StarkBank.Deposit.Log.query/1","doc":"- `:limit` [integer, default nil]: maximum number of structs to be retrieved. Unlimited if nil. ex: 35\n  - `:after` [Date or string, default nil]: date filter for structs created only after specified date. ex: ~D[2020-03-25]\n  - `:before` [Date or string, default nil]: date filter for structs created only before specified date. ex: ~D[2020-03-25]\n  - `:types` [list of strings, default nil]: filter retrieved structs by types. ex: \"success\" or \"failed\"\n  - `:deposit_ids` [list of strings, default nil]: list of Deposit ids to filter retrieved structs. ex: [\"5656565656565656\", \"4545454545454545\"]\n  - `:user` [Organization/Project, default nil]: Organization or Project struct returned from StarkBank.project(). Only necessary if default project or organization has not been set in configs.","ref":"StarkBank.Deposit.Log.html#query/1-options"},{"type":"function","title":"Return: - StarkBank.Deposit.Log.query/1","doc":"- stream of Log structs with updated attributes","ref":"StarkBank.Deposit.Log.html#query/1-return"},{"type":"function","title":"StarkBank.Deposit.Log.query!/1","doc":"Same as query(), but it will unwrap the error tuple and raise in case of errors.","ref":"StarkBank.Deposit.Log.html#query!/1"},{"type":"type","title":"StarkBank.Deposit.Log.t/0","doc":"","ref":"StarkBank.Deposit.Log.html#t:t/0"},{"type":"module","title":"StarkBank.DictKey","doc":"Groups DictKey related functions","ref":"StarkBank.DictKey.html"},{"type":"function","title":"StarkBank.DictKey.__struct__/0","doc":"DictKey represents a PIX key registered in Bacen's DICT system.","ref":"StarkBank.DictKey.html#__struct__/0"},{"type":"function","title":"Parameters (optional): - StarkBank.DictKey.__struct__/0","doc":"- `:id` [string]: DictKey object unique id and PIX key itself. ex: \"tony@starkbank.com\", \"722.461.430-04\", \"20.018.183/0001-80\", \"+5511988887777\", \"b6295ee1-f054-47d1-9e90-ee57b74f60d9\"","ref":"StarkBank.DictKey.html#__struct__/0-parameters-optional"},{"type":"function","title":"Attributes (return-only): - StarkBank.DictKey.__struct__/0","doc":"- `:type` [string, default nil]: DICT key type. ex: \"email\", \"cpf\", \"cnpj\", \"phone\" or \"evp\"\n  - `:name` [string, default nil]: key owner full name. ex: \"Tony Stark\"\n  - `:tax_id` [string, default nil]: key owner tax ID (CNPJ or masked CPF). ex: \"***.345.678-**\" or \"20.018.183/0001-80\"\n  - `:owner_type` [string, default nil]: DICT key owner type. ex \"naturalPerson\" or \"legalPerson\"\n  - `:bank_name` [string, default nil]: bank name associated with the DICT key. ex: \"Stark Bank\"\n  - `:ispb` [string, default nil]: bank ISPB associated with the DICT key. ex: \"20018183\"\n  - `:branch_code` [string, default nil]: bank account branch code associated with the DICT key. ex: \"9585\"\n  - `:account_number` [string, default nil]: bank account number associated with the DICT key. ex: \"9828282578010513\"\n  - `:account_type` [string, default nil]: bank account type associated with the DICT key. ex: \"checking\", \"saving\", \"salary\" or \"payment\"\n  - `:status` [string, default nil]: current DICT key status. ex: \"created\", \"registered\", \"canceled\" or \"failed\"\n  - `:account_created` [datetime.datetime, default nil]: creation datetime of the bank account associated with the DICT key. ex: datetime.date(2020, 1, 12, 11, 14, 8)\n  - `:owned` [DateTime, default nil]: datetime since when the current owner hold this DICT key. ex: ~U[2020-11-26 17:31:45.482618Z]\n  - `:created` [DateTime, default nil]: creation datetime for the DICT key. ex: ~U[2020-11-26 17:31:45.482618Z]","ref":"StarkBank.DictKey.html#__struct__/0-attributes-return-only"},{"type":"function","title":"StarkBank.DictKey.get/2","doc":"Receive a single DictKey struct by passing its id","ref":"StarkBank.DictKey.html#get/2"},{"type":"function","title":"Parameters (required): - StarkBank.DictKey.get/2","doc":"- `:id` [string]: DictKey object unique id and PIX key itself. ex: \"tony@starkbank.com\", \"722.461.430-04\", \"20.018.183/0001-80\", \"+5511988887777\", \"b6295ee1-f054-47d1-9e90-ee57b74f60d9\"","ref":"StarkBank.DictKey.html#get/2-parameters-required"},{"type":"function","title":"Options: - StarkBank.DictKey.get/2","doc":"- `:user` [Organization/Project, default nil]: Organization or Project struct returned from StarkBank.project(). Only necessary if default project or organization has not been set in configs.","ref":"StarkBank.DictKey.html#get/2-options"},{"type":"function","title":"Return: - StarkBank.DictKey.get/2","doc":"- DictKey struct with updated attributes","ref":"StarkBank.DictKey.html#get/2-return"},{"type":"function","title":"StarkBank.DictKey.get!/2","doc":"Same as get(), but it will unwrap the error tuple and raise in case of errors.","ref":"StarkBank.DictKey.html#get!/2"},{"type":"function","title":"StarkBank.DictKey.page/1","doc":"Receive a list of up to 100 DictKey objects previously created in the Stark Bank API and the cursor to the next page. \nUse this function instead of query if you want to manually page your requests.","ref":"StarkBank.DictKey.html#page/1"},{"type":"function","title":"Options: - StarkBank.DictKey.page/1","doc":"- `:cursor` [string, default nil]: cursor returned on the previous page function call\n  - `:limit` [integer, default nil]: maximum number of structs to be retrieved. Unlimited if nil. ex: 35\n  - `:type` [string, default nil]: DictKey type. ex: \"cpf\", \"cnpj\", \"phone\", \"email\" or \"evp\"\n  - `:after` [Date or string, default nil]: date filter for structs created only after specified date. ex: ~D[2020-03-25]\n  - `:before` [Date or string, default nil]: date filter for structs created only before specified date. ex: ~D[2020-03-25]\n  - `:ids` [list of strings, default nil]: list of ids to filter retrieved objects. ex: [\"5656565656565656\", \"4545454545454545\"]\n  - `:status` [string, default nil]: filter for status of retrieved structs. ex: \"registered\"\n  - `:user` [Organization/Project, default nil]: Organization or Project struct returned from StarkBank.project(). Only necessary if default project or organization has not been set in configs.","ref":"StarkBank.DictKey.html#page/1-options"},{"type":"function","title":"Return: - StarkBank.DictKey.page/1","doc":"- list of DictKey structs with updated attributes and cursor to retrieve the next page of DictKey objects","ref":"StarkBank.DictKey.html#page/1-return"},{"type":"function","title":"StarkBank.DictKey.page!/1","doc":"Same as page(), but it will unwrap the error tuple and raise in case of errors.","ref":"StarkBank.DictKey.html#page!/1"},{"type":"function","title":"StarkBank.DictKey.query/1","doc":"Receive a stream of DictKey structs associated with your Stark Bank Workspace","ref":"StarkBank.DictKey.html#query/1"},{"type":"function","title":"Options: - StarkBank.DictKey.query/1","doc":"- `:limit` [integer, default nil]: maximum number of structs to be retrieved. Unlimited if nil. ex: 35\n  - `:type` [string, default nil]: DictKey type. ex: \"cpf\", \"cnpj\", \"phone\", \"email\" or \"evp\"\n  - `:after` [Date or string, default nil]: date filter for structs created only after specified date. ex: ~D[2020-03-25]\n  - `:before` [Date or string, default nil]: date filter for structs created only before specified date. ex: ~D[2020-03-25]\n  - `:ids` [list of strings, default nil]: list of ids to filter retrieved objects. ex: [\"5656565656565656\", \"4545454545454545\"]\n  - `:status` [string, default nil]: filter for status of retrieved structs. ex: \"registered\"\n  - `:user` [Organization/Project, default nil]: Organization or Project struct returned from StarkBank.project(). Only necessary if default project or organization has not been set in configs.","ref":"StarkBank.DictKey.html#query/1-options"},{"type":"function","title":"Return: - StarkBank.DictKey.query/1","doc":"- stream of DictKey structs with updated attributes","ref":"StarkBank.DictKey.html#query/1-return"},{"type":"function","title":"StarkBank.DictKey.query!/1","doc":"Same as query(), but it will unwrap the error tuple and raise in case of errors.","ref":"StarkBank.DictKey.html#query!/1"},{"type":"type","title":"StarkBank.DictKey.t/0","doc":"","ref":"StarkBank.DictKey.html#t:t/0"},{"type":"module","title":"StarkBank.Error","doc":"","ref":"StarkBank.Error.html"},{"type":"function","title":"StarkBank.Error.__struct__/0","doc":"Error generated on interactions with the API\n\nIf the error code is:\n  - \"internalServerError\": the API has run into an internal error. If you ever stumble upon this one, rest assured that the development team is already rushing in to fix the mistake and get you back up to speed.\n  - \"unknownException\": a request encounters an error that has not been sent by the API, such as connectivity problems.\n  - any other binary: the API has detected a mistake in your request","ref":"StarkBank.Error.html#__struct__/0"},{"type":"function","title":"Attributes: - StarkBank.Error.__struct__/0","doc":"- `code` [string]: defines de error code. ex: \"invalidCredentials\"\n  - `message` [string]: explains the detected error. ex: \"Provided digital signature in the header Access-Signature does not check out. See https://docs.api.starkbank.com/#auth for details.\"","ref":"StarkBank.Error.html#__struct__/0-attributes"},{"type":"module","title":"StarkBank.Event","doc":"Groups Webhook-Event related functions","ref":"StarkBank.Event.html"},{"type":"function","title":"StarkBank.Event.__struct__/0","doc":"An Event is the notification received from the subscription to the Webhook.\nEvents cannot be created, but may be retrieved from the Stark Bank API to\nlist all generated updates on entities.","ref":"StarkBank.Event.html#__struct__/0"},{"type":"function","title":"Attributes: - StarkBank.Event.__struct__/0","doc":"- `:id` [string]: unique id returned when the event is created. ex: \"5656565656565656\"\n  - `:log` [Log]: a Log struct from one the subscription services (Transfer.Log, Boleto.Log, BoletoPayment.log, UtilityPayment.Log or TaxPayment.Log)\n  - `:created` [DateTime]: creation datetime for the notification event. ex: ~U[2020-03-26 19:32:35.418698Z]\n  - `:is_delivered` [bool]: true if the event has been successfully delivered to the user url. ex: false\n  - `:subscription` [string]: service that triggered this event. ex: \"transfer\", \"utility-payment\"\n  - `workspace_id` [string]: ID of the Workspace that generated this event. Mostly used when multiple Workspaces have Webhooks registered to the same endpoint. ex: \"4545454545454545\"","ref":"StarkBank.Event.html#__struct__/0-attributes"},{"type":"function","title":"StarkBank.Event.delete/2","doc":"Delete a list of notification Event entities previously created in the Stark Bank API","ref":"StarkBank.Event.html#delete/2"},{"type":"function","title":"Parameters (required): - StarkBank.Event.delete/2","doc":"- `id` [string]: Event unique id. ex: \"5656565656565656\"","ref":"StarkBank.Event.html#delete/2-parameters-required"},{"type":"function","title":"Options: - StarkBank.Event.delete/2","doc":"- `:user` [Organization/Project, default nil]: Organization or Project struct returned from StarkBank.project(). Only necessary if default project or organization has not been set in configs.","ref":"StarkBank.Event.html#delete/2-options"},{"type":"function","title":"Return: - StarkBank.Event.delete/2","doc":"- deleted Event struct","ref":"StarkBank.Event.html#delete/2-return"},{"type":"function","title":"StarkBank.Event.delete!/2","doc":"Same as delete(), but it will unwrap the error tuple and raise in case of errors.","ref":"StarkBank.Event.html#delete!/2"},{"type":"function","title":"StarkBank.Event.get/2","doc":"Receive a single notification Event struct previously created in the Stark Bank API by passing its id","ref":"StarkBank.Event.html#get/2"},{"type":"function","title":"Parameters (required): - StarkBank.Event.get/2","doc":"- `id` [string]: struct unique id. ex: \"5656565656565656\"","ref":"StarkBank.Event.html#get/2-parameters-required"},{"type":"function","title":"Options: - StarkBank.Event.get/2","doc":"- `:user` [Organization/Project, default nil]: Organization or Project struct returned from StarkBank.project(). Only necessary if default project or organization has not been set in configs.","ref":"StarkBank.Event.html#get/2-options"},{"type":"function","title":"Return: - StarkBank.Event.get/2","doc":"- Event struct with updated attributes","ref":"StarkBank.Event.html#get/2-return"},{"type":"function","title":"StarkBank.Event.get!/2","doc":"Same as get(), but it will unwrap the error tuple and raise in case of errors.","ref":"StarkBank.Event.html#get!/2"},{"type":"function","title":"StarkBank.Event.page/1","doc":"Receive a list of up to 100 Event objects previously created in the Stark Bank API and the cursor to the next page. \nUse this function instead of query if you want to manually page your requests.","ref":"StarkBank.Event.html#page/1"},{"type":"function","title":"Options: - StarkBank.Event.page/1","doc":"- `:cursor` [string, default nil]: cursor returned on the previous page function call\n  - `:limit` [integer, default nil]: maximum number of structs to be retrieved. Unlimited if nil. ex: 35\n  - `:after` [Date or string, default nil]: date filter for structs created only after specified date. ex: ~D[2020-03-25]\n  - `:before` [Date or string, default nil]: date filter for structs created only before specified date. ex: ~D[2020-03-25]\n  - `:is_delivered` [bool, default nil]: filter successfully delivered events. ex: true or false\n  - `:user` [Organization/Project, default nil]: Organization or Project struct returned from StarkBank.project(). Only necessary if default project or organization has not been set in configs.","ref":"StarkBank.Event.html#page/1-options"},{"type":"function","title":"Return: - StarkBank.Event.page/1","doc":"- list of Event structs with updated attributes and cursor to retrieve the next page of Event objects","ref":"StarkBank.Event.html#page/1-return"},{"type":"function","title":"StarkBank.Event.page!/1","doc":"Same as page(), but it will unwrap the error tuple and raise in case of errors.","ref":"StarkBank.Event.html#page!/1"},{"type":"function","title":"StarkBank.Event.parse/1","doc":"Create a single Event struct received from event listening at subscribed user endpoint.\nIf the provided digital signature does not check out with the StarkBank public key, an \"invalidSignature\"\nerror will be returned.","ref":"StarkBank.Event.html#parse/1"},{"type":"function","title":"Parameters (required): - StarkBank.Event.parse/1","doc":"- `content` [string]: response content from request received at user endpoint (not parsed)\n  - `signature` [string]: base-64 digital signature received at response header \"Digital-Signature\"","ref":"StarkBank.Event.html#parse/1-parameters-required"},{"type":"function","title":"Parameters (optional): - StarkBank.Event.parse/1","doc":"- `cache_pid` [PID, default nil]: PID of the process that holds the public key cache, returned on previous parses. If not provided, a new cache process will be generated.\n  - `user` [Organization/Project, default nil]: Organization or Project struct returned from StarkBank.project(). Only necessary if default project or organization has not been set in configs.","ref":"StarkBank.Event.html#parse/1-parameters-optional"},{"type":"function","title":"Return: - StarkBank.Event.parse/1","doc":"- Event struct with updated attributes\n  - Cache PID that holds the Stark Bank public key in order to avoid unnecessary requests to the API on future parses","ref":"StarkBank.Event.html#parse/1-return"},{"type":"function","title":"StarkBank.Event.parse!/1","doc":"Same as parse(), but it will unwrap the error tuple and raise in case of errors.","ref":"StarkBank.Event.html#parse!/1"},{"type":"function","title":"StarkBank.Event.query/1","doc":"Receive a stream of notification Event structs previously created in the Stark Bank API","ref":"StarkBank.Event.html#query/1"},{"type":"function","title":"Options: - StarkBank.Event.query/1","doc":"- `:limit` [integer, default nil]: maximum number of structs to be retrieved. Unlimited if nil. ex: 35\n  - `:after` [Date or string, default nil]: date filter for structs created only after specified date. ex: ~D[2020-03-25]\n  - `:before` [Date or string, default nil]: date filter for structs created only before specified date. ex: ~D[2020-03-25]\n  - `:is_delivered` [bool, default nil]: filter successfully delivered events. ex: true or false\n  - `:user` [Organization/Project, default nil]: Organization or Project struct returned from StarkBank.project(). Only necessary if default project or organization has not been set in configs.","ref":"StarkBank.Event.html#query/1-options"},{"type":"function","title":"Return: - StarkBank.Event.query/1","doc":"- stream of Event structs with updated attributes","ref":"StarkBank.Event.html#query/1-return"},{"type":"function","title":"StarkBank.Event.query!/1","doc":"Same as query(), but it will unwrap the error tuple and raise in case of errors.","ref":"StarkBank.Event.html#query!/1"},{"type":"function","title":"StarkBank.Event.update/2","doc":"Update notification Event by passing id.\n  If is_delivered is true, the event will no longer be returned on queries with is_delivered=false.","ref":"StarkBank.Event.html#update/2"},{"type":"function","title":"Parameters (required): - StarkBank.Event.update/2","doc":"- `id` [list of strings]: Event unique ids. ex: \"5656565656565656\"\n  - `:is_delivered` [bool]: If true and event hasn't been delivered already, event will be set as delivered. ex: true","ref":"StarkBank.Event.html#update/2-parameters-required"},{"type":"function","title":"Parameters (optional): - StarkBank.Event.update/2","doc":"- `:user` [Organization/Project, default nil]: Organization or Project struct returned from StarkBank.project(). Only necessary if default project or organization has not been set in configs.","ref":"StarkBank.Event.html#update/2-parameters-optional"},{"type":"function","title":"Return: - StarkBank.Event.update/2","doc":"- target Event with updated attributes","ref":"StarkBank.Event.html#update/2-return"},{"type":"function","title":"StarkBank.Event.update!/2","doc":"Same as update(), but it will unwrap the error tuple and raise in case of errors.","ref":"StarkBank.Event.html#update!/2"},{"type":"type","title":"StarkBank.Event.t/0","doc":"","ref":"StarkBank.Event.html#t:t/0"},{"type":"module","title":"StarkBank.Event.Attempt","doc":"Groups Event.Attempt related functions","ref":"StarkBank.Event.Attempt.html"},{"type":"function","title":"StarkBank.Event.Attempt.__struct__/0","doc":"When an Event delivery fails, an event attempt will be registered.\nIt carries information meant to help you debug event reception issues.","ref":"StarkBank.Event.Attempt.html#__struct__/0"},{"type":"function","title":"Attributes: - StarkBank.Event.Attempt.__struct__/0","doc":"- `:id` [string]: unique id that identifies the delivery attempt. ex: \"5656565656565656\"\n  - `:code` [string]: delivery error code. ex: badHttpStatus, badConnection, timeout\n  - `:message` [string]: delivery error full description. ex: \"HTTP POST request returned status 404\"\n  - `:event_id` [string]: ID of the Event whose delivery failed. ex: \"4848484848484848\"\n  - `:webhook_id` [string]: ID of the Webhook that triggered this event. ex: \"5656565656565656\"\n  - `:created` [DateTime]: datetime representing the moment when the attempt was made. ex: ~U[2020-03-26 19:32:35.418698Z]","ref":"StarkBank.Event.Attempt.html#__struct__/0-attributes"},{"type":"function","title":"StarkBank.Event.Attempt.get/2","doc":"Receive a single Event.Attempt object previously created by the Stark Bank API by its id","ref":"StarkBank.Event.Attempt.html#get/2"},{"type":"function","title":"Parameters (required): - StarkBank.Event.Attempt.get/2","doc":"- `:id` [string]: struct unique id. ex: \"5656565656565656\"","ref":"StarkBank.Event.Attempt.html#get/2-parameters-required"},{"type":"function","title":"Options: - StarkBank.Event.Attempt.get/2","doc":"- `:user` [Organization/Project, default nil]: Organization or Project struct returned from StarkBank.project(). Only necessary if default project or organization has not been set in configs.","ref":"StarkBank.Event.Attempt.html#get/2-options"},{"type":"function","title":"Return: - StarkBank.Event.Attempt.get/2","doc":"- Event.Attempt struct with updated attributes","ref":"StarkBank.Event.Attempt.html#get/2-return"},{"type":"function","title":"StarkBank.Event.Attempt.get!/2","doc":"Same as get(), but it will unwrap the error tuple and raise in case of errors.","ref":"StarkBank.Event.Attempt.html#get!/2"},{"type":"function","title":"StarkBank.Event.Attempt.page/1","doc":"Receive a list of up to 100 Attempt objects previously created in the Stark Bank API and the cursor to the next page. \nUse this function instead of query if you want to manually page your requests.","ref":"StarkBank.Event.Attempt.html#page/1"},{"type":"function","title":"Options: - StarkBank.Event.Attempt.page/1","doc":"- `:cursor` [string, default nil]: cursor returned on the previous page function call\n  - `:limit` [integer, default nil]: maximum number of structs to be retrieved. Unlimited if nil. ex: 35\n  - `:after` [Date or string, default nil]: date filter for structs created only after specified date. ex: ~D[2020-03-25]\n  - `:before` [Date or string, default nil]: date filter for structs created only before specified date. ex: ~D[2020-03-25]\n  - `:event_ids` [list of strings, default nil]: list of Event ids to filter attempts. ex: [\"5656565656565656\", \"4545454545454545\"]\n  - `:webhook_ids` [list of strings, default nil]: list of Webhook ids to filter attempts. ex: [\"5656565656565656\", \"4545454545454545\"]\n  - `:user` [Organization/Project, default nil]: Organization or Project struct returned from StarkBank.project(). Only necessary if default project or organization has not been set in configs.","ref":"StarkBank.Event.Attempt.html#page/1-options"},{"type":"function","title":"Return: - StarkBank.Event.Attempt.page/1","doc":"- list of Attempt structs with updated attributes and cursor to retrieve the next page of Attempt objects","ref":"StarkBank.Event.Attempt.html#page/1-return"},{"type":"function","title":"StarkBank.Event.Attempt.page!/1","doc":"Same as page(), but it will unwrap the error tuple and raise in case of errors.","ref":"StarkBank.Event.Attempt.html#page!/1"},{"type":"function","title":"StarkBank.Event.Attempt.query/1","doc":"Receive a stream of Event.Attempt structs previously created in the Stark Bank API","ref":"StarkBank.Event.Attempt.html#query/1"},{"type":"function","title":"Options: - StarkBank.Event.Attempt.query/1","doc":"- `:limit` [integer, default nil]: maximum number of structs to be retrieved. Unlimited if nil. ex: 35\n  - `:after` [Date or string, default nil]: date filter for structs created only after specified date. ex: ~D[2020-03-25]\n  - `:before` [Date or string, default nil]: date filter for structs created only before specified date. ex: ~D[2020-03-25]\n  - `:event_ids` [list of strings, default nil]: list of Event ids to filter attempts. ex: [\"5656565656565656\", \"4545454545454545\"]\n  - `:webhook_ids` [list of strings, default nil]: list of Webhook ids to filter attempts. ex: [\"5656565656565656\", \"4545454545454545\"]\n  - `:user` [Organization/Project, default nil]: Organization or Project struct returned from StarkBank.project(). Only necessary if default project or organization has not been set in configs.","ref":"StarkBank.Event.Attempt.html#query/1-options"},{"type":"function","title":"Return: - StarkBank.Event.Attempt.query/1","doc":"- stream of Event.Attempt structs with updated attributes","ref":"StarkBank.Event.Attempt.html#query/1-return"},{"type":"function","title":"StarkBank.Event.Attempt.query!/1","doc":"Same as query(), but it will unwrap the error tuple and raise in case of errors.","ref":"StarkBank.Event.Attempt.html#query!/1"},{"type":"type","title":"StarkBank.Event.Attempt.t/0","doc":"","ref":"StarkBank.Event.Attempt.html#t:t/0"},{"type":"module","title":"StarkBank.Institution","doc":"Groups Institution related functions","ref":"StarkBank.Institution.html"},{"type":"function","title":"StarkBank.Institution.__struct__/0","doc":"This resource is used to get information on the institutions that are recognized by the Brazilian Central Bank.\nBesides the display name and full name, they also include the STR code (used for TEDs) and the SPI Code\n(used for Pix) for the institutions. Either of these codes may be empty if the institution is not registered on\nthat Central Bank service.","ref":"StarkBank.Institution.html#__struct__/0"},{"type":"function","title":"Attributes: - StarkBank.Institution.__struct__/0","doc":"- `:display_name` [string]: short version of the institution name that should be displayed to end users. ex: \"Stark Bank\"\n  - `:name` [string]: full version of the institution name. ex: \"Stark Bank S.A.\"\n  - `:spi_code` [string]: SPI code used to identify the institution on Pix transactions. ex: \"20018183\"\n  - `:str_code` [string]: STR code used to identify the institution on TED transactions. ex: \"123\"","ref":"StarkBank.Institution.html#__struct__/0-attributes"},{"type":"function","title":"StarkBank.Institution.query/1","doc":"Receive a list of Institution objects that are recognized by the Brazilian Central bank for Pix and TED transactions","ref":"StarkBank.Institution.html#query/1"},{"type":"function","title":"Options: - StarkBank.Institution.query/1","doc":"- `:limit` [integer, default nil]: maximum number of objects to be retrieved. Unlimited if nil. ex: 35\n  - `:search` [string, default nil]: part of the institution name to be searched. ex: \"stark\"\n  - `:spi_codes` [list of strings, default nil]: list of SPI (Pix) codes to be searched. ex: [\"20018183\"]\n  - `:str_codes` [list of strings, default nil]: list of STR (TED) codes to be searched. ex: [\"260\"]\n  - `:user` [Organization/Project, default nil]: Organization or Project struct returned from StarkBank.project(). Only necessary if default project or organization has not been set in configs.","ref":"StarkBank.Institution.html#query/1-options"},{"type":"function","title":"Return: - StarkBank.Institution.query/1","doc":"- list of Institution objects with updated attributes","ref":"StarkBank.Institution.html#query/1-return"},{"type":"function","title":"StarkBank.Institution.query!/1","doc":"Same as query(), but it will unwrap the error tuple and raise in case of errors.","ref":"StarkBank.Institution.html#query!/1"},{"type":"type","title":"StarkBank.Institution.t/0","doc":"","ref":"StarkBank.Institution.html#t:t/0"},{"type":"module","title":"StarkBank.Invoice","doc":"Groups Invoice related functions","ref":"StarkBank.Invoice.html"},{"type":"function","title":"StarkBank.Invoice.__struct__/0","doc":"When you initialize a Invoice struct, the entity will not be automatically\nsent to the Stark Bank API. The 'create' function sends the structs\nto the Stark Bank API and returns the list of created structs.\nTo create scheduled Invoices, which will display the discount, interest, etc. on the final users banking interface,\nuse dates instead of datetimes on the \"due\" and \"discounts\" fields.","ref":"StarkBank.Invoice.html#__struct__/0"},{"type":"function","title":"Parameters (required): - StarkBank.Invoice.__struct__/0","doc":"- `:amount` [integer]: Invoice value in cents. Minimum = 0 (any value will be accepted). ex: 1234 (= R$ 12.34)\n  - `:tax_id` [string]: payer tax ID (CPF or CNPJ) with or without formatting. ex: \"01234567890\" or \"20.018.183/0001-80\"\n  - `:name` [string]: payer name. ex: \"Iron Bank S.A.\"","ref":"StarkBank.Invoice.html#__struct__/0-parameters-required"},{"type":"function","title":"Parameters (optional): - StarkBank.Invoice.__struct__/0","doc":"- `:due` [DateTime, Date or string, default now + 2 days]: Invoice due date in UTC ISO format. ex: ~U[2021-03-26 19:32:35.418698Z] for immediate invoices and ~D[2020-10-28] for scheduled invoices\n  - `:expiration` [integer, default 59 days]: time interval in seconds between due date and expiration date. ex 123456789\n  - `:fine` [float, default 0.0]: Invoice fine for overdue payment in %. ex: 2.5\n  - `:interest` [float, default 0.0]: Invoice monthly interest for overdue payment in %. ex: 5.2\n  - `:discounts` [list of dictionaries, default nil]: list of dictionaries with \"percentage\":float and \"due\":string pairs\n  - `:tags` [list of strings, default nil]: list of strings for tagging\n  - `:descriptions` [list of dictionaries, default nil]: list of dictionaries with \"key\":string and (optional) \"value\":string pairs","ref":"StarkBank.Invoice.html#__struct__/0-parameters-optional"},{"type":"function","title":"Attributes (return-only): - StarkBank.Invoice.__struct__/0","doc":"- `:pdf` [string, default nil]: public Invoice PDF URL. ex: \"https://invoice.starkbank.com/pdf/d454fa4e524441c1b0c1a729457ed9d8\"\n  - `:link` [string, default nil]: public Invoice webpage URL. ex: \"https://my-workspace.sandbox.starkbank.com/invoicelink/d454fa4e524441c1b0c1a729457ed9d8\"\n  - `:nominal_amount` [integer, default nil]: Invoice emission value in cents (will change if invoice is updated, but not if it's paid). ex: 400000\n  - `:fine_amount` [integer, default nil]: Invoice fine value calculated over nominal_amount. ex: 20000\n  - `:interest_amount` [integer, default nil]: Invoice interest value calculated over nominal_amount. ex: 10000\n  - `:discount_amount` [integer, default nil]: Invoice discount value calculated over nominal_amount. ex: 3000\n  - `:id` [string, default nil]: unique id returned when Invoice is created. ex: \"5656565656565656\"\n  - `:brcode` [string, default nil]: BR Code for the Invoice payment. ex: \"00020101021226800014br.gov.bcb.pix2558invoice.starkbank.com/f5333103-3279-4db2-8389-5efe335ba93d5204000053039865802BR5913Arya Stark6009Sao Paulo6220051656565656565656566304A9A0\"\n  - `:status` [string, default nil]: current Invoice status. ex: \"created\", \"paid\", \"canceled\" or \"overdue\"\n  - `:fee` [integer, default nil]: fee charged by this Invoice. ex: 65 (= R$ 0.65)\n  - `:transaction_ids` [list of strings, default nil]: ledger transaction ids linked to this boleto. ex: [\"19827356981273\"]\n  - `:created` [DateTime, default nil]: creation datetime for the Invoice. ex: ~U[2020-03-26 19:32:35.418698Z]\n  - `:updated` [DateTime, default nil]: latest update datetime for the Invoice. ex: ~U[2020-11-26 17:31:45.482618Z]","ref":"StarkBank.Invoice.html#__struct__/0-attributes-return-only"},{"type":"function","title":"StarkBank.Invoice.create/2","doc":"Send a list of Invoice structs for creation in the Stark Bank API","ref":"StarkBank.Invoice.html#create/2"},{"type":"function","title":"Parameters (required): - StarkBank.Invoice.create/2","doc":"- `invoices` [list of Invoice structs]: list of Invoice structs to be created in the API","ref":"StarkBank.Invoice.html#create/2-parameters-required"},{"type":"function","title":"Options: - StarkBank.Invoice.create/2","doc":"- `:user` [Organization/Project, default nil]: Organization or Project struct returned from StarkBank.project(). Only necessary if default project or organization has not been set in configs.","ref":"StarkBank.Invoice.html#create/2-options"},{"type":"function","title":"Return: - StarkBank.Invoice.create/2","doc":"- list of Invoice structs with updated attributes","ref":"StarkBank.Invoice.html#create/2-return"},{"type":"function","title":"StarkBank.Invoice.create!/2","doc":"Same as create(), but it will unwrap the error tuple and raise in case of errors.","ref":"StarkBank.Invoice.html#create!/2"},{"type":"function","title":"StarkBank.Invoice.get/2","doc":"Receive a single Invoice struct previously created in the Stark Bank API by passing its id","ref":"StarkBank.Invoice.html#get/2"},{"type":"function","title":"Parameters (required): - StarkBank.Invoice.get/2","doc":"- `id` [string]: struct unique id. ex: \"5656565656565656\"","ref":"StarkBank.Invoice.html#get/2-parameters-required"},{"type":"function","title":"Options: - StarkBank.Invoice.get/2","doc":"- `:user` [Organization/Project, default nil]: Organization or Project struct returned from StarkBank.project(). Only necessary if default project or organization has not been set in configs.","ref":"StarkBank.Invoice.html#get/2-options"},{"type":"function","title":"Return: - StarkBank.Invoice.get/2","doc":"- Invoice struct with updated attributes","ref":"StarkBank.Invoice.html#get/2-return"},{"type":"function","title":"StarkBank.Invoice.get!/2","doc":"Same as get(), but it will unwrap the error tuple and raise in case of errors.","ref":"StarkBank.Invoice.html#get!/2"},{"type":"function","title":"StarkBank.Invoice.page/1","doc":"Receive a list of up to 100 Invoice objects previously created in the Stark Bank API and the cursor to the next page. \nUse this function instead of query if you want to manually page your requests.","ref":"StarkBank.Invoice.html#page/1"},{"type":"function","title":"Options: - StarkBank.Invoice.page/1","doc":"- `:cursor` [string, default nil]: cursor returned on the previous page function call\n  - `:limit` [integer, default nil]: maximum number of structs to be retrieved. Unlimited if nil. ex: 35\n  - `:after` [Date or string, default nil]: date filter for structs created only after specified date. ex: ~D[2020-03-25]\n  - `:before` [Date or string, default nil]: date filter for structs created only before specified date. ex: ~D[2020-03-25]\n  - `:status` [string, default nil]: filter for status of retrieved structs. ex: \"created\", \"paid\", \"canceled\" or \"overdue\"\n  - `:tags` [list of strings, default nil]: tags to filter retrieved structs. ex: [\"tony\", \"stark\"]\n  - `:ids` [list of strings, default nil]: list of ids to filter retrieved structs. ex: [\"5656565656565656\", \"4545454545454545\"]\n  - `:user` [Organization/Project, default nil]: Organization or Project struct returned from StarkBank.project(). Only necessary if default project or organization has not been set in configs.","ref":"StarkBank.Invoice.html#page/1-options"},{"type":"function","title":"Return: - StarkBank.Invoice.page/1","doc":"- list of Invoice structs with updated attributes and cursor to retrieve the next page of Invoice objects","ref":"StarkBank.Invoice.html#page/1-return"},{"type":"function","title":"StarkBank.Invoice.page!/1","doc":"Same as page(), but it will unwrap the error tuple and raise in case of errors.","ref":"StarkBank.Invoice.html#page!/1"},{"type":"function","title":"StarkBank.Invoice.payment/2","doc":"Receive the Invoice.Payment sub-resource associated with a paid Invoice.","ref":"StarkBank.Invoice.html#payment/2"},{"type":"function","title":"Parameters (required): - StarkBank.Invoice.payment/2","doc":"- `:id` [string]: Invoice id. ex: '5656565656565656'","ref":"StarkBank.Invoice.html#payment/2-parameters-required"},{"type":"function","title":"Parameters (optional): - StarkBank.Invoice.payment/2","doc":"- `:user` [Organization/Project, default nil]: Organization or Project struct returned from StarkBank.project(). Only necessary if default project or organization has not been set in configs.","ref":"StarkBank.Invoice.html#payment/2-parameters-optional"},{"type":"function","title":"Return: - StarkBank.Invoice.payment/2","doc":"- Invoice.Payment sub-resource","ref":"StarkBank.Invoice.html#payment/2-return"},{"type":"function","title":"StarkBank.Invoice.payment!/2","doc":"Same as payment(), but it will unwrap the error tuple and raise in case of errors.","ref":"StarkBank.Invoice.html#payment!/2"},{"type":"function","title":"StarkBank.Invoice.pdf/2","doc":"Receive a single Invoice pdf file generated in the Stark Bank API by passing its id.","ref":"StarkBank.Invoice.html#pdf/2"},{"type":"function","title":"Parameters (required): - StarkBank.Invoice.pdf/2","doc":"- `id` [string]: struct unique id. ex: \"5656565656565656\"","ref":"StarkBank.Invoice.html#pdf/2-parameters-required"},{"type":"function","title":"Options: - StarkBank.Invoice.pdf/2","doc":"- `:user` [Organization/Project, default nil]: Organization or Project struct returned from StarkBank.project(). Only necessary if default project or organization has not been set in configs.","ref":"StarkBank.Invoice.html#pdf/2-options"},{"type":"function","title":"Return: - StarkBank.Invoice.pdf/2","doc":"- Invoice pdf file content","ref":"StarkBank.Invoice.html#pdf/2-return"},{"type":"function","title":"StarkBank.Invoice.pdf!/2","doc":"Same as pdf(), but it will unwrap the error tuple and raise in case of errors.","ref":"StarkBank.Invoice.html#pdf!/2"},{"type":"function","title":"StarkBank.Invoice.qrcode/2","doc":"Receive a single Invoice QR Code png file generated in the Stark Bank API by passing its id.","ref":"StarkBank.Invoice.html#qrcode/2"},{"type":"function","title":"Parameters (required): - StarkBank.Invoice.qrcode/2","doc":"- `id` [string]: struct unique id. ex: \"5656565656565656\"","ref":"StarkBank.Invoice.html#qrcode/2-parameters-required"},{"type":"function","title":"Options: - StarkBank.Invoice.qrcode/2","doc":"- `:user` [Organization/Project, default nil]: Organization or Project struct returned from StarkBank.project(). Only necessary if default project or organization has not been set in configs.","ref":"StarkBank.Invoice.html#qrcode/2-options"},{"type":"function","title":"Return: - StarkBank.Invoice.qrcode/2","doc":"- Invoice QR Code png file content","ref":"StarkBank.Invoice.html#qrcode/2-return"},{"type":"function","title":"StarkBank.Invoice.qrcode!/2","doc":"Same as qrcode(), but it will unwrap the error tuple and raise in case of errors.","ref":"StarkBank.Invoice.html#qrcode!/2"},{"type":"function","title":"StarkBank.Invoice.query/1","doc":"Receive a stream of Invoice structs previously created in the Stark Bank API","ref":"StarkBank.Invoice.html#query/1"},{"type":"function","title":"Options: - StarkBank.Invoice.query/1","doc":"- `:limit` [integer, default nil]: maximum number of structs to be retrieved. Unlimited if nil. ex: 35\n  - `:after` [Date or string, default nil]: date filter for structs created only after specified date. ex: ~D[2020-03-25]\n  - `:before` [Date or string, default nil]: date filter for structs created only before specified date. ex: ~D[2020-03-25]\n  - `:status` [string, default nil]: filter for status of retrieved structs. ex: \"created\", \"paid\", \"canceled\" or \"overdue\"\n  - `:tags` [list of strings, default nil]: tags to filter retrieved structs. ex: [\"tony\", \"stark\"]\n  - `:ids` [list of strings, default nil]: list of ids to filter retrieved structs. ex: [\"5656565656565656\", \"4545454545454545\"]\n  - `:user` [Organization/Project, default nil]: Organization or Project struct returned from StarkBank.project(). Only necessary if default project or organization has not been set in configs.","ref":"StarkBank.Invoice.html#query/1-options"},{"type":"function","title":"Return: - StarkBank.Invoice.query/1","doc":"- stream of Invoice structs with updated attributes","ref":"StarkBank.Invoice.html#query/1-return"},{"type":"function","title":"StarkBank.Invoice.query!/1","doc":"Same as query(), but it will unwrap the error tuple and raise in case of errors.","ref":"StarkBank.Invoice.html#query!/1"},{"type":"function","title":"StarkBank.Invoice.update/2","doc":"Update an Invoice by passing id, if it hasn't been paid yet.","ref":"StarkBank.Invoice.html#update/2"},{"type":"function","title":"Parameters (required): - StarkBank.Invoice.update/2","doc":"- `:id` [string]: Invoice id. ex: '5656565656565656'","ref":"StarkBank.Invoice.html#update/2-parameters-required"},{"type":"function","title":"Parameters (optional): - StarkBank.Invoice.update/2","doc":"- `:status` [string]: You may cancel the invoice by passing \"canceled\" in the status\n  - `:amount` [string]: Nominal amount charge by the invoice. ex: 100 (R$1.00)\n  - `:due` [DateTime or string]: Invoice due date in UTC ISO format. ex: ~U[2021-03-26 19:32:35.418698Z]\n  - `:expiration` [integer]: time interval in seconds between due date and expiration date. ex 123456789\n  - `:user` [Organization/Project, default nil]: Organization or Project struct returned from StarkBank.project(). Only necessary if default project or organization has not been set in configs.","ref":"StarkBank.Invoice.html#update/2-parameters-optional"},{"type":"function","title":"Return: - StarkBank.Invoice.update/2","doc":"- target Invoice with updated attributes","ref":"StarkBank.Invoice.html#update/2-return"},{"type":"function","title":"StarkBank.Invoice.update!/2","doc":"Same as update(), but it will unwrap the error tuple and raise in case of errors.","ref":"StarkBank.Invoice.html#update!/2"},{"type":"type","title":"StarkBank.Invoice.t/0","doc":"","ref":"StarkBank.Invoice.html#t:t/0"},{"type":"module","title":"StarkBank.Invoice.Log","doc":"Groups Invoice.Log related functions","ref":"StarkBank.Invoice.Log.html"},{"type":"function","title":"StarkBank.Invoice.Log.__struct__/0","doc":"Every time a Invoice entity is updated, a corresponding Invoice.Log\nis generated for the entity. This log is never generated by the\nuser, but it can be retrieved to check additional information\non the Invoice.","ref":"StarkBank.Invoice.Log.html#__struct__/0"},{"type":"function","title":"Attributes: - StarkBank.Invoice.Log.__struct__/0","doc":"- `:id` [string]: unique id returned when the log is created. ex: \"5656565656565656\"\n  - `:invoice` [Invoice]: Invoice entity to which the log refers to.\n  - `:errors` [list of strings]: list of errors linked to this Invoice event\n  - `:type` [string]: type of the Invoice event which triggered the log creation. ex: \"created\", \"paid\", \"canceled\" or \"overdue\"\n  - `:created` [DateTime]: creation datetime for the log. ex: ~U[2020-03-26 19:32:35.418698Z]","ref":"StarkBank.Invoice.Log.html#__struct__/0-attributes"},{"type":"function","title":"StarkBank.Invoice.Log.get/2","doc":"Receive a single Log struct previously created by the Stark Bank API by passing its id","ref":"StarkBank.Invoice.Log.html#get/2"},{"type":"function","title":"Parameters (required): - StarkBank.Invoice.Log.get/2","doc":"- `id` [string]: struct unique id. ex: \"5656565656565656\"","ref":"StarkBank.Invoice.Log.html#get/2-parameters-required"},{"type":"function","title":"Options: - StarkBank.Invoice.Log.get/2","doc":"- `:user` [Organization/Project, default nil]: Organization or Project struct returned from StarkBank.project(). Only necessary if default project or organization has not been set in configs.","ref":"StarkBank.Invoice.Log.html#get/2-options"},{"type":"function","title":"Return: - StarkBank.Invoice.Log.get/2","doc":"- Log struct with updated attributes","ref":"StarkBank.Invoice.Log.html#get/2-return"},{"type":"function","title":"StarkBank.Invoice.Log.get!/2","doc":"Same as get(), but it will unwrap the error tuple and raise in case of errors.","ref":"StarkBank.Invoice.Log.html#get!/2"},{"type":"function","title":"StarkBank.Invoice.Log.page/1","doc":"Receive a list of up to 100 Invoice.Log objects previously created in the Stark Bank API and the cursor to the next page. \nUse this function instead of query if you want to manually page your requests.","ref":"StarkBank.Invoice.Log.html#page/1"},{"type":"function","title":"Options: - StarkBank.Invoice.Log.page/1","doc":"- `:cursor` [string, default nil]: cursor returned on the previous page function call\n  - `:limit` [integer, default nil]: maximum number of structs to be retrieved. Unlimited if nil. ex: 35\n  - `:after` [Date or string, default nil]: date filter for structs created only after specified date. ex: ~D[2020-03-25]\n  - `:before` [Date or string, default nil]: date filter for structs created only before specified date. ex: ~D[2020-03-25]\n  - `:types` [list of strings, default nil]: filter for log event types. ex: \"created\", \"paid\", \"canceled\" or \"overdue\"\n  - `:invoice_ids` [list of strings, default nil]: list of Invoice ids to filter logs. ex: [\"5656565656565656\", \"4545454545454545\"]\n  - `:user` [Organization/Project, default nil]: Organization or Project struct returned from StarkBank.project(). Only necessary if default project or organization has not been set in configs.","ref":"StarkBank.Invoice.Log.html#page/1-options"},{"type":"function","title":"Return: - StarkBank.Invoice.Log.page/1","doc":"- list of Invoice.Log structs with updated attributes and cursor to retrieve the next page of Invoice.Log objects","ref":"StarkBank.Invoice.Log.html#page/1-return"},{"type":"function","title":"StarkBank.Invoice.Log.page!/1","doc":"Same as page(), but it will unwrap the error tuple and raise in case of errors.","ref":"StarkBank.Invoice.Log.html#page!/1"},{"type":"function","title":"StarkBank.Invoice.Log.pdf/2","doc":"Receive a single Invoice.Log pdf file generated in the Stark Bank API by passing its id.","ref":"StarkBank.Invoice.Log.html#pdf/2"},{"type":"function","title":"Parameters (required): - StarkBank.Invoice.Log.pdf/2","doc":"- `:id` [string]: struct unique id. ex: \"5656565656565656\"","ref":"StarkBank.Invoice.Log.html#pdf/2-parameters-required"},{"type":"function","title":"Options: - StarkBank.Invoice.Log.pdf/2","doc":"- `:user` [Organization/Project, default nil]: Organization or Project struct returned from StarkBank.project(). Only necessary if default project or organization has not been set in configs.","ref":"StarkBank.Invoice.Log.html#pdf/2-options"},{"type":"function","title":"Return: - StarkBank.Invoice.Log.pdf/2","doc":"- Invoice.Log pdf file content","ref":"StarkBank.Invoice.Log.html#pdf/2-return"},{"type":"function","title":"StarkBank.Invoice.Log.pdf!/2","doc":"Same as pdf(), but it will unwrap the error tuple and raise in case of errors.","ref":"StarkBank.Invoice.Log.html#pdf!/2"},{"type":"function","title":"StarkBank.Invoice.Log.query/1","doc":"Receive a stream of Log structs previously created in the Stark Bank API","ref":"StarkBank.Invoice.Log.html#query/1"},{"type":"function","title":"Options: - StarkBank.Invoice.Log.query/1","doc":"- `:limit` [integer, default nil]: maximum number of structs to be retrieved. Unlimited if nil. ex: 35\n  - `:after` [Date or string, default nil]: date filter for structs created only after specified date. ex: ~D[2020-03-25]\n  - `:before` [Date or string, default nil]: date filter for structs created only before specified date. ex: ~D[2020-03-25]\n  - `:types` [list of strings, default nil]: filter for log event types. ex: \"created\", \"paid\", \"canceled\" or \"overdue\"\n  - `:invoice_ids` [list of strings, default nil]: list of Invoice ids to filter logs. ex: [\"5656565656565656\", \"4545454545454545\"]\n  - `:user` [Organization/Project, default nil]: Organization or Project struct returned from StarkBank.project(). Only necessary if default project or organization has not been set in configs.","ref":"StarkBank.Invoice.Log.html#query/1-options"},{"type":"function","title":"Return: - StarkBank.Invoice.Log.query/1","doc":"- stream of Log structs with updated attributes","ref":"StarkBank.Invoice.Log.html#query/1-return"},{"type":"function","title":"StarkBank.Invoice.Log.query!/1","doc":"Same as query(), but it will unwrap the error tuple and raise in case of errors.","ref":"StarkBank.Invoice.Log.html#query!/1"},{"type":"type","title":"StarkBank.Invoice.Log.t/0","doc":"","ref":"StarkBank.Invoice.Log.html#t:t/0"},{"type":"module","title":"StarkBank.Invoice.Payment","doc":"Groups Invoice.Payment related functions","ref":"StarkBank.Invoice.Payment.html"},{"type":"function","title":"StarkBank.Invoice.Payment.__struct__/0","doc":"When an Invoice is paid, its Payment sub-resource will become available.\nIt carries all the available information about the invoice payment.","ref":"StarkBank.Invoice.Payment.html#__struct__/0"},{"type":"function","title":"Attributes: - StarkBank.Invoice.Payment.__struct__/0","doc":"- `:amount` [integer]: amount in cents that was paid. ex: 1234 (= R$ 12.34)\n  - `:name` [string]: payer full name. ex: \"Anthony Edward Stark\"\n  - `:tax_id` [string]: payer tax ID (CPF or CNPJ). ex: \"20.018.183/0001-80\"\n  - `:bank_code` [string]: code of the payer bank institution in Brazil. ex: \"20018183\"\n  - `:branch_code` [string]: payer bank account branch. ex: \"1357-9\"\n  - `:account_number` [string]: payer bank account number. ex: \"876543-2\"\n  - `:account_type` [string]: payer bank account type. ex: \"checking\", \"savings\", \"salary\" or \"payment\"\n  - `:end_to_end_id` [string]: central bank's unique transaction ID. ex: \"E79457883202101262140HHX553UPqeq\"\n  - `:method` [string]: payment method that was used. ex: \"pix\"","ref":"StarkBank.Invoice.Payment.html#__struct__/0-attributes"},{"type":"function","title":"StarkBank.Invoice.Payment.resource/0","doc":"","ref":"StarkBank.Invoice.Payment.html#resource/0"},{"type":"function","title":"StarkBank.Invoice.Payment.resource_maker/1","doc":"","ref":"StarkBank.Invoice.Payment.html#resource_maker/1"},{"type":"type","title":"StarkBank.Invoice.Payment.t/0","doc":"","ref":"StarkBank.Invoice.Payment.html#t:t/0"},{"type":"module","title":"StarkBank.Key","doc":"Used to generate API-compatible key pairs","ref":"StarkBank.Key.html"},{"type":"function","title":"StarkBank.Key.create/1","doc":"Generates a secp256k1 ECDSA private/public key pair to be used in the API authentications","ref":"StarkBank.Key.html#create/1"},{"type":"function","title":"Parameters (optional): - StarkBank.Key.create/1","doc":"- `path` [string, default nil]: path to save the keys .pem files. No files will be saved if this parameter isn't provided.","ref":"StarkBank.Key.html#create/1-parameters-optional"},{"type":"module","title":"StarkBank.PaymentPreview","doc":"Groups PaymentPreview related functions","ref":"StarkBank.PaymentPreview.html"},{"type":"function","title":"StarkBank.PaymentPreview.__struct__/0","doc":"A PaymentPreview is used to get information from a payment code before confirming the payment.\nThis resource can be used to preview BR Codes and bar codes of boleto, tax and utility payments","ref":"StarkBank.PaymentPreview.html#__struct__/0"},{"type":"function","title":"Parameters (required): - StarkBank.PaymentPreview.__struct__/0","doc":"- `:id` [string]: Main identification of the payment. This should be the BR Code for Pix payments and lines or bar codes for payment slips. ex: \"34191.09008 63571.277308 71444.640008 5 81960000000062\", \"00020126580014br.gov.bcb.pix0136a629532e-7693-4846-852d-1bbff817b5a8520400005303986540510.005802BR5908T'Challa6009Sao Paulo62090505123456304B14A\"","ref":"StarkBank.PaymentPreview.html#__struct__/0-parameters-required"},{"type":"function","title":"Parameters (optional): - StarkBank.PaymentPreview.__struct__/0","doc":"- `:scheduled` [Date or string]: intended payment date. Right now, this parameter only has effect on BrcodePreviews. ex: 2020-12-31","ref":"StarkBank.PaymentPreview.html#__struct__/0-parameters-optional"},{"type":"function","title":"Attributes (return-only): - StarkBank.PaymentPreview.__struct__/0","doc":"- `:type` [string]: Payment type. ex: \"brcode-payment\", \"boleto-payment\", \"utility-payment\" or \"tax-payment\"\n  - `:payment` [BrcodePreview, BoletoPreview, UtilityPreview or TaxPreview]: Information preview of the informed payment.","ref":"StarkBank.PaymentPreview.html#__struct__/0-attributes-return-only"},{"type":"function","title":"StarkBank.PaymentPreview.create/2","doc":"Send a list of PaymentPreviews objects for processing in the Stark Bank API","ref":"StarkBank.PaymentPreview.html#create/2"},{"type":"function","title":"Parameters (required): - StarkBank.PaymentPreview.create/2","doc":"- `:previews` [list of PaymentPreviews structs]: list of PaymentPreviews objects to be created in the API","ref":"StarkBank.PaymentPreview.html#create/2-parameters-required"},{"type":"function","title":"Options: - StarkBank.PaymentPreview.create/2","doc":"- `:user` [Organization/Project, default nil]: Organization or Project struct returned from StarkBank.project(). Only necessary if default project or organization has not been set in configs.","ref":"StarkBank.PaymentPreview.html#create/2-options"},{"type":"function","title":"Return: - StarkBank.PaymentPreview.create/2","doc":"- list of PaymentPreviews structs with updated attributes","ref":"StarkBank.PaymentPreview.html#create/2-return"},{"type":"function","title":"StarkBank.PaymentPreview.create!/2","doc":"Same as create(), but it will unwrap the error tuple and raise in case of errors.","ref":"StarkBank.PaymentPreview.html#create!/2"},{"type":"type","title":"StarkBank.PaymentPreview.t/0","doc":"","ref":"StarkBank.PaymentPreview.html#t:t/0"},{"type":"module","title":"StarkBank.PaymentPreview.BoletoPreview","doc":"Groups BoletoPreview related functions","ref":"StarkBank.PaymentPreview.BoletoPreview.html"},{"type":"function","title":"StarkBank.PaymentPreview.BoletoPreview.__struct__/0","doc":"A BoletoPreview is used to get information from a Boleto payment you received before confirming the payment.","ref":"StarkBank.PaymentPreview.BoletoPreview.html#__struct__/0"},{"type":"function","title":"Attributes (return-only): - StarkBank.PaymentPreview.BoletoPreview.__struct__/0","doc":"- `:status` [string]: current boleto status. ex: \"active\", \"expired\" or \"inactive\"\n  - `:amount` [int]: final amount to be paid. ex: 23456 (= R$ 234.56)\n  - `:discount_amount` [int]: discount amount to be paid. ex: 23456 (= R$ 234.56)\n  - `:fine_amount` [int]: fine amount to be paid. ex: 23456 (= R$ 234.56)\n  - `:interest_amount` [int]: interest amount to be paid. ex: 23456 (= R$ 234.56)\n  - `:due` [Date]: Boleto due date. ex: 2020-04-30\n  - `:expiration` [Date]: Boleto expiration date. ex: 2020-04-30\n  - `:name` [string]: beneficiary full name. ex: \"Anthony Edward Stark\"\n  - `:tax_id` [string]: beneficiary tax ID (CPF or CNPJ). ex: \"20.018.183/0001-80\"\n  - `:receiver_name` [string]: receiver (Sacador Avalista) full name. ex: \"Anthony Edward Stark\"\n  - `:receiver_tax_id` [string]: receiver (Sacador Avalista) tax ID (CPF or CNPJ). ex: \"20.018.183/0001-80\"\n  - `:payer_name` [string]: payer full name. ex: \"Anthony Edward Stark\"\n  - `:payer_tax_id` [string]: payer tax ID (CPF or CNPJ). ex: \"20.018.183/0001-80\"\n  - `:line` [string]: Number sequence that identifies the payment. ex: \"34191.09008 63571.277308 71444.640008 5 81960000000062\"\n  - `:bar_code` [string]: Bar code number that identifies the payment. ex: \"34195819600000000621090063571277307144464000\"","ref":"StarkBank.PaymentPreview.BoletoPreview.html#__struct__/0-attributes-return-only"},{"type":"type","title":"StarkBank.PaymentPreview.BoletoPreview.t/0","doc":"","ref":"StarkBank.PaymentPreview.BoletoPreview.html#t:t/0"},{"type":"module","title":"StarkBank.PaymentPreview.BrcodePreview","doc":"Groups BrcodePreview related functions","ref":"StarkBank.PaymentPreview.BrcodePreview.html"},{"type":"function","title":"StarkBank.PaymentPreview.BrcodePreview.__struct__/0","doc":"A BrcodePreview is used to get information from a BR Code you received before confirming the payment.","ref":"StarkBank.PaymentPreview.BrcodePreview.html#__struct__/0"},{"type":"function","title":"Attributes (return-only): - StarkBank.PaymentPreview.BrcodePreview.__struct__/0","doc":"- `:status` [string]: Payment status. ex: \"active\", \"paid\", \"canceled\" or \"unknown\"\n  - `:name` [string]: Payment receiver name. ex: \"Tony Stark\"\n  - `:tax_id` [string]: Payment receiver tax ID. ex: \"012.345.678-90\"\n  - `:bank_code` [string]: Payment receiver bank code. ex: \"20018183\"\n  - `:branch_code` [string]: Payment receiver branch code. ex: \"0001\"\n  - `:account_number` [string]: Payment receiver account number. ex: \"1234567\"\n  - `:account_type` [string]: Payment receiver account type. ex: \"checking\"\n  - `:allow_change` [bool]: If True, the payment is able to receive amounts that are different from the nominal one. ex: True or False\n  - `:amount` [integer]: Value in cents that this payment is expecting to receive. If 0, any value is accepted. ex: 123 (= R$1,23)\n  - `:nominal_amount` [integer]: Original value in cents that this payment was expecting to receive without the discounts, fines, etc.. If 0, any value is accepted. ex: 123 (= R$1,23)\n  - `:interest_amount` [integer]: Current interest value in cents that this payment is charging. If 0, any value is accepted. ex: 123 (= R$1,23)\n  - `:fine_amount` [integer]: Current fine value in cents that this payment is charging. ex: 123 (= R$1,23)\n  - `:reduction_amount` [integer]: Current value reduction value in cents that this payment is expecting. ex: 123 (= R$1,23)\n  - `:discount_amount` [integer]: Current discount value in cents that this payment is expecting. ex: 123 (= R$1,23)\n  - `:reconciliation_id` [string]: Reconciliation ID linked to this payment. ex: \"txId\", \"payment-123\"","ref":"StarkBank.PaymentPreview.BrcodePreview.html#__struct__/0-attributes-return-only"},{"type":"type","title":"StarkBank.PaymentPreview.BrcodePreview.t/0","doc":"","ref":"StarkBank.PaymentPreview.BrcodePreview.html#t:t/0"},{"type":"module","title":"StarkBank.PaymentPreview.TaxPreview","doc":"Groups TaxPreview related functions","ref":"StarkBank.PaymentPreview.TaxPreview.html"},{"type":"function","title":"StarkBank.PaymentPreview.TaxPreview.__struct__/0","doc":"A TaxPreview is used to get information from a Tax Payment you received before confirming the payment.","ref":"StarkBank.PaymentPreview.TaxPreview.html#__struct__/0"},{"type":"function","title":"Attributes (return-only): - StarkBank.PaymentPreview.TaxPreview.__struct__/0","doc":"- `:amount` [int]: final amount to be paid. ex: 23456 (= R$ 234.56)\n  - `:name` [string]: beneficiary full name. ex: \"Iron Throne\"\n  - `:description` [string]: tax payment description. ex: \"ISS Payment - Iron Throne\"\n  - `:line` [string]: Number sequence that identifies the payment. ex: \"85660000006 6 67940064007 5 41190025511 7 00010601813 8\"\n  - `:bar_code` [string]: Bar code number that identifies the payment. ex: \"85660000006679400640074119002551100010601813\"","ref":"StarkBank.PaymentPreview.TaxPreview.html#__struct__/0-attributes-return-only"},{"type":"type","title":"StarkBank.PaymentPreview.TaxPreview.t/0","doc":"","ref":"StarkBank.PaymentPreview.TaxPreview.html#t:t/0"},{"type":"module","title":"StarkBank.PaymentPreview.UtilityPreview","doc":"Groups UtilityPreview related functions","ref":"StarkBank.PaymentPreview.UtilityPreview.html"},{"type":"function","title":"StarkBank.PaymentPreview.UtilityPreview.__struct__/0","doc":"A UtilityPreview is used to get information from a BR Code\nyou received to check the informations before paying it.","ref":"StarkBank.PaymentPreview.UtilityPreview.html#__struct__/0"},{"type":"function","title":"Attributes (return-only): - StarkBank.PaymentPreview.UtilityPreview.__struct__/0","doc":"- `:amount` [int]: final amount to be paid. ex: 23456 (= R$ 234.56)\n  - `:name` [string]: beneficiary full name. ex: \"Light Company\"\n  - `:description` [string]: utility payment description. ex: \"Utility Payment - Light Company\"\n  - `:line` [string]: Number sequence that identifies the payment. ex: \"82660000002 8 44361143007 7 41190025511 7 00010601813 8\"\n  - `:bar_code` [string]: Bar code number that identifies the payment. ex: \"82660000002443611430074119002551100010601813\"","ref":"StarkBank.PaymentPreview.UtilityPreview.html#__struct__/0-attributes-return-only"},{"type":"type","title":"StarkBank.PaymentPreview.UtilityPreview.t/0","doc":"","ref":"StarkBank.PaymentPreview.UtilityPreview.html#t:t/0"},{"type":"module","title":"StarkBank.PaymentRequest","doc":"Groups PaymentRequest related functions","ref":"StarkBank.PaymentRequest.html"},{"type":"function","title":"StarkBank.PaymentRequest.__struct__/0","doc":"A PaymentRequest is an indirect request to access a specific cash-out service\n(such as Transfer, BrcodePayments, etc.) which goes through the cost center\napproval flow on our web banking. To emit a PaymentRequest, you must direct it to\na specific cost center by its ID, which can be retrieved on our web banking at the\ncost center page.","ref":"StarkBank.PaymentRequest.html#__struct__/0"},{"type":"function","title":"Parameters (required): - StarkBank.PaymentRequest.__struct__/0","doc":"- `:center_id` [string]: target cost center ID. ex: \"5656565656565656\"\n- `:payment` [Transfer, BrcodePayments, BoletoPayment, UtilityPayment, TaxPayment, DarfPayment, Transaction or map]: payment entity that should be approved and executed.","ref":"StarkBank.PaymentRequest.html#__struct__/0-parameters-required"},{"type":"function","title":"Parameters (conditionally required): - StarkBank.PaymentRequest.__struct__/0","doc":"- `:type` [string]: payment type, inferred from the payment parameter if it is not a map. ex: \"transfer\", \"boleto-payment\"","ref":"StarkBank.PaymentRequest.html#__struct__/0-parameters-conditionally-required"},{"type":"function","title":"Parameters (optional): - StarkBank.PaymentRequest.__struct__/0","doc":"- `:due` [Date or string]: Payment target date in ISO format. ex: 2020-12-31\n- `:tags` [list of strings]: list of strings for tagging","ref":"StarkBank.PaymentRequest.html#__struct__/0-parameters-optional"},{"type":"function","title":"Attributes (return-only): - StarkBank.PaymentRequest.__struct__/0","doc":"- `:id` [string, default nil]: unique id returned when PaymentRequest is created. ex: \"5656565656565656\"\n- `:amount` [integer, default nil]: PaymentRequest amount. ex: 100000 = R$1.000,00\n- `:status` [string, default nil]: current PaymentRequest status.ex: \"pending\" or \"approved\"\n- `:actions` [list of maps, default nil]: list of actions that are affecting this PaymentRequest. ex: [%{\"type\": \"member\", \"id\": \"56565656565656, \"action\": \"requested\"}]\n- `:updated` [DateTime, default nil]: latest update datetime for the PaymentRequest. ex: 2020-12-31\n- `:created` [DateTime, default nil]: creation datetime for the PaymentRequest. ex: 2020-12-31","ref":"StarkBank.PaymentRequest.html#__struct__/0-attributes-return-only"},{"type":"function","title":"StarkBank.PaymentRequest.create/2","doc":"Sends a list of PaymentRequests structs for creating in the Stark Bank API","ref":"StarkBank.PaymentRequest.html#create/2"},{"type":"function","title":"Paramenters (required): - StarkBank.PaymentRequest.create/2","doc":"- `payment_requests` [list of PaymentRequest structs]: list of PaymentRequest objects to be created in the API","ref":"StarkBank.PaymentRequest.html#create/2-paramenters-required"},{"type":"function","title":"Options: - StarkBank.PaymentRequest.create/2","doc":"- `:user` [Organization/Project, default nil]: Organization or Project struct returned from StarkBank.project(). Only necessary if default project or organization has not been set in configs.","ref":"StarkBank.PaymentRequest.html#create/2-options"},{"type":"function","title":"Return: - StarkBank.PaymentRequest.create/2","doc":"- list of PaymentRequest structs with updated attributes","ref":"StarkBank.PaymentRequest.html#create/2-return"},{"type":"function","title":"StarkBank.PaymentRequest.create!/2","doc":"Same as create(), but it will unwrap the error tuple and raise in case of errors.","ref":"StarkBank.PaymentRequest.html#create!/2"},{"type":"function","title":"StarkBank.PaymentRequest.page/1","doc":"Receive a list of up to 100 PaymentRequest objects previously created in the Stark Bank API and the cursor to the next page. \nUse this function instead of query if you want to manually page your requests.","ref":"StarkBank.PaymentRequest.html#page/1"},{"type":"function","title":"Options: - StarkBank.PaymentRequest.page/1","doc":"- `:cursor` [string, default nil]: cursor returned on the previous page function call\n    - `:center_id` [string]: target cost center ID. ex: '5656565656565656'\n    - `:limit` [integer, default nil]: maximum number of structs to be retrieved. Unlimited if nil. ex: 35\n    - `:after` [Date or string, default nil]: date filter for structs created only after specified date. ex: ~D[2020-03-25]\n    - `:before` [Date or string, default nil]: date filter for structs created only before specified date. ex: ~D[2020-03-25]\n    - `:sort` [string, default \"-created\"]: sort order considered in response. Valid options are \"-created\" or \"-due\".\n    - `:status` [string, default nil]: filter for status of retrieved structs. ex: \"paid\" or \"registered\"\n    - `:type` [string, default nil]: payment type, inferred from the payment parameter if it is not a dictionary. ex: \"transfer\", \"brcode-payment\"\n    - `:tags` [list of strings, default nil]: tags to filter retrieved structs. ex: [\"tony\", \"stark\"]\n    - `:ids` [list of strings, default nil]: list of ids to filter retrieved structs. ex: [\"5656565656565656\", \"4545454545454545\"]\n    - `:user` [Organization/Project, default nil]: Organization or Project struct returned from StarkBank.project(). Only necessary if default project or organization has not been set in configs.","ref":"StarkBank.PaymentRequest.html#page/1-options"},{"type":"function","title":"Return: - StarkBank.PaymentRequest.page/1","doc":"- list of PaymentRequest structs with updated attributes and cursor to retrieve the next page of PaymentRequest objects","ref":"StarkBank.PaymentRequest.html#page/1-return"},{"type":"function","title":"StarkBank.PaymentRequest.page!/1","doc":"Same as page(), but it will unwrap the error tuple and raise in case of errors.","ref":"StarkBank.PaymentRequest.html#page!/1"},{"type":"function","title":"StarkBank.PaymentRequest.query/1","doc":"Receive a stream of PaymentRequest structs previously created by this user in the Stark Bank API","ref":"StarkBank.PaymentRequest.html#query/1"},{"type":"function","title":"Options: - StarkBank.PaymentRequest.query/1","doc":"- `:limit` [integer, default nil]: maximum number of structs to be retrieved. Unlimited if nil. ex: 35\n    - `:center_id` [string]: target cost center ID. ex: '5656565656565656'\n    - `:after` [Date or string, default nil]: date filter for structs created only after specified date. ex: ~D[2020-03-25]\n    - `:before` [Date or string, default nil]: date filter for structs created only before specified date. ex: ~D[2020-03-25]\n    - `:sort` [string, default \"-created\"]: sort order considered in response. Valid options are \"-created\" or \"-due\".\n    - `:status` [string, default nil]: filter for status of retrieved structs. ex: \"paid\" or \"registered\"\n    - `:type` [string, default nil]: payment type, inferred from the payment parameter if it is not a dictionary. ex: \"transfer\", \"brcode-payment\"\n    - `:tags` [list of strings, default nil]: tags to filter retrieved structs. ex: [\"tony\", \"stark\"]\n    - `:ids` [list of strings, default nil]: list of ids to filter retrieved structs. ex: [\"5656565656565656\", \"4545454545454545\"]\n    - `:user` [Organization/Project, default nil]: Organization or Project struct returned from StarkBank.project(). Only necessary if default project or organization has not been set in configs.","ref":"StarkBank.PaymentRequest.html#query/1-options"},{"type":"function","title":"Return: - StarkBank.PaymentRequest.query/1","doc":"- stream of PaymentRequest structs with updated attributes","ref":"StarkBank.PaymentRequest.html#query/1-return"},{"type":"function","title":"StarkBank.PaymentRequest.query!/1","doc":"Same as query(), but it will unwrap the error tuple and raise in case of errors.","ref":"StarkBank.PaymentRequest.html#query!/1"},{"type":"type","title":"StarkBank.PaymentRequest.t/0","doc":"","ref":"StarkBank.PaymentRequest.html#t:t/0"},{"type":"module","title":"StarkBank.TaxPayment","doc":"Groups TaxPayment related functions","ref":"StarkBank.TaxPayment.html"},{"type":"function","title":"StarkBank.TaxPayment.__struct__/0","doc":"When you initialize a TaxPayment, the entity will not be automatically\ncreated in the Stark Bank API. The \"create\" function sends the structs\nto the Stark Bank API and returns the list of created structs.","ref":"StarkBank.TaxPayment.html#__struct__/0"},{"type":"function","title":"Parameters (conditionally required): - StarkBank.TaxPayment.__struct__/0","doc":"- `:line` [string, default nil]: Number sequence that describes the payment. Either \"line\" or \"bar_code\" parameters are required. If both are sent, they must match. ex: \"34191.09008 63571.277308 71444.640008 5 81960000000062\"\n  - `:bar_code` [string, default nil]: Bar code number that describes the payment. Either \"line\" or \"bar_code\" parameters are required. If both are sent, they must match. ex: \"34195819600000000621090063571277307144464000\"","ref":"StarkBank.TaxPayment.html#__struct__/0-parameters-conditionally-required"},{"type":"function","title":"Parameters (required): - StarkBank.TaxPayment.__struct__/0","doc":"- `:description` [string]: Text to be displayed in your statement (min. 10 characters). ex: \"payment ABC\"","ref":"StarkBank.TaxPayment.html#__struct__/0-parameters-required"},{"type":"function","title":"Parameters (optional): - StarkBank.TaxPayment.__struct__/0","doc":"- `:scheduled` [string, default today]: payment scheduled date. ex: \"2020-03-10\"\n  - `:tags` [list of strings]: list of strings for tagging","ref":"StarkBank.TaxPayment.html#__struct__/0-parameters-optional"},{"type":"function","title":"Attributes (return-only): - StarkBank.TaxPayment.__struct__/0","doc":"- `:id` [string, default nil]: unique id returned when payment is created. ex: \"5656565656565656\"\n  - `:type` [string, default nil]: tax type. ex: \"das\"\n  - `:status` [string, default nil]: current payment status. ex: \"success\" or \"failed\"\n  - `:amount` [int, default nil]: amount automatically calculated from line or bar_code. ex: 23456 (= R$ 234.56)\n  - `:fee` [integer, default nil]: fee charged when the tax payment is created. ex: 200 (= R$ 2.00)\n  - `:updated` [string, default nil]: latest update datetime for the payment. ex: \"2020-03-10 10:30:00.000\"\n  - `:created` [string, default nil]: creation datetime for the payment. ex: \"2020-03-10 10:30:00.000\"","ref":"StarkBank.TaxPayment.html#__struct__/0-attributes-return-only"},{"type":"function","title":"StarkBank.TaxPayment.create/2","doc":"Send a list of TaxPayment structs for creation in the Stark Bank API","ref":"StarkBank.TaxPayment.html#create/2"},{"type":"function","title":"Parameters (required): - StarkBank.TaxPayment.create/2","doc":"- `:payments` [list of TaxPayment structs]: list of TaxPayment structs to be created in the API","ref":"StarkBank.TaxPayment.html#create/2-parameters-required"},{"type":"function","title":"Options: - StarkBank.TaxPayment.create/2","doc":"- `:user` [Organization/Project, default nil]: Organization or Project struct returned from StarkBank.project(). Only necessary if default project or organization has not been set in configs.","ref":"StarkBank.TaxPayment.html#create/2-options"},{"type":"function","title":"Return: - StarkBank.TaxPayment.create/2","doc":"- list of TaxPayment structs with updated attributes","ref":"StarkBank.TaxPayment.html#create/2-return"},{"type":"function","title":"StarkBank.TaxPayment.create!/2","doc":"Same as create(), but it will unwrap the error tuple and raise in case of errors.","ref":"StarkBank.TaxPayment.html#create!/2"},{"type":"function","title":"StarkBank.TaxPayment.delete/2","doc":"Delete a TaxPayment entity previously created in the Stark Bank API","ref":"StarkBank.TaxPayment.html#delete/2"},{"type":"function","title":"Parameters (required): - StarkBank.TaxPayment.delete/2","doc":"- `:id` [string]: Boleto unique id. ex: \"5656565656565656\"","ref":"StarkBank.TaxPayment.html#delete/2-parameters-required"},{"type":"function","title":"Options: - StarkBank.TaxPayment.delete/2","doc":"- `:user` [Organization/Project, default nil]: Organization or Project struct returned from StarkBank.project(). Only necessary if default project or organization has not been set in configs.\n\n##  Return:\n  - deleted TaxPayment struct","ref":"StarkBank.TaxPayment.html#delete/2-options"},{"type":"function","title":"StarkBank.TaxPayment.delete!/2","doc":"Same as delete(), but it will unwrap the error tuple and raise in case of errors.","ref":"StarkBank.TaxPayment.html#delete!/2"},{"type":"function","title":"StarkBank.TaxPayment.get/2","doc":"Receive a single TaxPayment struct previously created by the Stark Bank API by passing its id","ref":"StarkBank.TaxPayment.html#get/2"},{"type":"function","title":"Parameters (required): - StarkBank.TaxPayment.get/2","doc":"- `:id` [string]: entity unique id. ex: \"5656565656565656\"","ref":"StarkBank.TaxPayment.html#get/2-parameters-required"},{"type":"function","title":"Options: - StarkBank.TaxPayment.get/2","doc":"- `:user` [Organization/Project, default nil]: Organization or Project struct returned from StarkBank.project(). Only necessary if default project or organization has not been set in configs.","ref":"StarkBank.TaxPayment.html#get/2-options"},{"type":"function","title":"Return: - StarkBank.TaxPayment.get/2","doc":"- TaxPayment struct with updated attributes","ref":"StarkBank.TaxPayment.html#get/2-return"},{"type":"function","title":"StarkBank.TaxPayment.get!/2","doc":"Same as get(), but it will unwrap the error tuple and raise in case of errors.","ref":"StarkBank.TaxPayment.html#get!/2"},{"type":"function","title":"StarkBank.TaxPayment.page/1","doc":"Receive a list of up to 100 TaxPayment structs previously created in the Stark Bank API and the cursor to the next page.\nUse this function instead of query if you want to manually page your requests.","ref":"StarkBank.TaxPayment.html#page/1"},{"type":"function","title":"Options: - StarkBank.TaxPayment.page/1","doc":"- `:cursor` [string, default nil]: cursor returned on the previous page function call\n  - `:limit` [integer, default nil]: maximum number of entities to be retrieved. Unlimited if nil. ex: 35\n  - `:after` [Date or string, default nil]: date filter for entities created only after specified date. ex: ~D[2020-03-25]\n  - `:before` [Date or string, default nil]: date filter for entities created only before specified date. ex: ~D[2020-03-25]\n  - `:tags` [list of strings, default nil]: tags to filter retrieved structs. ex: [\"tony\", \"stark\"]\n  - `:ids` [list of strings, default nil]: list of ids to filter retrieved structs. ex: ['5656565656565656', '4545454545454545']\n  - `:status` [string, default nil]: filter for status of retrieved structs. ex: 'success'\n  - `:user` [Organization/Project, default nil]: Organization or Project struct returned from StarkBank.project(). Only necessary if default project or organization has not been set in configs.","ref":"StarkBank.TaxPayment.html#page/1-options"},{"type":"function","title":"Return: - StarkBank.TaxPayment.page/1","doc":"- list of TaxPayment structs with updated attributes and cursor to retrieve the next page of TaxPayment structs","ref":"StarkBank.TaxPayment.html#page/1-return"},{"type":"function","title":"StarkBank.TaxPayment.page!/1","doc":"Same as page(), but it will unwrap the error tuple and raise in case of errors.","ref":"StarkBank.TaxPayment.html#page!/1"},{"type":"function","title":"StarkBank.TaxPayment.pdf/2","doc":"Receive a single Transfer pdf receipt file generated in the Stark Bank API by passing its id.\nOnly valid for transfers with \"processing\" or \"success\" status.","ref":"StarkBank.TaxPayment.html#pdf/2"},{"type":"function","title":"Parameters (required): - StarkBank.TaxPayment.pdf/2","doc":"- `id` [string]: struct unique id. ex: \"5656565656565656\"","ref":"StarkBank.TaxPayment.html#pdf/2-parameters-required"},{"type":"function","title":"Options: - StarkBank.TaxPayment.pdf/2","doc":"- `:user` [Organization/Project, default nil]: Organization or Project struct returned from StarkBank.project(). Only necessary if default project or organization has not been set in configs.","ref":"StarkBank.TaxPayment.html#pdf/2-options"},{"type":"function","title":"Return: - StarkBank.TaxPayment.pdf/2","doc":"- Transfer pdf file content","ref":"StarkBank.TaxPayment.html#pdf/2-return"},{"type":"function","title":"StarkBank.TaxPayment.pdf!/2","doc":"Same as pdf(), but it will unwrap the error tuple and raise in case of errors.","ref":"StarkBank.TaxPayment.html#pdf!/2"},{"type":"function","title":"StarkBank.TaxPayment.query/1","doc":"Receive a stream of TaxPayment entities previously created in the Stark Bank API","ref":"StarkBank.TaxPayment.html#query/1"},{"type":"function","title":"Options: - StarkBank.TaxPayment.query/1","doc":"- `:limit` [integer, default nil]: maximum number of entities to be retrieved. Unlimited if nil. ex: 35\n  - `:after` [Date or string, default nil]: date filter for entities created only after specified date. ex: ~D[2020-03-25]\n  - `:before` [Date or string, default nil]: date filter for entities created only before specified date. ex: ~D[2020-03-25]\n  - `:tags` [list of strings, default nil]: tags to filter retrieved structs. ex: [\"tony\", \"stark\"]\n  - `:ids` [list of strings, default nil]: list of ids to filter retrieved structs. ex: ['5656565656565656', '4545454545454545']\n  - `:status` [string, default nil]: filter for status of retrieved structs. ex: 'success'\n  - `:user` [Organization/Project, default nil]: Organization or Project struct returned from StarkBank.project(). Only necessary if default project or organization has not been set in configs.","ref":"StarkBank.TaxPayment.html#query/1-options"},{"type":"function","title":"Return: - StarkBank.TaxPayment.query/1","doc":"- stream of TaxPayment structs with updated attributes","ref":"StarkBank.TaxPayment.html#query/1-return"},{"type":"function","title":"StarkBank.TaxPayment.query!/1","doc":"Same as query(), but it will unwrap the error tuple and raise in case of errors.","ref":"StarkBank.TaxPayment.html#query!/1"},{"type":"type","title":"StarkBank.TaxPayment.t/0","doc":"","ref":"StarkBank.TaxPayment.html#t:t/0"},{"type":"module","title":"StarkBank.TaxPayment.Log","doc":"Groups TaxPayment related functions","ref":"StarkBank.TaxPayment.Log.html"},{"type":"function","title":"StarkBank.TaxPayment.Log.__struct__/0","doc":"Every time a TaxPayment entity is modified, a corresponding TaxPayment Log\nis generated for the entity. This log is never generated by the user, but it can\nbe retrieved to check additional information on the TaxPayment.","ref":"StarkBank.TaxPayment.Log.html#__struct__/0"},{"type":"function","title":"Attributes (return-only): - StarkBank.TaxPayment.Log.__struct__/0","doc":"- `:id` [string]: unique id returned when payment is created. ex: \"5656565656565656\"\n  - `:payment` [TaxPayment]: TaxPayment entity to which the log refers to.\n  - `:errors` [list of strings]: list of errors linked to this TaxPayment event.\n  - `:type` [string]: tax type. ex: \"das\"\n  - `:created` [DateTime]: creation datetime for the payment. ex: \"2020-03-10 10:30:00.000\"","ref":"StarkBank.TaxPayment.Log.html#__struct__/0-attributes-return-only"},{"type":"function","title":"StarkBank.TaxPayment.Log.get/2","doc":"Receive a single TaxPayment Log struct previously created by the Stark Bank API by passing its id","ref":"StarkBank.TaxPayment.Log.html#get/2"},{"type":"function","title":"Parameters (required): - StarkBank.TaxPayment.Log.get/2","doc":"- `:id` [string]: entity unique id. ex: \"5656565656565656\"","ref":"StarkBank.TaxPayment.Log.html#get/2-parameters-required"},{"type":"function","title":"Options: - StarkBank.TaxPayment.Log.get/2","doc":"- `:user` [Organization/Project, default nil]: Organization or Project struct returned from StarkBank.project(). Only necessary if default project or organization has not been set in configs.","ref":"StarkBank.TaxPayment.Log.html#get/2-options"},{"type":"function","title":"Return: - StarkBank.TaxPayment.Log.get/2","doc":"- TaxPayment Log struct with updated attributes","ref":"StarkBank.TaxPayment.Log.html#get/2-return"},{"type":"function","title":"StarkBank.TaxPayment.Log.get!/2","doc":"Same as get(), but it will unwrap the error tuple and raise in case of errors.","ref":"StarkBank.TaxPayment.Log.html#get!/2"},{"type":"function","title":"StarkBank.TaxPayment.Log.page/1","doc":"Receive a list of up to 100 TaxPayment structs previously created in the Stark Bank API and the cursor to the next page.\nUse this function instead of query if you want to manually page your requests.","ref":"StarkBank.TaxPayment.Log.html#page/1"},{"type":"function","title":"Options: - StarkBank.TaxPayment.Log.page/1","doc":"- `:cursor` [string, default nil]: cursor returned on the previous page function call\n  - `:limit` [integer, default nil]: maximum number of entities to be retrieved. Unlimited if nil. ex: 35\n  - `:after` [Date or string, default nil]: date filter for entities created only after specified date. ex: ~D[2020-03-25]\n  - `:before` [Date or string, default nil]: date filter for entities created only before specified date. ex: ~D[2020-03-25]\n  - `:types` [list of strings, default null]: filter retrieved structs by event types. ex: 'paid' or 'registered'\n  - `:payment_ids` [list of strings, default null]: list of TaxPayment ids to filter retrieved structs. ex: ['5656565656565656', '4545454545454545']\n  - `:user` [Organization/Project, default nil]: Organization or Project struct returned from StarkBank.project(). Only necessary if default project or organization has not been set in configs.","ref":"StarkBank.TaxPayment.Log.html#page/1-options"},{"type":"function","title":"Return: - StarkBank.TaxPayment.Log.page/1","doc":"- list of TaxPayment structs with updated attributes and cursor to retrieve the next page of TaxPayment structs","ref":"StarkBank.TaxPayment.Log.html#page/1-return"},{"type":"function","title":"StarkBank.TaxPayment.Log.page!/1","doc":"Same as page(), but it will unwrap the error tuple and raise in case of errors.","ref":"StarkBank.TaxPayment.Log.html#page!/1"},{"type":"function","title":"StarkBank.TaxPayment.Log.query/1","doc":"Receive a stream of TaxPayment Log structs previously created in the Stark Bank API","ref":"StarkBank.TaxPayment.Log.html#query/1"},{"type":"function","title":"Options: - StarkBank.TaxPayment.Log.query/1","doc":"- `:limit` [integer, default nil]: maximum number of entities to be retrieved. Unlimited if nil. ex: 35\n  - `:after` [Date or string, default nil]: date filter for entities created only after specified date. ex: ~D[2020-03-25]\n  - `:before` [Date or string, default nil]: date filter for entities created only before specified date. ex: ~D[2020-03-25]\n  - `:types` [list of strings, default null]: filter retrieved structs by event types. ex: 'paid' or 'registered'\n  - `:payment_ids` [list of strings, default null]: list of TaxPayment ids to filter retrieved structs. ex: ['5656565656565656', '4545454545454545']\n  - `:user` [Organization/Project, default nil]: Organization or Project struct returned from StarkBank.project(). Only necessary if default project or organization has not been set in configs.","ref":"StarkBank.TaxPayment.Log.html#query/1-options"},{"type":"function","title":"Return: - StarkBank.TaxPayment.Log.query/1","doc":"- stream of TaxPayment Log structs with updated attributes","ref":"StarkBank.TaxPayment.Log.html#query/1-return"},{"type":"function","title":"StarkBank.TaxPayment.Log.query!/1","doc":"Same as query(), but it will unwrap the error tuple and raise in case of errors.","ref":"StarkBank.TaxPayment.Log.html#query!/1"},{"type":"type","title":"StarkBank.TaxPayment.Log.t/0","doc":"","ref":"StarkBank.TaxPayment.Log.html#t:t/0"},{"type":"module","title":"StarkBank.Transaction","doc":"Groups Transaction related functions","ref":"StarkBank.Transaction.html"},{"type":"function","title":"StarkBank.Transaction.__struct__/0","doc":"A Transaction is a transfer of funds between workspaces inside Stark Bank.\nTransactions created by the user are only for internal transactions.\nOther operations (such as transfer or charge-payment) will automatically\ncreate a transaction for the user which can be retrieved for the statement.\nWhen you initialize a Transaction, the entity will not be automatically\ncreated in the Stark Bank API. The 'create' function sends the structs\nto the Stark Bank API and returns the list of created structs.","ref":"StarkBank.Transaction.html#__struct__/0"},{"type":"function","title":"Parameters (required): - StarkBank.Transaction.__struct__/0","doc":"- `:amount` [integer]: amount in cents to be transferred. ex: 1234 (= R$ 12.34)\n  - `:description` [string]: text to be displayed in the receiver and the sender statements (Min. 10 characters). ex: \"funds redistribution\"\n  - `:external_id` [string]: unique id, generated by user, to avoid duplicated transactions. ex: \"transaction ABC 2020-03-30\"\n  - `:received_id` [string]: unique id of the receiving workspace. ex: \"5656565656565656\"","ref":"StarkBank.Transaction.html#__struct__/0-parameters-required"},{"type":"function","title":"Parameters (optional): - StarkBank.Transaction.__struct__/0","doc":"- `:tags` [list of strings]: list of strings for reference when searching transactions (may be empty). ex: [\"abc\", \"test\"]","ref":"StarkBank.Transaction.html#__struct__/0-parameters-optional"},{"type":"function","title":"Attributes (return-only): - StarkBank.Transaction.__struct__/0","doc":"- `:id` [string, default nil]: unique id returned when Transaction is created. ex: \"7656565656565656\"\n  - `:sender_id` [string]: unique id of the sending workspace. ex: \"5656565656565656\"\n  - `:fee` [integer, default nil]: fee charged when the transaction was created. ex: 200 (= R$ 2.00)\n  - `:source` [string, default nil]: locator of the entity that generated the transaction. ex: \"charge/18276318736\" or \"transfer/19381639871263/chargeback\"\n  - `:balance` [integer, default nil]: account balance after transaction was processed. ex: 100000000 (= R$ 1,000,000.00)\n  - `:created` [DateTime, default nil]: creation datetime for the transaction. ex: ~U[2020-03-26 19:32:35.418698Z]","ref":"StarkBank.Transaction.html#__struct__/0-attributes-return-only"},{"type":"function","title":"StarkBank.Transaction.create/2","doc":"Send a list of Transaction entities for creation in the Stark Bank API","ref":"StarkBank.Transaction.html#create/2"},{"type":"function","title":"Parameters (required): - StarkBank.Transaction.create/2","doc":"- `transactions` [list of Transaction entities]: list of Transaction entities to be created in the API","ref":"StarkBank.Transaction.html#create/2-parameters-required"},{"type":"function","title":"Options: - StarkBank.Transaction.create/2","doc":"- `:user` [Organization/Project, default nil]: Organization or Project struct returned from StarkBank.project(). Only necessary if default project or organization has not been set in configs.","ref":"StarkBank.Transaction.html#create/2-options"},{"type":"function","title":"Return: - StarkBank.Transaction.create/2","doc":"- list of Transaction structs with updated attributes","ref":"StarkBank.Transaction.html#create/2-return"},{"type":"function","title":"StarkBank.Transaction.create!/2","doc":"Same as create(), but it will unwrap the error tuple and raise in case of errors.","ref":"StarkBank.Transaction.html#create!/2"},{"type":"function","title":"StarkBank.Transaction.get/2","doc":"Receive a single Transaction entity previously created in the Stark Bank API by passing its id","ref":"StarkBank.Transaction.html#get/2"},{"type":"function","title":"Parameters (required): - StarkBank.Transaction.get/2","doc":"- `id` [string]: entity unique id. ex: \"5656565656565656\"","ref":"StarkBank.Transaction.html#get/2-parameters-required"},{"type":"function","title":"Options: - StarkBank.Transaction.get/2","doc":"- `:user` [Organization/Project, default nil]: Organization or Project struct returned from StarkBank.project(). Only necessary if default project or organization has not been set in configs.","ref":"StarkBank.Transaction.html#get/2-options"},{"type":"function","title":"Return: - StarkBank.Transaction.get/2","doc":"- Transaction struct with updated attributes","ref":"StarkBank.Transaction.html#get/2-return"},{"type":"function","title":"StarkBank.Transaction.get!/2","doc":"Same as get(), but it will unwrap the error tuple and raise in case of errors.","ref":"StarkBank.Transaction.html#get!/2"},{"type":"function","title":"StarkBank.Transaction.page/1","doc":"Receive a list of up to 100 Transaction objects previously created in the Stark Bank API and the cursor to the next page. \nUse this function instead of query if you want to manually page your requests.","ref":"StarkBank.Transaction.html#page/1"},{"type":"function","title":"Options: - StarkBank.Transaction.page/1","doc":"- `:cursor` [string, default nil]: cursor returned on the previous page function call\n  - `:limit` [integer, default nil]: maximum number of entities to be retrieved. Unlimited if nil. ex: 35\n  - `:after` [Date or string, default nil]: date filter for entities created only after specified date. ex: ~D[2020-03-25]\n  - `:before` [Date or string, default nil]: date filter for entities created only before specified date. ex: ~D[2020-03-25]\n  - `:tags` [list of strings, default nil]: tags to filter retrieved structs. ex: [\"tony\", \"stark\"]\n  - `:external_ids` [list of strings, default nil]: list of external ids to filter retrieved entities. ex: [\"5656565656565656\", \"4545454545454545\"]\n  - `:ids` [list of strings, default nil]: list of ids to filter retrieved structs. ex: [\"5656565656565656\", \"4545454545454545\"]\n  - `:user` [Organization/Project, default nil]: Organization or Project struct returned from StarkBank.project(). Only necessary if default project or organization has not been set in configs.","ref":"StarkBank.Transaction.html#page/1-options"},{"type":"function","title":"Return: - StarkBank.Transaction.page/1","doc":"- list of Transaction structs with updated attributes and cursor to retrieve the next page of Transaction objects","ref":"StarkBank.Transaction.html#page/1-return"},{"type":"function","title":"StarkBank.Transaction.page!/1","doc":"Same as page(), but it will unwrap the error tuple and raise in case of errors.","ref":"StarkBank.Transaction.html#page!/1"},{"type":"function","title":"StarkBank.Transaction.query/1","doc":"Receive a stream of Transaction entities previously created in the Stark Bank API","ref":"StarkBank.Transaction.html#query/1"},{"type":"function","title":"Options: - StarkBank.Transaction.query/1","doc":"- `:limit` [integer, default nil]: maximum number of entities to be retrieved. Unlimited if nil. ex: 35\n  - `:after` [Date or string, default nil]: date filter for entities created only after specified date. ex: ~D[2020-03-25]\n  - `:before` [Date or string, default nil]: date filter for entities created only before specified date. ex: ~D[2020-03-25]\n  - `:tags` [list of strings, default nil]: tags to filter retrieved structs. ex: [\"tony\", \"stark\"]\n  - `:external_ids` [list of strings, default nil]: list of external ids to filter retrieved entities. ex: [\"5656565656565656\", \"4545454545454545\"]\n  - `:ids` [list of strings, default nil]: list of ids to filter retrieved structs. ex: [\"5656565656565656\", \"4545454545454545\"]\n  - `:user` [Organization/Project, default nil]: Organization or Project struct returned from StarkBank.project(). Only necessary if default project or organization has not been set in configs.","ref":"StarkBank.Transaction.html#query/1-options"},{"type":"function","title":"Return: - StarkBank.Transaction.query/1","doc":"- stream of Transaction structs with updated attributes","ref":"StarkBank.Transaction.html#query/1-return"},{"type":"function","title":"StarkBank.Transaction.query!/1","doc":"Same as query(), but it will unwrap the error tuple and raise in case of errors.","ref":"StarkBank.Transaction.html#query!/1"},{"type":"type","title":"StarkBank.Transaction.t/0","doc":"","ref":"StarkBank.Transaction.html#t:t/0"},{"type":"module","title":"StarkBank.Transfer","doc":"Groups Transfer related functions","ref":"StarkBank.Transfer.html"},{"type":"function","title":"StarkBank.Transfer.__struct__/0","doc":"When you initialize a Transfer, the entity will not be automatically\ncreated in the Stark Bank API. The 'create' function sends the structs\nto the Stark Bank API and returns the list of created structs.","ref":"StarkBank.Transfer.html#__struct__/0"},{"type":"function","title":"Parameters (required): - StarkBank.Transfer.__struct__/0","doc":"- `:amount` [integer]: amount in cents to be transferred. ex: 1234 (= R$ 12.34)\n  - `:name` [string]: receiver full name. ex: \"Anthony Edward Stark\"\n  - `:tax_id` [string]: receiver tax ID (CPF or CNPJ) with or without formatting. ex: \"01234567890\" or \"20.018.183/0001-80\"\n  - `:bank_code` [string]: code of the receiver bank institution in Brazil. If an ISPB (8 digits) is informed, a PIX transfer will be created, else a TED will be issued. ex: \"20018183\" or \"341\"\n  - `:branch_code` [string]: receiver bank account branch. Use '-' in case there is a verifier digit. ex: \"1357-9\"\n  - `:account_number` [string]: Receiver bank account number. Use '-' before the verifier digit. ex: \"876543-2\"","ref":"StarkBank.Transfer.html#__struct__/0-parameters-required"},{"type":"function","title":"Parameters (optional): - StarkBank.Transfer.__struct__/0","doc":"- `:account_type` [string, default \"checking\"]: Receiver bank account type. This parameter only has effect on Pix Transfers. ex: \"checking\", \"savings\", \"salary\" or \"payment\"\n  - `:external_id` [string, default nil]: url safe string that must be unique among all your transfers. Duplicated external_ids will cause failures. By default, this parameter will block any transfer that repeats amount and receiver information on the same date. ex: \"my-internal-id-123456\"\n  - `:scheduled` [Date, DateTime or string, default now]: date or datetime when the transfer will be processed. May be pushed to next business day if necessary. ex: ~U[2020-03-26 19:32:35.418698Z]\n  - `:description` [string, default nil]: optional description to override default description to be shown in the bank statement. ex: \"Payment for service #1234\"\n  - `:tags` [list of strings]: list of strings for reference when searching for transfers. ex: [\"employees\", \"monthly\"]\n\nAttributes (return-only):\n  - `:id` [string, default nil]: unique id returned when Transfer is created. ex: \"5656565656565656\"\n  - `:fee` [integer, default nil]: fee charged when transfer is created. ex: 200 (= R$ 2.00)\n  - `:status` [string, default nil]: current transfer status. ex: \"success\" or \"failed\"\n  - `:transaction_ids` [list of strings, default nil]: ledger transaction ids linked to this transfer (if there are two, second is the chargeback). ex: [\"19827356981273\"]\n  - `:created` [DateTime, default nil]: creation datetime for the transfer. ex: ~U[2020-03-26 19:32:35.418698Z]\n  - `:updated` [DateTime, default nil]: latest update datetime for the transfer. ex: ~U[2020-03-26 19:32:35.418698Z]","ref":"StarkBank.Transfer.html#__struct__/0-parameters-optional"},{"type":"function","title":"StarkBank.Transfer.create/2","doc":"Send a list of Transfer structs for creation in the Stark Bank API","ref":"StarkBank.Transfer.html#create/2"},{"type":"function","title":"Parameters (required): - StarkBank.Transfer.create/2","doc":"- `transfers` [list of Transfer structs]: list of Transfer structs to be created in the API","ref":"StarkBank.Transfer.html#create/2-parameters-required"},{"type":"function","title":"Options: - StarkBank.Transfer.create/2","doc":"- `:user` [Organization/Project, default nil]: Organization or Project struct returned from StarkBank.project(). Only necessary if default project or organization has not been set in configs.","ref":"StarkBank.Transfer.html#create/2-options"},{"type":"function","title":"Return: - StarkBank.Transfer.create/2","doc":"- list of Transfer structs with updated attributes","ref":"StarkBank.Transfer.html#create/2-return"},{"type":"function","title":"StarkBank.Transfer.create!/2","doc":"Same as create(), but it will unwrap the error tuple and raise in case of errors.","ref":"StarkBank.Transfer.html#create!/2"},{"type":"function","title":"StarkBank.Transfer.delete/2","doc":"Delete a list of Transfer entities previously created in the Stark Bank API","ref":"StarkBank.Transfer.html#delete/2"},{"type":"function","title":"Parameters (required): - StarkBank.Transfer.delete/2","doc":"- `id` [string]: Boleto unique id. ex: \"5656565656565656\"","ref":"StarkBank.Transfer.html#delete/2-parameters-required"},{"type":"function","title":"Options: - StarkBank.Transfer.delete/2","doc":"- `:user` [Organization/Project, default nil]: Organization or Project struct returned from StarkBank.project(). Only necessary if default project or organization has not been set in configs.\n\n##  Return:\n  - deleted Transfer struct","ref":"StarkBank.Transfer.html#delete/2-options"},{"type":"function","title":"StarkBank.Transfer.delete!/2","doc":"Same as delete(), but it will unwrap the error tuple and raise in case of errors.","ref":"StarkBank.Transfer.html#delete!/2"},{"type":"function","title":"StarkBank.Transfer.get/2","doc":"Receive a single Transfer struct previously created in the Stark Bank API by passing its id","ref":"StarkBank.Transfer.html#get/2"},{"type":"function","title":"Parameters (required): - StarkBank.Transfer.get/2","doc":"- `id` [string]: struct unique id. ex: \"5656565656565656\"","ref":"StarkBank.Transfer.html#get/2-parameters-required"},{"type":"function","title":"Options: - StarkBank.Transfer.get/2","doc":"- `:user` [Organization/Project, default nil]: Organization or Project struct returned from StarkBank.project(). Only necessary if default project or organization has not been set in configs.","ref":"StarkBank.Transfer.html#get/2-options"},{"type":"function","title":"Return: - StarkBank.Transfer.get/2","doc":"- Transfer struct with updated attributes","ref":"StarkBank.Transfer.html#get/2-return"},{"type":"function","title":"StarkBank.Transfer.get!/2","doc":"Same as get(), but it will unwrap the error tuple and raise in case of errors.","ref":"StarkBank.Transfer.html#get!/2"},{"type":"function","title":"StarkBank.Transfer.page/1","doc":"Receive a list of up to 100 Transfer objects previously created in the Stark Bank API and the cursor to the next page. \nUse this function instead of query if you want to manually page your requests.","ref":"StarkBank.Transfer.html#page/1"},{"type":"function","title":"Options: - StarkBank.Transfer.page/1","doc":"- `:cursor` [string, default nil]: cursor returned on the previous page function call\n  - `:limit` [integer, default nil]: maximum number of structs to be retrieved. Unlimited if nil. ex: 35\n  - `:after` [Date or string, default nil]: date filter for structs created or updated only after specified date. ex: ~D[2020-03-25]\n  - `:before` [Date or string, default nil]: date filter for structs created or updated only before specified date. ex: ~D[2020-03-25]\n  - `:transaction_ids` [list of strings, default nil]: list of transaction IDs linked to the desired transfers. ex: [\"5656565656565656\", \"4545454545454545\"]\n  - `:status` [string, default nil]: filter for status of retrieved structs. ex: \"paid\" or \"registered\"\n  - `:tax_id` [string, default nil]: filter for transfers sent to the specified tax ID. ex: \"012.345.678-90\"\n  - `:sort` [string, default \"-created\"]: sort order considered in response. Valid options are \"created\", \"-created\", \"updated\" or \"-updated\".\n  - `:tags` [list of strings, default nil]: tags to filter retrieved structs. ex: [\"tony\", \"stark\"]\n  - `:ids` [list of strings, default nil]: list of ids to filter retrieved structs. ex: [\"5656565656565656\", \"4545454545454545\"]\n  - `:user` [Organization/Project, default nil]: Organization or Project struct returned from StarkBank.project(). Only necessary if default project or organization has not been set in configs.","ref":"StarkBank.Transfer.html#page/1-options"},{"type":"function","title":"Return: - StarkBank.Transfer.page/1","doc":"- list of Transfer structs with updated attributes and cursor to retrieve the next page of Transfer objects","ref":"StarkBank.Transfer.html#page/1-return"},{"type":"function","title":"StarkBank.Transfer.page!/1","doc":"Same as page(), but it will unwrap the error tuple and raise in case of errors.","ref":"StarkBank.Transfer.html#page!/1"},{"type":"function","title":"StarkBank.Transfer.pdf/2","doc":"Receive a single Transfer pdf receipt file generated in the Stark Bank API by passing its id.\nOnly valid for transfers with \"processing\" or \"success\" status.","ref":"StarkBank.Transfer.html#pdf/2"},{"type":"function","title":"Parameters (required): - StarkBank.Transfer.pdf/2","doc":"- `id` [string]: struct unique id. ex: \"5656565656565656\"","ref":"StarkBank.Transfer.html#pdf/2-parameters-required"},{"type":"function","title":"Options: - StarkBank.Transfer.pdf/2","doc":"- `:user` [Organization/Project, default nil]: Organization or Project struct returned from StarkBank.project(). Only necessary if default project or organization has not been set in configs.","ref":"StarkBank.Transfer.html#pdf/2-options"},{"type":"function","title":"Return: - StarkBank.Transfer.pdf/2","doc":"- Transfer pdf file content","ref":"StarkBank.Transfer.html#pdf/2-return"},{"type":"function","title":"StarkBank.Transfer.pdf!/2","doc":"Same as pdf(), but it will unwrap the error tuple and raise in case of errors.","ref":"StarkBank.Transfer.html#pdf!/2"},{"type":"function","title":"StarkBank.Transfer.query/1","doc":"Receive a stream of Transfer structs previously created in the Stark Bank API","ref":"StarkBank.Transfer.html#query/1"},{"type":"function","title":"Options: - StarkBank.Transfer.query/1","doc":"- `:limit` [integer, default nil]: maximum number of structs to be retrieved. Unlimited if nil. ex: 35\n  - `:after` [Date or string, default nil]: date filter for structs created or updated only after specified date. ex: ~D[2020-03-25]\n  - `:before` [Date or string, default nil]: date filter for structs created or updated only before specified date. ex: ~D[2020-03-25]\n  - `:transaction_ids` [list of strings, default nil]: list of transaction IDs linked to the desired transfers. ex: [\"5656565656565656\", \"4545454545454545\"]\n  - `:status` [string, default nil]: filter for status of retrieved structs. ex: \"paid\" or \"registered\"\n  - `:tax_id` [string, default nil]: filter for transfers sent to the specified tax ID. ex: \"012.345.678-90\"\n  - `:sort` [string, default \"-created\"]: sort order considered in response. Valid options are \"created\", \"-created\", \"updated\" or \"-updated\".\n  - `:tags` [list of strings, default nil]: tags to filter retrieved structs. ex: [\"tony\", \"stark\"]\n  - `:ids` [list of strings, default nil]: list of ids to filter retrieved structs. ex: [\"5656565656565656\", \"4545454545454545\"]\n  - `:user` [Organization/Project, default nil]: Organization or Project struct returned from StarkBank.project(). Only necessary if default project or organization has not been set in configs.","ref":"StarkBank.Transfer.html#query/1-options"},{"type":"function","title":"Return: - StarkBank.Transfer.query/1","doc":"- stream of Transfer structs with updated attributes","ref":"StarkBank.Transfer.html#query/1-return"},{"type":"function","title":"StarkBank.Transfer.query!/1","doc":"Same as query(), but it will unwrap the error tuple and raise in case of errors.","ref":"StarkBank.Transfer.html#query!/1"},{"type":"type","title":"StarkBank.Transfer.t/0","doc":"","ref":"StarkBank.Transfer.html#t:t/0"},{"type":"module","title":"StarkBank.Transfer.Log","doc":"Groups Transfer.Log related functions","ref":"StarkBank.Transfer.Log.html"},{"type":"function","title":"StarkBank.Transfer.Log.__struct__/0","doc":"Every time a Transfer entity is modified, a corresponding Transfer.Log\nis generated for the entity. This log is never generated by the\nuser.","ref":"StarkBank.Transfer.Log.html#__struct__/0"},{"type":"function","title":"Attributes: - StarkBank.Transfer.Log.__struct__/0","doc":"- `:id` [string]: unique id returned when the log is created. ex: \"5656565656565656\"\n  - `:transfer` [Transfer]: Transfer entity to which the log refers to.\n  - `:errors` [list of strings]: list of errors linked to this BoletoPayment event.\n  - `:type` [string]: type of the Transfer event which triggered the log creation. ex: \"processing\" or \"success\"\n  - `:created` [DateTime]: creation datetime for the log. ex: ~U[2020-03-26 19:32:35.418698Z]","ref":"StarkBank.Transfer.Log.html#__struct__/0-attributes"},{"type":"function","title":"StarkBank.Transfer.Log.get/2","doc":"Receive a single Log struct previously created by the Stark Bank API by passing its id","ref":"StarkBank.Transfer.Log.html#get/2"},{"type":"function","title":"Parameters (required): - StarkBank.Transfer.Log.get/2","doc":"- `id` [string]: struct unique id. ex: \"5656565656565656\"","ref":"StarkBank.Transfer.Log.html#get/2-parameters-required"},{"type":"function","title":"Options: - StarkBank.Transfer.Log.get/2","doc":"- `:user` [Organization/Project, default nil]: Organization or Project struct returned from StarkBank.project(). Only necessary if default project or organization has not been set in configs.","ref":"StarkBank.Transfer.Log.html#get/2-options"},{"type":"function","title":"Return: - StarkBank.Transfer.Log.get/2","doc":"- Log struct with updated attributes","ref":"StarkBank.Transfer.Log.html#get/2-return"},{"type":"function","title":"StarkBank.Transfer.Log.get!/2","doc":"Same as get(), but it will unwrap the error tuple and raise in case of errors.","ref":"StarkBank.Transfer.Log.html#get!/2"},{"type":"function","title":"StarkBank.Transfer.Log.page/1","doc":"Receive a list of up to 100 Transfer.Log objects previously created in the Stark Bank API and the cursor to the next page. \nUse this function instead of query if you want to manually page your requests.","ref":"StarkBank.Transfer.Log.html#page/1"},{"type":"function","title":"Options: - StarkBank.Transfer.Log.page/1","doc":"- `:cursor` [string, default nil]: cursor returned on the previous page function call\n  - `:limit` [integer, default nil]: maximum number of structs to be retrieved. Unlimited if nil. ex: 35\n  - `:after` [Date or string, default nil]: date filter for structs created only after specified date. ex: ~D[2020-03-25]\n  - `:before` [Date or string, default nil]: date filter for structs created only before specified date. ex: ~D[2020-03-25]\n  - `:types` [list of strings, default nil]: filter retrieved structs by types. ex: \"success\" or \"failed\"\n  - `:transfer_ids` [list of strings, default nil]: list of Transfer ids to filter retrieved structs. ex: [\"5656565656565656\", \"4545454545454545\"]\n  - `:user` [Organization/Project, default nil]: Organization or Project struct returned from StarkBank.project(). Only necessary if default project or organization has not been set in configs.","ref":"StarkBank.Transfer.Log.html#page/1-options"},{"type":"function","title":"Return: - StarkBank.Transfer.Log.page/1","doc":"- list of Transfer.Log structs with updated attributes and cursor to retrieve the next page of Transfer.Log objects","ref":"StarkBank.Transfer.Log.html#page/1-return"},{"type":"function","title":"StarkBank.Transfer.Log.page!/1","doc":"Same as page(), but it will unwrap the error tuple and raise in case of errors.","ref":"StarkBank.Transfer.Log.html#page!/1"},{"type":"function","title":"StarkBank.Transfer.Log.query/1","doc":"Receive a stream of Log structs previously created in the Stark Bank API","ref":"StarkBank.Transfer.Log.html#query/1"},{"type":"function","title":"Options: - StarkBank.Transfer.Log.query/1","doc":"- `:limit` [integer, default nil]: maximum number of structs to be retrieved. Unlimited if nil. ex: 35\n  - `:after` [Date or string, default nil]: date filter for structs created only after specified date. ex: ~D[2020-03-25]\n  - `:before` [Date or string, default nil]: date filter for structs created only before specified date. ex: ~D[2020-03-25]\n  - `:types` [list of strings, default nil]: filter retrieved structs by types. ex: \"success\" or \"failed\"\n  - `:transfer_ids` [list of strings, default nil]: list of Transfer ids to filter retrieved structs. ex: [\"5656565656565656\", \"4545454545454545\"]\n  - `:user` [Organization/Project, default nil]: Organization or Project struct returned from StarkBank.project(). Only necessary if default project or organization has not been set in configs.","ref":"StarkBank.Transfer.Log.html#query/1-options"},{"type":"function","title":"Return: - StarkBank.Transfer.Log.query/1","doc":"- stream of Log structs with updated attributes","ref":"StarkBank.Transfer.Log.html#query/1-return"},{"type":"function","title":"StarkBank.Transfer.Log.query!/1","doc":"Same as query(), but it will unwrap the error tuple and raise in case of errors.","ref":"StarkBank.Transfer.Log.html#query!/1"},{"type":"type","title":"StarkBank.Transfer.Log.t/0","doc":"","ref":"StarkBank.Transfer.Log.html#t:t/0"},{"type":"module","title":"StarkBank.UtilityPayment","doc":"Groups UtilityPayment related functions","ref":"StarkBank.UtilityPayment.html"},{"type":"function","title":"StarkBank.UtilityPayment.__struct__/0","doc":"When you initialize a UtilityPayment, the entity will not be automatically\ncreated in the Stark Bank API. The 'create' function sends the structs\nto the Stark Bank API and returns the list of created structs.","ref":"StarkBank.UtilityPayment.html#__struct__/0"},{"type":"function","title":"Parameters (conditionally required): - StarkBank.UtilityPayment.__struct__/0","doc":"- `:line` [string, default nil]: Number sequence that describes the payment. Either 'line' or 'bar_code' parameters are required. If both are sent, they must match. ex: \"34191.09008 63571.277308 71444.640008 5 81960000000062\"\n  - `:bar_code` [string, default nil]: Bar code number that describes the payment. Either 'line' or 'barCode' parameters are required. If both are sent, they must match. ex: \"34195819600000000621090063571277307144464000\"","ref":"StarkBank.UtilityPayment.html#__struct__/0-parameters-conditionally-required"},{"type":"function","title":"Parameters (required): - StarkBank.UtilityPayment.__struct__/0","doc":"- `:description` [string]: Text to be displayed in your statement (min. 10 characters). ex: \"payment ABC\"","ref":"StarkBank.UtilityPayment.html#__struct__/0-parameters-required"},{"type":"function","title":"Parameters (optional): - StarkBank.UtilityPayment.__struct__/0","doc":"- `:scheduled` [Date or string, default today]: payment scheduled date. ex: ~D[2020-03-25]\n  - `:tags` [list of strings]: list of strings for tagging\n\nAttributes (return-only):\n  - `:id` [string, default nil]: unique id returned when payment is created. ex: \"5656565656565656\"\n  - `:status` [string, default nil]: current payment status. ex: \"success\" or \"failed\"\n  - `:amount` [int, default nil]: amount automatically calculated from line or bar_code. ex: 23456 (= R$ 234.56)\n  - `:fee` [integer, default nil]: fee charged when a utility payment is created. ex: 200 (= R$ 2.00)\n  - `:created` [DateTime, default nil]: creation datetime for the payment. ex: ~U[2020-03-26 19:32:35.418698Z]","ref":"StarkBank.UtilityPayment.html#__struct__/0-parameters-optional"},{"type":"function","title":"StarkBank.UtilityPayment.create/2","doc":"Send a list of UtilityPayment structs for creation in the Stark Bank API","ref":"StarkBank.UtilityPayment.html#create/2"},{"type":"function","title":"Parameters (required): - StarkBank.UtilityPayment.create/2","doc":"- `payments` [list of UtilityPayment structs]: list of UtilityPayment structs to be created in the API","ref":"StarkBank.UtilityPayment.html#create/2-parameters-required"},{"type":"function","title":"Options: - StarkBank.UtilityPayment.create/2","doc":"- `:user` [Organization/Project, default nil]: Organization or Project struct returned from StarkBank.project(). Only necessary if default project or organization has not been set in configs.","ref":"StarkBank.UtilityPayment.html#create/2-options"},{"type":"function","title":"Return: - StarkBank.UtilityPayment.create/2","doc":"- list of UtilityPayment structs with updated attributes","ref":"StarkBank.UtilityPayment.html#create/2-return"},{"type":"function","title":"StarkBank.UtilityPayment.create!/2","doc":"Same as create(), but it will unwrap the error tuple and raise in case of errors.","ref":"StarkBank.UtilityPayment.html#create!/2"},{"type":"function","title":"StarkBank.UtilityPayment.delete/2","doc":"Delete a UtilityPayment entity previously created in the Stark Bank API","ref":"StarkBank.UtilityPayment.html#delete/2"},{"type":"function","title":"Parameters (required): - StarkBank.UtilityPayment.delete/2","doc":"- `id` [string]: UtilityPayment unique id. ex: \"5656565656565656\"","ref":"StarkBank.UtilityPayment.html#delete/2-parameters-required"},{"type":"function","title":"Options: - StarkBank.UtilityPayment.delete/2","doc":"- `:user` [Organization/Project, default nil]: Organization or Project struct returned from StarkBank.project(). Only necessary if default project or organization has not been set in configs.","ref":"StarkBank.UtilityPayment.html#delete/2-options"},{"type":"function","title":"Return: - StarkBank.UtilityPayment.delete/2","doc":"- deleted UtilityPayment struct","ref":"StarkBank.UtilityPayment.html#delete/2-return"},{"type":"function","title":"StarkBank.UtilityPayment.delete!/2","doc":"Same as delete(), but it will unwrap the error tuple and raise in case of errors.","ref":"StarkBank.UtilityPayment.html#delete!/2"},{"type":"function","title":"StarkBank.UtilityPayment.get/2","doc":"Receive a single UtilityPayment struct previously created by the Stark Bank API by passing its id","ref":"StarkBank.UtilityPayment.html#get/2"},{"type":"function","title":"Parameters (required): - StarkBank.UtilityPayment.get/2","doc":"- `id` [string]: struct unique id. ex: \"5656565656565656\"","ref":"StarkBank.UtilityPayment.html#get/2-parameters-required"},{"type":"function","title":"Options: - StarkBank.UtilityPayment.get/2","doc":"- `:user` [Organization/Project, default nil]: Organization or Project struct returned from StarkBank.project(). Only necessary if default project or organization has not been set in configs.","ref":"StarkBank.UtilityPayment.html#get/2-options"},{"type":"function","title":"Return: - StarkBank.UtilityPayment.get/2","doc":"- UtilityPayment struct with updated attributes","ref":"StarkBank.UtilityPayment.html#get/2-return"},{"type":"function","title":"StarkBank.UtilityPayment.get!/2","doc":"Same as get(), but it will unwrap the error tuple and raise in case of errors.","ref":"StarkBank.UtilityPayment.html#get!/2"},{"type":"function","title":"StarkBank.UtilityPayment.page/1","doc":"Receive a list of up to 100 UtilityPayment objects previously created in the Stark Bank API and the cursor to the next page. \nUse this function instead of query if you want to manually page your requests.","ref":"StarkBank.UtilityPayment.html#page/1"},{"type":"function","title":"Options: - StarkBank.UtilityPayment.page/1","doc":"- `:cursor` [string, default nil]: cursor returned on the previous page function call\n  - `:limit` [integer, default nil]: maximum number of structs to be retrieved. Unlimited if nil. ex: 35\n  - `:after` [Date or string, default nil]: date filter for structs created only after specified date. ex: ~D[2020-03-25]\n  - `:before` [Date or string, default nil]: date filter for structs created only before specified date. ex: ~D[2020-03-25]\n  - `:tags` [list of strings, default nil]: tags to filter retrieved structs. ex: [\"tony\", \"stark\"]\n  - `:ids` [list of strings, default nil]: list of ids to filter retrieved structs. ex: [\"5656565656565656\", \"4545454545454545\"]\n  - `:status` [string, default nil]: filter for status of retrieved structs. ex: \"paid\"\n  - `:user` [Organization/Project, default nil]: Organization or Project struct returned from StarkBank.project(). Only necessary if default project or organization has not been set in configs.","ref":"StarkBank.UtilityPayment.html#page/1-options"},{"type":"function","title":"Return: - StarkBank.UtilityPayment.page/1","doc":"- list of UtilityPayment structs with updated attributes and cursor to retrieve the next page of UtilityPayment objects","ref":"StarkBank.UtilityPayment.html#page/1-return"},{"type":"function","title":"StarkBank.UtilityPayment.page!/1","doc":"Same as page(), but it will unwrap the error tuple and raise in case of errors.","ref":"StarkBank.UtilityPayment.html#page!/1"},{"type":"function","title":"StarkBank.UtilityPayment.pdf/2","doc":"Receive a single UtilityPayment pdf file generated in the Stark Bank API by passing its id.\nOnly valid for utility payments with \"success\" status.","ref":"StarkBank.UtilityPayment.html#pdf/2"},{"type":"function","title":"Parameters (required): - StarkBank.UtilityPayment.pdf/2","doc":"- `id` [string]: struct unique id. ex: \"5656565656565656\"","ref":"StarkBank.UtilityPayment.html#pdf/2-parameters-required"},{"type":"function","title":"Options: - StarkBank.UtilityPayment.pdf/2","doc":"- `:user` [Organization/Project, default nil]: Organization or Project struct returned from StarkBank.project(). Only necessary if default project or organization has not been set in configs.","ref":"StarkBank.UtilityPayment.html#pdf/2-options"},{"type":"function","title":"Return: - StarkBank.UtilityPayment.pdf/2","doc":"- UtilityPayment pdf file content","ref":"StarkBank.UtilityPayment.html#pdf/2-return"},{"type":"function","title":"StarkBank.UtilityPayment.pdf!/2","doc":"Same as pdf(), but it will unwrap the error tuple and raise in case of errors.","ref":"StarkBank.UtilityPayment.html#pdf!/2"},{"type":"function","title":"StarkBank.UtilityPayment.query/1","doc":"Receive a stream of UtilityPayment structs previously created in the Stark Bank API","ref":"StarkBank.UtilityPayment.html#query/1"},{"type":"function","title":"Options: - StarkBank.UtilityPayment.query/1","doc":"- `:limit` [integer, default nil]: maximum number of structs to be retrieved. Unlimited if nil. ex: 35\n  - `:after` [Date or string, default nil]: date filter for structs created only after specified date. ex: ~D[2020-03-25]\n  - `:before` [Date or string, default nil]: date filter for structs created only before specified date. ex: ~D[2020-03-25]\n  - `:tags` [list of strings, default nil]: tags to filter retrieved structs. ex: [\"tony\", \"stark\"]\n  - `:ids` [list of strings, default nil]: list of ids to filter retrieved structs. ex: [\"5656565656565656\", \"4545454545454545\"]\n  - `:status` [string, default nil]: filter for status of retrieved structs. ex: \"paid\"\n  - `:user` [Organization/Project, default nil]: Organization or Project struct returned from StarkBank.project(). Only necessary if default project or organization has not been set in configs.","ref":"StarkBank.UtilityPayment.html#query/1-options"},{"type":"function","title":"Return: - StarkBank.UtilityPayment.query/1","doc":"- stream of UtilityPayment structs with updated attributes","ref":"StarkBank.UtilityPayment.html#query/1-return"},{"type":"function","title":"StarkBank.UtilityPayment.query!/1","doc":"Same as query(), but it will unwrap the error tuple and raise in case of errors.","ref":"StarkBank.UtilityPayment.html#query!/1"},{"type":"type","title":"StarkBank.UtilityPayment.t/0","doc":"","ref":"StarkBank.UtilityPayment.html#t:t/0"},{"type":"module","title":"StarkBank.UtilityPayment.Log","doc":"Groups UtilityPayment.Log related functions","ref":"StarkBank.UtilityPayment.Log.html"},{"type":"function","title":"StarkBank.UtilityPayment.Log.__struct__/0","doc":"Every time a UtilityPayment entity is modified, a corresponding UtilityPayment.Log\nis generated for the entity. This log is never generated by the user, but it can\nbe retrieved to check additional information on the UtilityPayment.","ref":"StarkBank.UtilityPayment.Log.html#__struct__/0"},{"type":"function","title":"Attributes: - StarkBank.UtilityPayment.Log.__struct__/0","doc":"- `:id` [string]: unique id returned when the log is created. ex: \"5656565656565656\"\n  - `:payment` [UtilityPayment]: UtilityPayment entity to which the log refers to.\n  - `:errors` [list of strings]: list of errors linked to this UtilityPayment event.\n  - `:type` [string]: type of the UtilityPayment event which triggered the log creation. ex: \"processing\" or \"success\"\n  - `:created` [DateTime]: creation datetime for the log. ex: ~U[2020-03-26 19:32:35.418698Z]","ref":"StarkBank.UtilityPayment.Log.html#__struct__/0-attributes"},{"type":"function","title":"StarkBank.UtilityPayment.Log.get/2","doc":"Receive a single Log struct previously created by the Stark Bank API by passing its id","ref":"StarkBank.UtilityPayment.Log.html#get/2"},{"type":"function","title":"Parameters (required): - StarkBank.UtilityPayment.Log.get/2","doc":"- `id` [string]: struct unique id. ex: \"5656565656565656\"","ref":"StarkBank.UtilityPayment.Log.html#get/2-parameters-required"},{"type":"function","title":"Options: - StarkBank.UtilityPayment.Log.get/2","doc":"- `:user` [Organization/Project, default nil]: Organization or Project struct returned from StarkBank.project(). Only necessary if default project or organization has not been set in configs.","ref":"StarkBank.UtilityPayment.Log.html#get/2-options"},{"type":"function","title":"Return: - StarkBank.UtilityPayment.Log.get/2","doc":"- Log struct with updated attributes","ref":"StarkBank.UtilityPayment.Log.html#get/2-return"},{"type":"function","title":"StarkBank.UtilityPayment.Log.get!/2","doc":"Same as get(), but it will unwrap the error tuple and raise in case of errors.","ref":"StarkBank.UtilityPayment.Log.html#get!/2"},{"type":"function","title":"StarkBank.UtilityPayment.Log.page/1","doc":"Receive a list of up to 100 UtilityPayment.Log objects previously created in the Stark Bank API and the cursor to the next page. \nUse this function instead of query if you want to manually page your requests.","ref":"StarkBank.UtilityPayment.Log.html#page/1"},{"type":"function","title":"Options: - StarkBank.UtilityPayment.Log.page/1","doc":"- `:cursor` [string, default nil]: cursor returned on the previous page function call\n  - `:limit` [integer, default nil]: maximum number of entities to be retrieved. Unlimited if nil. ex: 35\n  - `:after` [Date or string, default nil]: date filter for entities created only after specified date. ex: ~D[2020-03-25]\n  - `:before` [Date or string, default nil]: date filter for entities created only before specified date. ex: ~D[2020-03-25]\n  - `:types` [list of strings, default nil]: filter retrieved entities by event types. ex: \"paid\" or \"registered\"\n  - `:payment_ids` [list of strings, default nil]: list of UtilityPayment ids to filter retrieved entities. ex: [\"5656565656565656\", \"4545454545454545\"]\n  - `:user` [Organization/Project, default nil]: Organization or Project struct returned from StarkBank.project(). Only necessary if default project or organization has not been set in configs.","ref":"StarkBank.UtilityPayment.Log.html#page/1-options"},{"type":"function","title":"Return: - StarkBank.UtilityPayment.Log.page/1","doc":"- list of UtilityPayment.Log structs with updated attributes and cursor to retrieve the next page of UtilityPayment.Log objects","ref":"StarkBank.UtilityPayment.Log.html#page/1-return"},{"type":"function","title":"StarkBank.UtilityPayment.Log.page!/1","doc":"Same as page(), but it will unwrap the error tuple and raise in case of errors.","ref":"StarkBank.UtilityPayment.Log.html#page!/1"},{"type":"function","title":"StarkBank.UtilityPayment.Log.query/1","doc":"Receive a stream of Log structs previously created in the Stark Bank API","ref":"StarkBank.UtilityPayment.Log.html#query/1"},{"type":"function","title":"Options: - StarkBank.UtilityPayment.Log.query/1","doc":"- `:limit` [integer, default nil]: maximum number of entities to be retrieved. Unlimited if nil. ex: 35\n  - `:after` [Date or string, default nil]: date filter for entities created only after specified date. ex: ~D[2020-03-25]\n  - `:before` [Date or string, default nil]: date filter for entities created only before specified date. ex: ~D[2020-03-25]\n  - `:types` [list of strings, default nil]: filter retrieved entities by event types. ex: \"paid\" or \"registered\"\n  - `:payment_ids` [list of strings, default nil]: list of UtilityPayment ids to filter retrieved entities. ex: [\"5656565656565656\", \"4545454545454545\"]\n  - `:user` [Organization/Project, default nil]: Organization or Project struct returned from StarkBank.project(). Only necessary if default project or organization has not been set in configs.","ref":"StarkBank.UtilityPayment.Log.html#query/1-options"},{"type":"function","title":"Return: - StarkBank.UtilityPayment.Log.query/1","doc":"- stream of Log structs with updated attributes","ref":"StarkBank.UtilityPayment.Log.html#query/1-return"},{"type":"function","title":"StarkBank.UtilityPayment.Log.query!/1","doc":"Same as query(), but it will unwrap the error tuple and raise in case of errors.","ref":"StarkBank.UtilityPayment.Log.html#query!/1"},{"type":"type","title":"StarkBank.UtilityPayment.Log.t/0","doc":"","ref":"StarkBank.UtilityPayment.Log.html#t:t/0"},{"type":"module","title":"StarkBank.Webhook","doc":"Groups Webhook related functions","ref":"StarkBank.Webhook.html"},{"type":"function","title":"StarkBank.Webhook.__struct__/0","doc":"A Webhook is used to subscribe to notification events on a user-selected endpoint.\nCurrently available services for subscription are transfer, invoice, deposit, brcode-payment,\nboleto, boleto-holmes, boleto-payment and utility-payment.","ref":"StarkBank.Webhook.html#__struct__/0"},{"type":"function","title":"Parameters (required): - StarkBank.Webhook.__struct__/0","doc":"- `:url` [string]: Url that will be notified when an event occurs.\n  - `:subscriptions` [list of strings]: list of any non-empty combination of the available services. ex: [\"transfer\", \"invoice\", \"deposit\"]","ref":"StarkBank.Webhook.html#__struct__/0-parameters-required"},{"type":"function","title":"Attributes: - StarkBank.Webhook.__struct__/0","doc":"- `:id` [string, default nil]: unique id returned when the webhook is created. ex: \"5656565656565656\"","ref":"StarkBank.Webhook.html#__struct__/0-attributes"},{"type":"function","title":"StarkBank.Webhook.create/1","doc":"Send a single Webhook subscription for creation in the Stark Bank API","ref":"StarkBank.Webhook.html#create/1"},{"type":"function","title":"Parameters (required): - StarkBank.Webhook.create/1","doc":"- `:url` [string]: url to which notification events will be sent to. ex: \"https://webhook.site/60e9c18e-4b5c-4369-bda1-ab5fcd8e1b29\"\n  - `:subscriptions` [list of strings]: list of any non-empty combination of the available services. ex: [\"transfer\", \"brcode-payment\"]","ref":"StarkBank.Webhook.html#create/1-parameters-required"},{"type":"function","title":"Parameters (optional): - StarkBank.Webhook.create/1","doc":"- `:user` [Organization/Project, default nil]: Organization or Project struct returned from StarkBank.project(). Only necessary if default project or organization has not been set in configs.","ref":"StarkBank.Webhook.html#create/1-parameters-optional"},{"type":"function","title":"Return: - StarkBank.Webhook.create/1","doc":"- Webhook struct with updated attributes","ref":"StarkBank.Webhook.html#create/1-return"},{"type":"function","title":"StarkBank.Webhook.create!/1","doc":"Same as create(), but it will unwrap the error tuple and raise in case of errors.","ref":"StarkBank.Webhook.html#create!/1"},{"type":"function","title":"StarkBank.Webhook.delete/2","doc":"Delete a Webhook subscription entity previously created in the Stark Bank API","ref":"StarkBank.Webhook.html#delete/2"},{"type":"function","title":"Parameters (required): - StarkBank.Webhook.delete/2","doc":"- `id` [string]: Webhook unique id. ex: \"5656565656565656\"","ref":"StarkBank.Webhook.html#delete/2-parameters-required"},{"type":"function","title":"Options: - StarkBank.Webhook.delete/2","doc":"- `:user` [Organization/Project, default nil]: Organization or Project struct returned from StarkBank.project(). Only necessary if default project or organization has not been set in configs.","ref":"StarkBank.Webhook.html#delete/2-options"},{"type":"function","title":"Return: - StarkBank.Webhook.delete/2","doc":"- deleted Webhook struct","ref":"StarkBank.Webhook.html#delete/2-return"},{"type":"function","title":"StarkBank.Webhook.delete!/2","doc":"Same as delete(), but it will unwrap the error tuple and raise in case of errors.","ref":"StarkBank.Webhook.html#delete!/2"},{"type":"function","title":"StarkBank.Webhook.get/2","doc":"Receive a single Webhook subscription struct previously created in the Stark Bank API by passing its id","ref":"StarkBank.Webhook.html#get/2"},{"type":"function","title":"Parameters (required): - StarkBank.Webhook.get/2","doc":"- `id` [string]: struct unique id. ex: \"5656565656565656\"","ref":"StarkBank.Webhook.html#get/2-parameters-required"},{"type":"function","title":"Options: - StarkBank.Webhook.get/2","doc":"- `:user` [Organization/Project, default nil]: Organization or Project struct returned from StarkBank.project(). Only necessary if default project or organization has not been set in configs.","ref":"StarkBank.Webhook.html#get/2-options"},{"type":"function","title":"Return: - StarkBank.Webhook.get/2","doc":"- Webhook struct with updated attributes","ref":"StarkBank.Webhook.html#get/2-return"},{"type":"function","title":"StarkBank.Webhook.get!/2","doc":"Same as get(), but it will unwrap the error tuple and raise in case of errors.","ref":"StarkBank.Webhook.html#get!/2"},{"type":"function","title":"StarkBank.Webhook.page/1","doc":"Receive a list of up to 100 Webhook objects previously created in the Stark Bank API and the cursor to the next page. \nUse this function instead of query if you want to manually page your requests.","ref":"StarkBank.Webhook.html#page/1"},{"type":"function","title":"Options: - StarkBank.Webhook.page/1","doc":"- `:cursor` [string, default nil]: cursor returned on the previous page function call\n  - `:limit` [integer, default nil]: maximum number of structs to be retrieved. Unlimited if nil. ex: 35\n  - `:user` [Organization/Project, default nil]: Organization or Project struct returned from StarkBank.project(). Only necessary if default project or organization has not been set in configs.","ref":"StarkBank.Webhook.html#page/1-options"},{"type":"function","title":"Return: - StarkBank.Webhook.page/1","doc":"- list of Webhook structs with updated attributes and cursor to retrieve the next page of Webhook objects","ref":"StarkBank.Webhook.html#page/1-return"},{"type":"function","title":"StarkBank.Webhook.page!/1","doc":"Same as page(), but it will unwrap the error tuple and raise in case of errors.","ref":"StarkBank.Webhook.html#page!/1"},{"type":"function","title":"StarkBank.Webhook.query/1","doc":"Receive a stream of Webhook subcription structs previously created in the Stark Bank API","ref":"StarkBank.Webhook.html#query/1"},{"type":"function","title":"Options: - StarkBank.Webhook.query/1","doc":"- `:limit` [integer, default nil]: maximum number of structs to be retrieved. Unlimited if nil. ex: 35\n  - `:user` [Organization/Project, default nil]: Organization or Project struct returned from StarkBank.project(). Only necessary if default project or organization has not been set in configs.","ref":"StarkBank.Webhook.html#query/1-options"},{"type":"function","title":"Return: - StarkBank.Webhook.query/1","doc":"- stream of Webhook structs with updated attributes","ref":"StarkBank.Webhook.html#query/1-return"},{"type":"function","title":"StarkBank.Webhook.query!/1","doc":"Same as query(), but it will unwrap the error tuple and raise in case of errors.","ref":"StarkBank.Webhook.html#query!/1"},{"type":"type","title":"StarkBank.Webhook.t/0","doc":"","ref":"StarkBank.Webhook.html#t:t/0"},{"type":"module","title":"StarkBank.Workspace","doc":"Groups Workspace related functions","ref":"StarkBank.Workspace.html"},{"type":"function","title":"StarkBank.Workspace.__struct__/0","doc":"Workspaces are bank accounts. They have independent balances, statements, operations and permissions.\nThe only property that is shared between your workspaces is that they are linked to your organization,\nwhich carries your basic informations, such as tax ID, name, etc.","ref":"StarkBank.Workspace.html#__struct__/0"},{"type":"function","title":"Parameters (required): - StarkBank.Workspace.__struct__/0","doc":"- `:username` [string]: Simplified name to define the workspace URL. This name must be unique across all Stark Bank Workspaces. Ex: \"starkbankworkspace\"\n  - `:name` [string]: Full name that identifies the Workspace. This name will appear when people access the Workspace on our platform, for example. Ex: \"Stark Bank Workspace\"","ref":"StarkBank.Workspace.html#__struct__/0-parameters-required"},{"type":"function","title":"Parameters (optional): - StarkBank.Workspace.__struct__/0","doc":"- `:allowed_tax_ids` [list of strings, default []]: list of tax IDs that will be allowed to send Deposits to this Workspace. If empty, all are allowed. ex: [\"012.345.678-90\", \"20.018.183/0001-80\"]","ref":"StarkBank.Workspace.html#__struct__/0-parameters-optional"},{"type":"function","title":"Attributes (return-only): - StarkBank.Workspace.__struct__/0","doc":"- `:id` [string, default nil]: unique id returned when the workspace is created. ex: \"5656565656565656\"","ref":"StarkBank.Workspace.html#__struct__/0-attributes-return-only"},{"type":"function","title":"StarkBank.Workspace.create/1","doc":"Send a single Workspace for creation in the Stark Bank API","ref":"StarkBank.Workspace.html#create/1"},{"type":"function","title":"Parameters (required): - StarkBank.Workspace.create/1","doc":"- `:username` [string]: Simplified name to define the workspace URL. This name must be unique across all Stark Bank Workspaces. Ex: \"starkbankworkspace\"\n  - `:name` [string]: Full name that identifies the Workspace. This name will appear when people access the Workspace on our platform, for example. Ex: \"Stark Bank Workspace\"","ref":"StarkBank.Workspace.html#create/1-parameters-required"},{"type":"function","title":"Options: - StarkBank.Workspace.create/1","doc":"- `:user` [Organization]: Organization struct with nil workspace_id. Only necessary if default organization has not been set in configs.","ref":"StarkBank.Workspace.html#create/1-options"},{"type":"function","title":"Return: - StarkBank.Workspace.create/1","doc":"- Workspace struct with updated attributes","ref":"StarkBank.Workspace.html#create/1-return"},{"type":"function","title":"StarkBank.Workspace.create!/1","doc":"Same as create(), but it will unwrap the error tuple and raise in case of errors.","ref":"StarkBank.Workspace.html#create!/1"},{"type":"function","title":"StarkBank.Workspace.get/2","doc":"Receive a single Workspace struct previously created in the Stark Bank API by passing its id","ref":"StarkBank.Workspace.html#get/2"},{"type":"function","title":"Parameters (required): - StarkBank.Workspace.get/2","doc":"- `id` [string]: struct unique id. ex: \"5656565656565656\"","ref":"StarkBank.Workspace.html#get/2-parameters-required"},{"type":"function","title":"Options: - StarkBank.Workspace.get/2","doc":"- `:user` [Organization/Project, default nil]: Organization or Project struct. Only necessary if default project or organization has not been set in configs.","ref":"StarkBank.Workspace.html#get/2-options"},{"type":"function","title":"Return: - StarkBank.Workspace.get/2","doc":"- Workspace struct with updated attributes","ref":"StarkBank.Workspace.html#get/2-return"},{"type":"function","title":"StarkBank.Workspace.get!/2","doc":"Same as get(), but it will unwrap the error tuple and raise in case of errors.","ref":"StarkBank.Workspace.html#get!/2"},{"type":"function","title":"StarkBank.Workspace.page/1","doc":"Receive a list of up to 100 Workspace objects previously created in the Stark Bank API and the cursor to the next page. \nUse this function instead of query if you want to manually page your requests.","ref":"StarkBank.Workspace.html#page/1"},{"type":"function","title":"Options: - StarkBank.Workspace.page/1","doc":"- `:cursor` [string, default nil]: cursor returned on the previous page function call\n  - `:limit` [integer, default nil]: maximum number of structs to be retrieved. Unlimited if nil. ex: 35\n  - `:username` [string]: query by the simplified name that defines the workspace URL. This name is always unique across all Stark Bank Workspaces. Ex: \"starkbankworkspace\"\n  - `:ids` [list of strings, default nil]: list of ids to filter retrieved structs. ex: [\"5656565656565656\", \"4545454545454545\"]\n  - `:user` [Project]: Project struct returned from StarkBank.project(). Only necessary if default project or organization has not been set in configs.","ref":"StarkBank.Workspace.html#page/1-options"},{"type":"function","title":"Return: - StarkBank.Workspace.page/1","doc":"- list of Workspace structs with updated attributes and cursor to retrieve the next page of Workspace objects","ref":"StarkBank.Workspace.html#page/1-return"},{"type":"function","title":"StarkBank.Workspace.page!/1","doc":"Same as page(), but it will unwrap the error tuple and raise in case of errors.","ref":"StarkBank.Workspace.html#page!/1"},{"type":"function","title":"StarkBank.Workspace.query/1","doc":"Receive a stream of Workspace structs previously created in the Stark Bank API","ref":"StarkBank.Workspace.html#query/1"},{"type":"function","title":"Options: - StarkBank.Workspace.query/1","doc":"- `:limit` [integer, default nil]: maximum number of structs to be retrieved. Unlimited if nil. ex: 35\n  - `:username` [string]: query by the simplified name that defines the workspace URL. This name is always unique across all Stark Bank Workspaces. Ex: \"starkbankworkspace\"\n  - `:ids` [list of strings, default nil]: list of ids to filter retrieved structs. ex: [\"5656565656565656\", \"4545454545454545\"]\n  - `:user` [Project]: Project struct returned from StarkBank.project(). Only necessary if default project or organization has not been set in configs.","ref":"StarkBank.Workspace.html#query/1-options"},{"type":"function","title":"Return: - StarkBank.Workspace.query/1","doc":"- stream of Workspace structs with updated attributes","ref":"StarkBank.Workspace.html#query/1-return"},{"type":"function","title":"StarkBank.Workspace.query!/1","doc":"Same as query(), but it will unwrap the error tuple and raise in case of errors.","ref":"StarkBank.Workspace.html#query!/1"},{"type":"function","title":"StarkBank.Workspace.update/2","doc":"Update a Workspace by passing its ID.","ref":"StarkBank.Workspace.html#update/2"},{"type":"function","title":"Parameters (required): - StarkBank.Workspace.update/2","doc":"- `:id` [string]: Invoice id. ex: '5656565656565656'","ref":"StarkBank.Workspace.html#update/2-parameters-required"},{"type":"function","title":"Parameters (optional): - StarkBank.Workspace.update/2","doc":"- `:username` [string, default nil]: Simplified name to define the workspace URL. This name must be unique across all Stark Bank Workspaces. Ex: \"starkbank-workspace\"\n  - `:name` [string, default nil]: Full name that identifies the Workspace. This name will appear when people access the Workspace on our platform, for example. Ex: \"Stark Bank Workspace\"\n  - `:allowed_tax_ids` [list of strings, default nil]: list of tax IDs that will be allowed to send Deposits to this Workspace. If empty, all are allowed. ex: [\"012.345.678-90\", \"20.018.183/0001-80\"]\n  - `:user` [Organization/Project, default nil]: Organization or Project struct returned from StarkBank.project(). Only necessary if default project or organization has not been set in configs.","ref":"StarkBank.Workspace.html#update/2-parameters-optional"},{"type":"function","title":"Return: - StarkBank.Workspace.update/2","doc":"- target Workspace with updated attributes","ref":"StarkBank.Workspace.html#update/2-return"},{"type":"function","title":"StarkBank.Workspace.update!/2","doc":"Same as update(), but it will unwrap the error tuple and raise in case of errors.","ref":"StarkBank.Workspace.html#update!/2"},{"type":"type","title":"StarkBank.Workspace.t/0","doc":"","ref":"StarkBank.Workspace.html#t:t/0"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,51,46,48]}}